@@ -51,6 +51,7 @@ import os
 import sys
 import time
 
+import animatedvalue
 import appconsts
 import audiomonitoring
 import audiowaveformrenderer
@@ -73,7 +74,9 @@ import editorlayout
 import editorpersistance
 import editorstate
 import editorwindow
+import glassbuttons
 import gmic
+import gtkevents
 import gui
 import guicomponents
 import guipopoverclip
@@ -81,6 +84,7 @@ import jobs
 import keyevents
 import keyframeeditor
 import keyframeeditcanvas
+import keygtkactions
 import kftoolmode
 import medialinker
 import medialog
@@ -144,11 +148,9 @@ disk_cache_timeout_id = -1
 loaded_autosave_file = None
 recovery_in_progress = False
 
-splash_screen = None
-splash_timeout_id = -1
 exit_timeout_id = -1
 window_resize_id = -1
-window_state_id = -1
+window_state_id = -1 # TODO: get rid of this
 resize_timeout_id = -1
 monitor_resize_id = -1
 
@@ -157,6 +159,7 @@ _log_file = None
 assoc_file_path = None
 assoc_timeout_id = None
 
+
 def main(root_path):
     """
     Called at application start.
@@ -231,7 +234,10 @@ class FlowbladeApplication(Gtk.Application):
         shortcuts.load_shortcut_files()
         shortcuts.load_shortcuts()
         shortcutsquickeffects.load_shortcuts()
-        
+
+        # We have translations in data structs and need some initing.
+        animatedvalue.init()
+
         # The test for len != 4 is to make sure that if we change the number of values below the prefs are reset to the correct list
         # So when we add or remove a value, make sure we also change the len test
         # Only use positive numbers.
@@ -302,10 +308,6 @@ class FlowbladeApplication(Gtk.Application):
         # We need to test which GPU render options work after profiles are inited because
         # we do the test by doing test renders.
         rendergputest.test_gpu_rendering_options(render.update_encoding_selector)
-
-        # Splash screen
-        if editorpersistance.prefs.display_splash_screen == True: 
-            show_splash_screen()
             
         # Save assoc file path if found in arguments.
         global assoc_file_path
@@ -353,6 +355,9 @@ class FlowbladeApplication(Gtk.Application):
         # Create main window and make widgeta available from gui.py.
         create_gui()
 
+        # These need widget objects to exist to build ata structures
+        keygtkactions.init()
+
         # Inits widgets with project data.
         init_project_gui()
 
@@ -383,18 +388,13 @@ class FlowbladeApplication(Gtk.Application):
         # Connect listener for this now that the tline panel size allocation is sure to be available.
         global window_resize_id, window_state_id, monitor_resize_id
         window_resize_id = gui.editor_window.window.connect("size-allocate", lambda w, e:updater.window_resized())
-        window_state_id = gui.editor_window.window.connect("window-state-event", lambda w, e:updater.window_resized())
+        if mltplayer.get_sdl_consumer_version() == mltplayer.SDL_1: # Delete when everyone is on mlt 7.30 or moving to Gtk4.
+            window_state_id = gui.editor_window.window.connect("window-state-event", lambda w, e:updater.window_resized())
         monitor_resize_id = gui.tline_display.connect("size-allocate", lambda w, e:tline_display_resized())
 
         # Get existing autosave files
         autosave_files = get_autosave_files()
 
-        # Show splash
-        if ((editorpersistance.prefs.display_splash_screen == True) and len(autosave_files) == 0):
-            global splash_timeout_id
-            splash_timeout_id = GLib.timeout_add(2600, destroy_splash_screen)
-            splash_screen.show_all()
-
         appconsts.SAVEFILE_VERSION = projectdata.SAVEFILE_VERSION # THIS IS A QUESTIONABLE IDEA TO SIMPLIFY IMPORTS, NOT DRY. WHEN DOING TOOLS THAT RUN IN ANOTHER PROCESSES AND SAVE PROJECTS, THIS LINE NEEDS TO BE THERE ALSO.
 
         # Every running instance has unique autosave file which is deleted at exit
@@ -508,6 +508,7 @@ def monkeypatch_callbacks():
     databridge.trimmodes_submode_is_keyb_edit_on = trimmodes.submode_is_keyb_edit_on
     databridge.snapping_get_snapping_on = snapping.get_snapping_on
     databridge.usbhid_get_usb_hid_device_config_metadata_list = usbhid.get_usb_hid_device_config_metadata_list
+    databridge.glass_buttons_default_focus_group_has_focus = glassbuttons.default_focus_group_has_focus
 
     # Set callbacks for undo/redo ops.
     undo.set_post_undo_redo_callback(modesetting.set_post_undo_redo_edit_mode)
@@ -572,10 +573,11 @@ def create_gui():
     gui.pos_bar.set_dark_bg_color()
     
     # Connect window global key listener.
+    #gui.global_key_controller_1 = gtkevents.KeyPressEventAdapter(gui.editor_window.window, keyevents.key_down, user_data=None, capture=True)
     gui.editor_window.window.connect("key-press-event", keyevents.key_down)
     if editorpersistance.prefs.global_layout != appconsts.SINGLE_WINDOW:
         gui.editor_window.window2.connect("key-press-event", keyevents.key_down)
-
+    
     # Give undo a reference to uimanager for menuitem state changes.
     undo.set_menu_items(gui.editor_window.uimanager)
     
@@ -710,7 +712,8 @@ def new_project(profile_index, v_tracks, a_tracks):
 def open_project(new_project):
     stop_autosave()
     gui.editor_window.window.handler_block(window_resize_id)
-    gui.editor_window.window.handler_block(window_state_id)
+    if mltplayer.get_sdl_consumer_version() == mltplayer.SDL_1: # TODO: get rid of this
+        gui.editor_window.window.handler_block(window_state_id)
 
     audiomonitoring.close_audio_monitor()
     audiowaveformrenderer.clear_cache()
@@ -757,7 +760,8 @@ def open_project(new_project):
     updater.set_timeline_height()
 
     gui.editor_window.window.handler_unblock(window_resize_id)
-    gui.editor_window.window.handler_unblock(window_state_id)
+    if mltplayer.get_sdl_consumer_version() == mltplayer.SDL_1: # TODO: get rid of this
+        gui.editor_window.window.handler_unblock(window_state_id)
 
     global resize_timeout_id
     resize_timeout_id = GLib.timeout_add(500, _do_window_resized_update)
@@ -772,7 +776,7 @@ def _do_window_resized_update():
     updater.window_resized()
     
 def change_current_sequence(index):
-    edit.do_gui_update = False  # This should not be necessary but we are doing this signal intention that GUI updates are disabled
+    edit.do_gui_update = False  # This should not be necessary but we are doing this signal intention that GUI updates are disabled.
     
     stop_autosave()
     editorstate.project.c_seq = editorstate.project.sequences[index]
@@ -906,27 +910,6 @@ def do_autosave():
     persistance.save_project(editorstate.PROJECT(), autosave_file)
     return True
 
-# ------------------------------------------------- splash screen
-def show_splash_screen():
-    global splash_screen
-    splash_screen = Gtk.Window(Gtk.WindowType.TOPLEVEL)
-    splash_screen.set_border_width(0)
-    splash_screen.set_decorated(False)
-    splash_screen.set_position(Gtk.WindowPosition.CENTER)
-    img = Gtk.Image.new_from_file(respaths.IMAGE_PATH + "flowblade_splash_black_small.png")
-
-    splash_screen.add(img)
-    splash_screen.set_size_request(598, 258) # Smaller then img.
-
-    splash_screen.set_resizable(False)
-
-    while(GLib.MainContext.default ().pending()):
-        GLib.MainContext.default().iteration(False) # GLib.MainContext to replace this
-
-def destroy_splash_screen():
-    splash_screen.destroy()
-    GLib.source_remove(splash_timeout_id)
-
 # ------------------------------------------------------- disk cache size check
 def check_disk_cache_size():
     GLib.source_remove(disk_cache_timeout_id)
