@@ -42,6 +42,7 @@ from gi.repository import PangoCairo
 
 import appconsts
 import cairoarea
+import gtkbuilder
 import editorstate
 import mltrefhold
 import guiutils
@@ -77,7 +78,7 @@ OVER_FRAMES = 30
 # Colors
 METER_BG_COLOR = (0.15, 0.15, 0.15)
 OVERLAY_COLOR = (0.70, 0.70, 0.70)
-CHANNEL_ID_COLOR = (0.06, 0.34, 0.66)
+CHANNEL_ID_COLOR = (0.66, 0.66, 0.66)
 
 # Color gradient used to draw "LED" colors
 rr, rg, rb = utils.get_cairo_color_tuple_255_rgb(219, 69, 69)
@@ -315,17 +316,26 @@ def _add_audio_level_filter(producer, profile):
     return audio_level_filter
 
 def _audio_monitor_update(data):
-    # 'data' is not used here. 
-    # This is called holding Gdk lock so we can do Gtk updates.
+    # 'data' is not used here, we get that from GLib.timeout_add used to implement ticker.
     if _monitor_window == None and _master_volume_meter == None:
         return
 
+    try:
+        seq = editorstate.current_sequence()
+        frame = editorstate.PLAYER().current_frame()
+    except:
+        return  #this can get attempted before all data available
+        
     global _audio_levels
     _audio_levels = []
+        
     for i in range(0, len(_level_filters)):
         audio_level_filter = _level_filters[i]
         l_val = _get_channel_value(audio_level_filter, LEFT_CHANNEL)
         r_val = _get_channel_value(audio_level_filter, RIGHT_CHANNEL)
+        track_len = seq.tracks[i].get_length() # is this O(n) for clips in MLT?
+        if i > 1 and track_len < frame:
+            l_val = r_val = 0.0
         _audio_levels.append((l_val, r_val))
 
     if _monitor_window != None:
@@ -444,12 +454,10 @@ class AudioMeter:
         
     def display_value(self, cr, x, value_left, value_right, grad):
         cr.set_source(grad)
-        cr.set_dash(DASHES, 0) 
         cr.set_line_width(self.meter_width)
         self.left_channel.display_value(cr, x + self.x_pad_l, value_left)
 
         cr.set_source(grad)
-        cr.set_dash(DASHES, 0) 
         cr.set_line_width(self.meter_width)
         self.right_channel.display_value(cr, x + self.x_pad_r, value_right)
 
@@ -588,8 +596,7 @@ class GainControl(Gtk.Frame):
         self.pan_slider.connect("value-changed", self.pan_changed)
 
         self.pan_button = Gtk.ToggleButton()
-        surface = guiutils.get_cairo_image("pan_track")
-        self.pan_button.set_image(Gtk.Image.new_from_surface (surface))
+        gtkbuilder.button_set_image(self.pan_button, "pan_track")
         self.pan_button.connect("toggled", self.pan_active_toggled)
 
         label = guiutils.bold_label(name)
@@ -661,7 +668,7 @@ class MasterVolumeMeter:
         self.GRAD_CUT = 37
         self.top_pad = 14
         
-        self.meter = AudioMeter(METER_HEIGHT + 40)
+        self.meter = AudioMeter(100)
         self.meter.x_pad_l = 6
         self.meter.x_pad_r = 14
         self.meter.right_channel.draw_dB = True
@@ -674,7 +681,7 @@ class MasterVolumeMeter:
         w = SLOT_W - 40
         h = METER_SLOT_H + 2 + 40
         self.canvas = cairoarea.CairoDrawableArea2( w,
-                                                    h, 
+                                                    100, 
                                                     self._draw)
 
         self.widget = Gtk.VBox(False, 0)
@@ -685,7 +692,7 @@ class MasterVolumeMeter:
 
         self.meter.set_height(h - self.H_CUT)
  
-        cr.set_source_rgb(0.0, 0.0, 0.0)
+        cr.set_source_rgb(0.15, 0.15, 0.15)
         cr.fill_preserve()
         cr.rectangle(0, 0, w, h)
         cr.fill()
