@@ -2,7 +2,7 @@
     Flowblade Movie Editor is a nonlinear video editor.
     Copyright 2012 Janne Liljeblad.
 
-    This file is part of Flowblade Movie Editor <http://code.google.com/p/flowblade>.
+    This file is part of Flowblade Movie Editor <https://github.com/jliljebl/flowblade/>.
 
     Flowblade Movie Editor is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,14 +20,13 @@
 
 """
 Module contains CairoDrawableArea2 widget. You can draw onto it using 
-Cairo by setting the raw function on ceation, and listen to its mouse and keyboard events.
+Cairo by setting the draw function on creation, and listen to its mouse and keyboard events.
 """
 
 from gi.repository import Gtk
-from gi.repository import GObject
 from gi.repository import Gdk
 
-import gui
+import gtkevents
 
 bg_color = None
 
@@ -44,7 +43,7 @@ class CairoDrawableArea2(Gtk.DrawingArea):
         self.add_events(Gdk.EventMask.ENTER_NOTIFY_MASK)
         self.add_events(Gdk.EventMask.LEAVE_NOTIFY_MASK)
         self.add_events(Gdk.EventMask.KEY_PRESS_MASK)
-        self.add_events(Gdk.EventMask.POINTER_MOTION_HINT_MASK)
+        self.add_events(Gdk.EventMask.POINTER_MOTION_MASK)
     
         self.set_size_request(pref_width, pref_height)
         self._use_widget_bg = use_widget_bg
@@ -53,14 +52,33 @@ class CairoDrawableArea2(Gtk.DrawingArea):
         self._draw_func = func_draw
         self.connect('draw', self._draw_event)
 
-        self.connect('button-press-event', self._button_press_event)
-        self.connect('button-release-event', self._button_release_event)
-        self.connect('motion-notify-event', self._motion_notify_event)
-        self.connect('enter-notify-event', self._enter_notify_event)
-        self.connect('leave-notify-event', self._leave_notify_event)
-        self.connect("scroll-event", self._mouse_scroll_event)
+        #self.connect('button-press-event', self._button_press_event)
+        self.press_controller = Gtk.GestureMultiPress(widget=self)
+        self.press_controller.set_button(0)
+        self.press_controller.connect("pressed", self._button_press_event)
+        
+        #self.connect('button-release-event', self._button_release_event)
+        self.release_controller = Gtk.GestureMultiPress(widget=self)
+        self.release_controller.connect("released", self._button_release_event)
 
-        # Signal handler funcs. These are monkeypatched as needed on codes sites
+        #self.connect('motion-notify-event', self._motion_notify_event)
+        self.motion_controller = Gtk.EventControllerMotion(widget=self)
+        self.motion_controller.connect("motion", self._motion_notify_event)
+
+        #self.connect('enter-notify-event', self._enter_notify_event)
+        self.enter_controller = Gtk.EventControllerMotion(widget=self)
+        self.enter_controller.connect("enter", self._enter_notify_event)
+        
+        #self.connect('leave-notify-event', self._leave_notify_event)
+        self.leave_controller = Gtk.EventControllerMotion(widget=self)
+        self.leave_controller.connect("leave", self._leave_notify_event)
+         
+        #self.connect("scroll-event", self._mouse_scroll_event)
+        self.scroll_controller = Gtk.EventControllerScroll(widget=self)
+        self.scroll_controller.set_flags(Gtk.EventControllerScrollFlags.BOTH_AXES)
+        self.scroll_controller.connect("scroll", self._mouse_scroll_event)
+ 
+        # Signal handler funcs. These are monkeypatched as needed on use sites
         # that create the objects.
         self.press_func = self._press
         self.release_func = self._release
@@ -69,13 +87,11 @@ class CairoDrawableArea2(Gtk.DrawingArea):
         self.enter_notify_func = self._enter
         self.mouse_scroll_func = None
 
-        # Flag for grabbing focus
         self.set_property("can-focus",  True)
         self.grab_focus_on_press = True
 
     def add_pointer_motion_mask(self):
         self.add_events(Gdk.EventMask.POINTER_MOTION_MASK)
-        #self.connect('pointer-motion-event', listener)
 
     def set_pref_size(self, pref_width, pref_height):
         self.set_size_request(pref_width, pref_height)
@@ -89,40 +105,48 @@ class CairoDrawableArea2(Gtk.DrawingArea):
 
     # ------------------------------------------------------------ Signal listeners 
     # These pass on events to handler functions that 
-    # are by default the noop functions here, but are monkeypathed 
+    # are by default the noop functions here, but are monkeypatched 
     # at creation sites as needed. 
-    def _button_press_event(self, widget, event):
+    def _button_press_event(self, event, n_press, x, y):    
+        gdk_event = gtkevents.ButtonEvent(n_press, x, y)
+        
         if self.grab_focus_on_press:
             self.grab_focus()
-        self.press_func(event)
+        self.press_func(gdk_event)
+        
+        return False
+
+    def _button_release_event(self, event, n_press, x, y):
+        gdk_event = gtkevents.ButtonEvent(n_press, x, y)
+        self.release_func(gdk_event)
 
         return False
 
-    def _button_release_event(self,  widget, event):
-        self.release_func(event)
-
-        return False
-
-    def _motion_notify_event(self, widget, event):
-        if event.is_hint:
-            winbdow, x, y, state = event.window.get_pointer()
-        else:
-            x = event.x
-            y = event.y
-            state = event.get_state()
-
+    def _motion_notify_event(self, event, x, y):
+        gdk_event = gtkevents.SimpleStateEvent()
+        state = gdk_event.get_state()
         self.motion_notify_func(x, y, state)
 
-    def _enter_notify_event(self, widget, event):
-        self.enter_notify_func(event)
+    def _enter_notify_event(self, event, a, b):
+        gdk_event = gtkevents.SimpleStateEvent()
+        self.enter_notify_func(gdk_event)
         
-    def _leave_notify_event(self, widget, event):
-        self.leave_notify_func(event)
-        
-    def _mouse_scroll_event(self, widget, event):
+    def _leave_notify_event(self, event):
+        try:
+            gdk_event = gtkevents.SimpleStateEvent()
+            self.leave_notify_func(gdk_event)
+        except:
+            # On start-up this one some times fails once for un-known reason.
+            # We keep printing info on it but won't attemp any fixes for now. 
+            print("Failed to create gtkevents.SimpleStateEvent for a leave notify event.")
+
+    def _mouse_scroll_event(self, scroll_event, dx, dy):
         if self.mouse_scroll_func == None:
             return
-        self.mouse_scroll_func(event)
+
+        gdk_event = gtkevents.ScrollEvent(dx, dy) # This wont be needed as such for Gtk4 which has get_current_event_state()
+
+        self.mouse_scroll_func(gdk_event)
 
     # ------------------------------------------------------- Noop funcs for unhandled events
     def _press(self, event):
