@@ -39,10 +39,12 @@ from editorstate import PROJECT
 from editorstate import PLAYER
 from editorstate import current_sequence
 import extraeditors
+import gtkbuilder
 import gui
 import guicomponents
 import guipopover
 import guiutils
+import keygtkactions
 import mltfilters
 import propertyedit
 import propertyeditorbuilder
@@ -92,13 +94,8 @@ class FilterFooterRow:
         self.filter_object = filter_object
         self.filter_stack = filter_stack
 
-        if editorpersistance.prefs.icons_scale == appconsts.ICONS_SCALE_DEFAULT:
-            w=22
-            h=22
-        else:
-            w=44
-            h=44
-            
+        w=22
+        h=22
         surface = guiutils.get_cairo_image("filter_save")
         save_button = guicomponents.PressLaunch(self.save_pressed, surface, w, h)
         save_button.widget.set_tooltip_markup(_("Save effect values"))
@@ -202,17 +199,35 @@ class FilterFooterRow:
 
 class FilterHeaderRow:
     
-    def __init__(self, filter_object):
+    def __init__(self, filter_object, stack_item):
         name = translations.get_filter_name(filter_object.info.name)
         self.filter_name_label = Gtk.Label(label= "<b>" + name + "</b>")
         self.filter_name_label.set_use_markup(True)
         self.icon = Gtk.Image.new_from_pixbuf(filter_object.info.get_icon())
 
+        surface = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "trash.png")
+        trash_button = guicomponents.PressLaunch(stack_item.trash_pressed, surface, w=22, h=22)
+        
+        surface = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "filters_up_arrow.png")
+        up_button = guicomponents.PressLaunch(stack_item.up_pressed, surface, w=10, h=22)
+        up_button.surface_x = 0
+        up_button.widget.set_margin_right(2)
+
+        surface = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "filters_down_arrow.png")
+        down_button = guicomponents.PressLaunch(stack_item.down_pressed, surface, w=10, h=22)
+        down_button.surface_x = 0
+        down_button.surface_y = 10
+        
+        
         hbox = Gtk.HBox(False, 0)
+        hbox.pack_start(stack_item.active_check, False, False, 0)
         hbox.pack_start(guiutils.pad_label(4,5), False, False, 0)
         hbox.pack_start(self.icon, False, False, 0)
         hbox.pack_start(self.filter_name_label, False, False, 0)
         hbox.pack_start(Gtk.Label(), True, True, 0)
+        hbox.pack_start(up_button.widget, False, False, 0)
+        hbox.pack_start(down_button.widget, False, False, 0)
+        hbox.pack_start(trash_button.widget, False, False, 0)
         self.widget = hbox
 
 
@@ -220,61 +235,29 @@ class FilterStackItem:
 
     def __init__(self, filter_object, edit_panel, filter_stack):
         self.filter_object = filter_object
-        self.filter_header_row = FilterHeaderRow(filter_object)
+
+        self.active_check = Gtk.CheckButton()
+        self.active_check.set_active(self.filter_object.active)
+        self.active_check.connect("toggled", self.toggle_filter_active)
+
+        self.active_check.set_margin_left(2)
+        self.filter_header_row = FilterHeaderRow(filter_object, self)
 
         self.edit_panel = edit_panel
         self.edit_panel_frame = Gtk.Box.new(Gtk.Orientation.VERTICAL, 0)
         self.edit_panel_frame.add(edit_panel)
         
         self.filter_stack = filter_stack
-        self.expander = Gtk.Expander()
+        self.expander = Expander()
         self.expander.set_label_widget(self.filter_header_row.widget)
         self.expander.add(self.edit_panel_frame)
-        self.expander.set_label_fill(True)
 
         self.expander_frame = Gtk.Box.new(Gtk.Orientation.VERTICAL, 0)
-        self.expander_frame.add(self.expander)
+        self.expander_frame.add(self.expander.widget)
         guiutils.set_margins(self.expander_frame, 2, 0, 0, 0)
         
-        self.active_check = Gtk.CheckButton()
-        self.active_check.set_active(self.filter_object.active)
-        self.active_check.connect("toggled", self.toggle_filter_active)
-        guiutils.set_margins(self.active_check, 4, 0, 0, 0)
-
-        self.active_check_vbox = Gtk.VBox(False, 0)
-        self.active_check_vbox.pack_start(self.active_check, False, False, 0)
-        self.active_check_vbox.pack_start(Gtk.Label(), True, True, 0)
-
-        surface = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "trash.png")
-        trash_button = guicomponents.PressLaunch(self.trash_pressed, surface, w=22, h=22)
-        
-        surface = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "filters_up_arrow.png")
-        up_button = guicomponents.PressLaunch(self.up_pressed, surface, w=10, h=22)
-        up_button.surface_x = 0
-
-        surface = cairo.ImageSurface.create_from_png(respaths.IMAGE_PATH + "filters_down_arrow.png")
-        down_button = guicomponents.PressLaunch(self.down_pressed, surface, w=10, h=22)
-        down_button.surface_x = 0
-        down_button.surface_y = 10
-        
-        self.trash_vbox = Gtk.VBox(False, 0)
-        self.trash_vbox.pack_start(trash_button.widget, False, False, 0)
-        self.trash_vbox.pack_start(Gtk.Label(), True, True, 0)
-
-        self.up_vbox = Gtk.VBox(False, 0)
-        self.up_vbox.pack_start(up_button.widget, False, False, 0)
-        self.up_vbox.pack_start(Gtk.Label(), True, True, 0)
-
-        self.down_vbox = Gtk.VBox(False, 0)
-        self.down_vbox.pack_start(down_button.widget, False, False, 0)
-        self.down_vbox.pack_start(Gtk.Label(), True, True, 0)
-        
         self.widget = Gtk.HBox(False, 0)
-        self.widget.pack_start(self.active_check_vbox, False, False, 0)
         self.widget.pack_start(self.expander_frame, True, True, 0)
-        self.widget.pack_start(self.trash_vbox, False, False, 0)
-        self.widget.pack_start(self.up_vbox, False, False, 0)
-        self.widget.pack_start(self.down_vbox, False, False, 0)
         self.widget.pack_start(guiutils.pad_label(10,2), False, False, 0)
 
         self.widget.show_all()
@@ -416,7 +399,7 @@ class ClipFilterStack:
         for i in range(0, len(self.filter_stack)):
             stack_item = self.filter_stack[i]
             stack_item.expander.set_expanded(expanded)
-            
+
     def get_expanded(self):
         state_list = []
         for stack_item in self.filter_stack:
@@ -436,6 +419,72 @@ class ClipFilterStack:
         stack_item = self.filter_stack[expanded_index]
         stack_item.expander.set_expanded(True)
 
+class Expander:
+    
+    def __init__(self):
+        self.widget = Gtk.VBox(False, 0) 
+        self.label = None
+        self.child = None
+        self.expanded = True
+        
+        self.label_box = Gtk.HBox(False, 0) 
+        self.child_box = Gtk.VBox(False, 0) 
+        
+        self.img_unexpanded = Gtk.Image.new_from_icon_name("pan-end-symbolic", Gtk.IconSize.BUTTON)
+        self.img_expanded = Gtk.Image.new_from_icon_name("pan-down-symbolic", Gtk.IconSize.BUTTON)
+
+        self.arrow_box = gtkbuilder.EventBox(self.img_expanded, 'button-release-event', self._toggle_expand)
+        
+        self.widget.pack_start(self.label_box, False, False, 0)
+        self.widget.pack_start(self.child_box, True, True, 0)
+        
+    def set_label_widget(self, label_widget):
+        self.label = label_widget
+        self._update_label_row()
+        self.widget.queue_draw()
+
+    def _update_label_row(self):
+        # Remove panels from box
+        children = self.label_box.get_children()
+        for child in children:
+            self.label_box.remove(child)
+        self.arrow_box.remove(self.arrow_box.get_child())
+        if self.expanded == True:
+            self.arrow_box.add(self.img_expanded)
+        else:
+            self.arrow_box.add(self.img_unexpanded)
+        self.arrow_box.show_all()
+
+        self.label_box.pack_start(self.arrow_box, False, False, 0)
+        self.label_box.pack_start(self.label, True, True, 0)
+
+    def add(self, child_widget):
+        self.child = child_widget
+        self._update_child_row()
+        self.widget.queue_draw()
+
+    def _update_child_row(self):
+        children = self.child_box.get_children()
+        for child in children:
+            self.child_box.remove(child)
+        
+        if self.expanded == True:
+            self.child_box.pack_start(self.child, False, False, 0)
+
+    def set_expanded(self, expanded):
+        self.expanded = expanded
+        self._update_label_row()
+        self._update_child_row()
+
+    def get_expanded(self):
+        return self.expanded
+
+    def _toggle_expand(self, widget, event):
+        self.expanded = not self.expanded
+        self._update_label_row()
+        self._update_child_row()
+        
+
 # -------------------------------------------------------------- GUI INIT
 def get_clip_effects_editor_info_row():
     _create_widgets()
@@ -456,9 +505,8 @@ def _create_widgets():
     widgets.clip_info = guicomponents.ClipInfoPanel()
     
     widgets.value_edit_box = Gtk.VBox()
-    widgets.value_edit_frame = Gtk.Frame()
+    widgets.value_edit_frame = Gtk.Alignment.new(0.5, 0, 1, 1)
     widgets.value_edit_frame.add(widgets.value_edit_box)
-    
     widgets.hamburger_launcher = guicomponents.HamburgerPressLaunch(_hamburger_launch_pressed)
     widgets.hamburger_launcher.do_popover_callback = True
     guiutils.set_margins(widgets.hamburger_launcher.widget, 6, 8, 1, 0)
@@ -470,6 +518,9 @@ def _create_widgets():
     guiutils.set_margins(widgets.filter_add_launch.widget, 6, 8, 1, 0)
     
 # ------------------------------------------------------------------- interface
+def get_stack():
+    return _filter_stack
+    
 def set_clip(clip, track, clip_index, show_tab=True):
     """
     Sets clip being edited and inits gui.
@@ -553,6 +604,7 @@ def effect_select_row_double_clicked(treeview, tree_path, col, effect_select_com
 
     _add_filter_from_effect_select_panel(row_index, group_index)
 
+"""
 def add_currently_selected_effect():
     # Currently selected in effect select panel, not here.
     treeselection = gui.effect_select_list_view.treeview.get_selection()
@@ -562,6 +614,7 @@ def add_currently_selected_effect():
     group_index = gui.effect_select_combo_box.get_active()
 
     _add_filter_from_effect_select_panel(row_index, group_index)
+"""
 
 def get_currently_selected_filter_info():
     # Currently selected in effect select panel, not here.
@@ -579,6 +632,8 @@ def _add_filter_from_effect_select_panel(row_index, group_index):
     group_name, filters_array = mltfilters.groups[group_index]
     filter_info = filters_array[row_index]
 
+    expanded_panels = _filter_stack.get_expanded()
+
     data = {"clip":_filter_stack.clip, 
             "filter_info":filter_info,
             "filter_edit_done_func":filter_edit_done_stack_update}
@@ -591,6 +646,9 @@ def _add_filter_from_effect_select_panel(row_index, group_index):
     clip, track, clip_index = _filter_stack.get_clip_data()
     set_clip(clip, track, clip_index)
 
+    expanded_panels.append(True)
+    _filter_stack.set_expanded(expanded_panels)
+
     updater.repaint_tline()
 
 def clear_clip():
@@ -638,7 +696,6 @@ def update_stack(clip, track, clip_index):
     global widgets
     widgets.value_edit_frame.remove(widgets.value_edit_box)
     widgets.value_edit_frame.add(scroll_window)
-
     widgets.value_edit_box = scroll_window
 
 def _alpha_filter_add_maybe_info(filter_info):
@@ -790,11 +847,13 @@ def _get_filter_panel(clip, filter_object, filter_index, track, clip_index):
                 or (editor_type == propertyeditorbuilder.KEYFRAME_EDITOR_CLIP_FADE_FILTER)):
                     keyframe_editor_widgets.append(editor_row)
                     filter_keyframe_editor_widgets.append(editor_row)
-
+                    keygtkactions.connect_filter_widget(editor_row)
+                
             # if slider property is being edited as keyrame property
             if hasattr(editor_row, "is_kf_editor"):
                 keyframe_editor_widgets.append(editor_row)
                 filter_keyframe_editor_widgets.append(editor_row)
+                keygtkactions.connect_filter_widget(editor_row)
 
             vbox.pack_start(editor_row, False, False, 0)
             if not hasattr(editor_row, "no_separator"):
@@ -830,6 +889,7 @@ def _get_filter_panel(clip, filter_object, filter_index, track, clip_index):
                 # editor_row is just Gtk.VBox.
                 keyframe_editor_widgets.append(editor_row.kf_edit_geom_editor)
                 filter_keyframe_editor_widgets.append(editor_row.kf_edit_geom_editor)
+                keygtkactions.connect_filter_widget(editor_row.kf_edit_geom_editor)
     else:
         vbox.pack_start(Gtk.Label(label=_("No editable parameters")), True, True, 0)
     vbox.show_all()
@@ -839,18 +899,18 @@ def _get_filter_panel(clip, filter_object, filter_index, track, clip_index):
 def show_text_in_edit_area(text):
     vbox = Gtk.VBox(False, 0)
 
-    filler = Gtk.EventBox()
-    filler.add(Gtk.Label())
+    filler = Gtk.Stack()  
+    filler.add_named(Gtk.Label(), "filler")
     vbox.pack_start(filler, True, True, 0)
     
     info = Gtk.Label(label=text)
     info.set_sensitive(False)
-    filler = Gtk.EventBox()
-    filler.add(info)
+    filler = Gtk.Stack()  
+    filler.add_named(info, "filler")
     vbox.pack_start(filler, False, False, 0)
     
-    filler = Gtk.EventBox()
-    filler.add(Gtk.Label())
+    filler = Gtk.Stack()  
+    filler.add_named(Gtk.Label(), "filler")
     vbox.pack_start(filler, True, True, 0)
 
     vbox.show_all()
@@ -993,6 +1053,8 @@ def _filter_menu_callback(w, data):
     clip, track, item_id, item_data = data
     x, filter_info = item_data
 
+    expanded_panels = _filter_stack.get_expanded()
+
     action = get_filter_add_action(filter_info, clip)
     set_stack_update_blocked() # We update stack on set_clip below
     action.do_edit()
@@ -1001,7 +1063,8 @@ def _filter_menu_callback(w, data):
     # (re)open clip in editor.
     index = track.clips.index(clip)
     set_clip(clip, track, index)
-    set_filter_item_expanded(len(clip.filters) - 1)
+    expanded_panels.append(True)
+    _filter_stack.set_expanded(expanded_panels)
     
 def _save_effect_values_dialog_callback(dialog, response_id, filter_object):
     if response_id == Gtk.ResponseType.ACCEPT:
