@@ -25,6 +25,7 @@ Module handles clip end dragging edits.
 from gi.repository import Gdk
 
 import appconsts
+import dualsynctrim
 import gui
 import edit
 from editorstate import current_sequence
@@ -113,10 +114,14 @@ def _init_insert_drag(clip, clip_index, track, frame, cut_frame):
     _edit_data["orig_in"] = cut_frame - 1
     _edit_data["orig_out"] = cut_frame + (clip.clip_out - clip.clip_in)
     _edit_data["submode"] = _submode
+    _edit_data["cut_frame"] = cut_frame
+
+    dualsynctrim.set_child_clip_end_drag_data(_edit_data, clip)
 
     _enter_mouse_drag_edit(editing_clip_end)
 
 def _init_overwrite_drag(clip, clip_index, track, frame, cut_frame):
+
     global _submode
     _submode = OVERWRITE_DRAG
     
@@ -156,12 +161,12 @@ def _init_overwrite_drag(clip, clip_index, track, frame, cut_frame):
         to_clip_end = track.clip_start(clip_index) + to_clip.clip_length()
         from_clip_start = track.clip_start(clip_index - 1)
         from_clip_end = track.clip_start(clip_index - 1) - from_clip.clip_in + from_clip.get_length() 
-        
-    if to_clip_start > from_clip_start:
-        bound_start = to_clip_start
-    else:
-        bound_start = from_clip_start
     
+    if to_clip_start > from_clip_start and to_clip.is_blanck_clip == False:
+        bound_start = to_clip_start
+    else:        
+        bound_start = from_clip_start
+
     if from_clip_end < to_clip_end:
         bound_end = from_clip_end
     else:
@@ -172,6 +177,9 @@ def _init_overwrite_drag(clip, clip_index, track, frame, cut_frame):
         
     if editing_clip_end == False and bound_start < from_clip_start:
         bound_start = from_clip_start
+
+    if to_clip_start > from_clip_start and from_clip.is_blanck_clip == True:
+        bound_start = to_clip_start
         
     global _enter_mode, _enter_draw_func, _edit_data
 
@@ -179,7 +187,7 @@ def _init_overwrite_drag(clip, clip_index, track, frame, cut_frame):
     editorstate.edit_mode = editorstate.CLIP_END_DRAG
 
     _enter_draw_func = tlinewidgets.canvas_widget.edit_mode_overlay_draw_func
-
+    
     _edit_data = {}
     _edit_data["track"] = track
     _edit_data["clip_index"] = clip_index
@@ -237,7 +245,6 @@ def mouse_release(x, y, frame, state):
     else:
         _do_overwrite_trim(x, y, frame, state)
 
-
 def _do_insert_trim(x, y, frame, state):
     frame = _legalize_frame(frame)
     _edit_data["frame"] = frame
@@ -273,7 +280,7 @@ def _do_insert_trim(x, y, frame, state):
                 updater.repaint_tline()
                 return
 
-        # next clip is not blank or last clip
+        # clip end trim if next clip is not blank or next xlip is last clip
         if ((clip_index == len(track.clips) - 1) or 
             (track.clips[clip_index + 1].is_blanck_clip == False)):
             data = {"track":track,
@@ -281,8 +288,19 @@ def _do_insert_trim(x, y, frame, state):
                     "clip":clip,
                     "delta":delta}
             action = edit.trim_last_clip_end_action(data)
-            action.do_edit()
-        else: # next clip is blank
+            
+            if _edit_data["child_clip_trim_data"] == None:
+                action.do_edit()
+            else:
+                sync_trim_action = dualsynctrim.get_one_roll_sync_edit(_edit_data, delta, dualsynctrim.ONE_ROLL_TRIM_END)
+                if sync_trim_action != None:
+                    actions = [action, sync_trim_action]
+                    consolidated_action = edit.ConsolidatedEditAction(actions)
+                    consolidated_action.do_consolidated_edit()
+                else:
+                    action.do_edit()
+    
+        else: # clip end trim next clip is blank
             blank_clip = track.clips[clip_index + 1]
             blank_clip_length = blank_clip.clip_length()
             data = {"track":track,
@@ -292,10 +310,20 @@ def _do_insert_trim(x, y, frame, state):
                     "delta":delta}
             if delta < blank_clip_length: # partial blank overwrite
                 action = edit.clip_end_drag_on_blank_action(data)
-                action.do_edit()
             else: # full blank replace
                 action = edit.clip_end_drag_replace_blank_action(data)
+
+            if _edit_data["child_clip_trim_data"] == None:
                 action.do_edit()
+            else:
+                sync_trim_action = dualsynctrim.get_one_roll_sync_edit(_edit_data, delta, dualsynctrim.ONE_ROLL_TRIM_END)
+                if sync_trim_action != None:
+                    actions = [action, sync_trim_action]
+                    consolidated_action = edit.ConsolidatedEditAction(actions)
+                    consolidated_action.do_consolidated_edit()
+                else:
+                    action.do_edit()
+                
     else:# Dragging clip start
         delta = frame - orig_in  - 1 # -1 because..uhh..inclusive exclusive something something
         # prev clip is not blank or first clip
@@ -306,7 +334,16 @@ def _do_insert_trim(x, y, frame, state):
                     "clip":clip,
                     "delta":delta}
             action = edit.trim_start_action(data)
-            action.do_edit()
+            if _edit_data["child_clip_trim_data"] == None:
+                action.do_edit()
+            else:
+                sync_trim_action = dualsynctrim.get_one_roll_sync_edit(_edit_data, delta, dualsynctrim.ONE_ROLL_TRIM_START)
+                if sync_trim_action != None:
+                    actions = [action, sync_trim_action]
+                    consolidated_action = edit.ConsolidatedEditAction(actions)
+                    consolidated_action.do_consolidated_edit()
+                else:
+                    action.do_edit()
         else: # prev clip is blank
             blank_clip = track.clips[clip_index - 1]
             blank_clip_length = blank_clip.clip_length()
@@ -317,10 +354,30 @@ def _do_insert_trim(x, y, frame, state):
                     "delta":delta}
             if -delta < blank_clip_length: # partial blank overwrite
                 action = edit.clip_start_drag_on_blank_action(data)
-                action.do_edit()
             else: # full blank replace
                 action = edit.clip_start_drag_replace_blank_action(data)
+
+            if _edit_data["child_clip_trim_data"] == None:
                 action.do_edit()
+            else:
+                data = {"track":track,
+                        "index":clip_index,
+                        "from_clip":blank_clip,
+                        "to_clip":clip,
+                        "delta":delta,
+                        "edit_done_callback": None, # we don't do callback needing this
+                        "cut_frame": _edit_data["cut_frame"],
+                        "to_side_being_edited":None, # we don't do callback needing this
+                        "non_edit_side_blank":True,
+                        "first_do":False}  # no callback
+
+                sync_trim_action = dualsynctrim.get_two_roll_sync_edits(data)
+                if sync_trim_action != None:
+                    actions = [action, sync_trim_action[0]]
+                    consolidated_action = edit.ConsolidatedEditAction(actions)
+                    consolidated_action.do_consolidated_edit()
+                else:
+                    action.do_edit()
 
     _exit_clip_end_drag()
 
@@ -328,7 +385,6 @@ def _do_insert_trim(x, y, frame, state):
 
 def _do_overwrite_trim(x, y, frame, state):
     frame = _legalize_frame(frame)
-
     updater.repaint_tline()
 
     track = _edit_data["track"]
@@ -336,7 +392,6 @@ def _do_overwrite_trim(x, y, frame, state):
     editing_clip_end = _edit_data["editing_clip_end"] 
     
     from_clip, to_clip = _get_from_clip_and_to_clip(editing_clip_end, track, clip_index)
-
     non_edit_side_blank = False
     if (_edit_data["editing_clip_end"] == False) and (track.clips[clip_index - 1].is_blanck_clip == True):
         non_edit_side_blank = True
@@ -344,7 +399,11 @@ def _do_overwrite_trim(x, y, frame, state):
         non_edit_side_blank = True
 
     # If drag covers adjacent clip fully we need to use different edit actions.
-    if editing_clip_end == True and frame == _edit_data["bound_end"]:
+    from_clip_start = track.clip_start(track.clips.index(from_clip)) - from_clip.clip_in
+    to_clip_end = track.clip_start(track.clips.index(to_clip)) + to_clip.clip_length()
+
+    if editing_clip_end == True and frame == _edit_data["bound_end"] and frame == to_clip_end:
+        
         data = {"track":track,
                 "clip":to_clip,
                 "index":clip_index + 1}
@@ -355,7 +414,7 @@ def _do_overwrite_trim(x, y, frame, state):
         _exit_clip_end_drag()
         updater.repaint_tline()
         return
-    elif editing_clip_end == False and frame == _edit_data["bound_start"]:
+    elif editing_clip_end == False and frame == _edit_data["bound_start"] and frame == from_clip_start:
         data = {"track":track,
                 "clip":from_clip,
                 "index":clip_index - 1}
@@ -369,12 +428,11 @@ def _do_overwrite_trim(x, y, frame, state):
         
     # Code here thinks "clip_index" is always index of trimmed clip,
     # but we are using existing edit.tworoll_trim_action() code to do the edit, and 
-    # that assumes index to be between clips.
+    # that assumes index to be latter of the to clips.
     if editing_clip_end == True:
         clip_index += 1
 
 
-
     # Get edit data
     delta = frame - _edit_data["edit_frame"]
     data = {"track":track,
@@ -387,11 +445,22 @@ def _do_overwrite_trim(x, y, frame, state):
             "to_side_being_edited":not editing_clip_end,
             "non_edit_side_blank":non_edit_side_blank,
             "first_do":True}
-                
-    action = edit.tworoll_trim_action(data)
-    edit.do_gui_update = True
-    action.do_edit()
 
+    action = edit.tworoll_trim_action(data)
+    action_list = [action]
+
+    sync_actions_list = dualsynctrim.get_two_roll_sync_edits(data)
+    if sync_actions_list != None:
+        action_list = action_list + sync_actions_list
+
+    edit.do_gui_update = True
+
+    if len(action_list) == 1:
+        action.do_edit() # No dual sync edits
+    else:
+        consolidated_action = edit.ConsolidatedEditAction(action_list)
+        consolidated_action.do_consolidated_edit()
+            
     _exit_clip_end_drag()
 
     updater.repaint_tline()
