@@ -179,8 +179,13 @@ def _open_clip_in_clip_monitor(data):
     if media_file == None and clip.container_data != None:
         media_file = PROJECT().get_media_file_for_container_data(clip.container_data)
 
-    media_file.mark_in = clip.clip_in
-    media_file.mark_out = clip.clip_out
+    try:
+        media_file.mark_in = clip.clip_in
+        media_file.mark_out = clip.clip_out
+    except:
+        # This fails for color clips and the correct fix is quite involved so this was added as temp for 2.24
+        return
+
     updater.set_and_display_monitor_media_file(media_file)
     gui.pos_bar.widget.grab_focus()
 
@@ -262,6 +267,11 @@ def _add_filter(data):
     clip, track, item_id, filter_info = data
     clip, track, x = _popover_clip_data 
 
+    if clipeffectseditor.get_stack() != None and clip == clipeffectseditor.get_stack().clip:
+        expanded_panels = clipeffectseditor.get_stack().get_expanded()
+    else:
+        expanded_panels = None
+
     action = clipeffectseditor.get_filter_add_action(filter_info, clip)
     clipeffectseditor.set_stack_update_blocked() # We update stack on set_clip below
     action.do_edit()
@@ -271,7 +281,12 @@ def _add_filter(data):
     frame = tlinewidgets.get_frame(x)
     index = track.get_clip_index_at(frame)
     clipeffectseditor.set_clip(clip, track, index)
-    clipeffectseditor.set_filter_item_expanded(len(clip.filters) - 1)
+
+    if expanded_panels != None:
+        expanded_panels.append(True)
+        clipeffectseditor.get_stack().set_expanded(expanded_panels)
+    else:
+        clipeffectseditor.set_filter_item_expanded(len(clip.filters) - 1)
 
 def _add_filter_multi(data):
     clip, track, item_id, item_data = data
@@ -460,16 +475,7 @@ def _re_render_transition_or_fade(data):
         
 def _mute_clip(data):
     clip, track, item_id, item_data = data
-    set_clip_muted = item_data
-
-    if set_clip_muted == True:
-        data = {"clip":clip}
-        action = edit.mute_clip(data)
-        action.do_edit()
-    else:# then we're sitting clip unmuted
-        data = {"clip":clip}
-        action = edit.unmute_clip(data)
-        action.do_edit()
+    tlineaction.do_mute_clip(clip, item_data)
 
 def _delete_clip(data):
     tlineaction.splice_out_button_pressed()
@@ -520,26 +526,8 @@ def _ripple_delete_selection(data):
 
 def _set_length(data):
     clip, track, item_id, item_data = data
-    dialogs.clip_length_change_dialog(_change_clip_length_dialog_callback, clip, track)
+    tlineaction.set_length(clip, track)
 
-def _change_clip_length_dialog_callback(dialog, response_id, clip, track, length_changer):
-    if response_id != Gtk.ResponseType.ACCEPT:
-        dialog.destroy()
-        return
-
-    length = length_changer.get_length()
-    index = track.clips.index(clip)
-    
-    dialog.destroy()
-    
-    data = {"track":track,
-            "clip":clip,
-            "index":index,
-            "length":length}
-            
-    action = edit.set_clip_length_action(data)
-    action.do_edit()
-                
 def _stretch_next(data):
     clip, track, item_id, item_data = data
     try:
@@ -1019,15 +1007,24 @@ def _do_seq_link_tline_edit(data):
     new_clip.container_data.rendered_media_range_out = -1
     new_clip.container_data.unrendered_length = new_clip.get_length() - 1
     new_clip.link_seq_data = copy.deepcopy(clip.link_seq_data)
-    
+
+    # Handle possibly changed sequence length.
+    # If new clip out not in available media area,
+    # simply use full length of new media.
+    new_clip.clip_in = clip.clip_in
+    new_clip.clip_out = clip.clip_out
+    if clip.get_length() > new_clip.get_length():
+        if clip.clip_out > new_clip.get_length() - 1:
+            new_clip.clip_in = 0
+            new_clip.clip_out =  new_clip.get_length() - 1
     clip_index = track.clips.index(clip)
-    
+
     data = {"old_clip":clip,
             "new_clip":new_clip,
             "track":track,
             "index":clip_index, 
-            "clip_in":clip.clip_in, 
-            "clip_out":clip.clip_out}
+            "clip_in":new_clip.clip_in, 
+            "clip_out":new_clip.clip_out}
     action = edit.clip_replace(data)
     action.do_edit()
     
