@@ -2,7 +2,7 @@
     Flowblade Movie Editor is a nonlinear video editor.
     Copyright 2012 Janne Liljeblad.
 
-    This file is part of Flowblade Movie Editor <http://code.google.com/p/flowblade>.
+    This file is part of Flowblade Movie Editor <https://github.com/jliljebl/flowblade/>.
 
     Flowblade Movie Editor is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -25,41 +25,33 @@ Module handles Compositors edit panel.
 import copy
 from gi.repository import Gtk
 import pickle
-import threading
-import time
 
 import appconsts
 import atomicfile
-import compositorfades
 import dialogs
 import dialogutils
 import gui
 import guicomponents
+import guipopover
 import guiutils
 import edit
 import editorlayout
 import editorstate
 from editorstate import current_sequence
 from editorstate import PROJECT
-import editorpersistance
 import keyframeeditor
+import keygtkactions
 import mlttransitions
 import propertyeditorbuilder
 import propertyedit
 import propertyparse
-import tlinerender
 import utils
 
-COMPOSITOR_PANEL_LEFT_WIDTH = 160
-
 widgets = utils.EmptyClass()
 
 compositor = None # Compositor being edited.
 
-# Edit polling.
-# We didn't put a layer of indirection to look for and launch events on edits,
-# so now we detect edits by polling. This has no performance impect, n is so small.
-_edit_polling_thread = None
+# Save menuitems handling.
 compositor_changed_since_last_save = False
 
 # This is updated when filter panel is displayed and cleared when removed.
@@ -67,18 +59,13 @@ compositor_changed_since_last_save = False
 keyframe_editor_widgets = []
 
 
-def shutdown_polling():
-    global _edit_polling_thread
-    if _edit_polling_thread != None:
-        _edit_polling_thread.shutdown()
-        _edit_polling_thread = None
-
 def create_widgets():
     """
     Widgets for editing compositing properties.
     """
     widgets.compositor_info = guicomponents.CompositorInfoPanel()
     widgets.hamburger_launcher = guicomponents.HamburgerPressLaunch(_hamburger_launch_pressed)
+    widgets.hamburger_launcher.do_popover_callback = True
     guiutils.set_margins(widgets.hamburger_launcher.widget, 4, 6, 6, 0)
 
     widgets.empty_label = Gtk.Label(label=_("No Compositor"))
@@ -88,7 +75,6 @@ def create_widgets():
     widgets.value_edit_box.pack_start(widgets.empty_label, True, True, 0)
     widgets.value_edit_frame = Gtk.Frame()
     widgets.value_edit_frame.add(widgets.value_edit_box)
-    widgets.value_edit_frame.set_shadow_type(Gtk.ShadowType.NONE)
 
 def get_compositor_clip_panel():
     create_widgets()
@@ -126,15 +112,9 @@ def set_compositor(new_compositor):
     set_enabled(True)
     _display_compositor_edit_box()
 
-    editorlayout.show_panel(appconsts.PANEL_COMPOSITORS)
+    editorlayout.show_panel(appconsts.PANEL_MULTI_EDIT)
 
-    global _edit_polling_thread
-    # Close old polling
-    if _edit_polling_thread != None:
-        _edit_polling_thread.shutdown()
-    # Start new polling
-    _edit_polling_thread = PropertyChangePollingThread()
-    _edit_polling_thread.start()
+    gui.editor_window.edit_multi.set_visible_child_name(appconsts.EDIT_MULTI_COMPOSITORS)
 
 def clear_compositor():
     global compositor
@@ -142,7 +122,7 @@ def clear_compositor():
     widgets.compositor_info.set_no_compositor_info()
     _display_compositor_edit_box()
     set_enabled(False)
-    shutdown_polling()
+    # shutdown_polling()
 
 def set_enabled(value):
     widgets.empty_label.set_sensitive(value)
@@ -185,8 +165,8 @@ def _display_compositor_edit_box():
     # Case: Empty edit frame
     global compositor
     if compositor == None:
-        filler = Gtk.EventBox()
-        filler.add(Gtk.Label())
+        filler = Gtk.Stack() 
+        filler.add_named(Gtk.Label(), "filler")
         vbox.pack_start(filler, True, True, 0)
 
         if current_sequence().compositing_mode != appconsts.COMPOSITING_MODE_STANDARD_FULL_TRACK:
@@ -197,17 +177,17 @@ def _display_compositor_edit_box():
             info.set_justify(Gtk.Justification.CENTER)
             info.set_sensitive(False)
         
-        filler = Gtk.EventBox()
-        filler.add(info)
+        filler = Gtk.Stack()
+        filler.add_named(info, "filler")
         vbox.pack_start(filler, False, False, 0)
         
-        filler = Gtk.EventBox()
-        filler.add(Gtk.Label())
+        filler = Gtk.Stack()
+        filler.add_named(Gtk.Label(), "filler")
         vbox.pack_start(filler, True, True, 0)
         vbox.show_all()
 
         scroll_window = Gtk.ScrolledWindow()
-        scroll_window.add_with_viewport(vbox)
+        scroll_window.add(vbox)
         scroll_window.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
         scroll_window.show_all()
 
@@ -222,26 +202,40 @@ def _display_compositor_edit_box():
     vbox.pack_start(guicomponents.EditorSeparator().widget, False, False, 0)
 
     # Track editor
-    if editorstate.get_compositing_mode() != appconsts.COMPOSITING_MODE_STANDARD_AUTO_FOLLOW:
-        target_combo = guicomponents.get_compositor_track_select_combo(
-                        current_sequence().tracks[compositor.transition.b_track], 
-                        current_sequence().tracks[compositor.transition.a_track], 
-                        _target_track_changed)
+    target_combo = guicomponents.get_compositor_track_select_combo(
+                    current_sequence().tracks[compositor.transition.b_track], 
+                    current_sequence().tracks[compositor.transition.a_track], 
+                    _target_track_changed)
 
-        target_row = Gtk.HBox()
-        target_row.pack_start(guiutils.get_pad_label(5, 3), False, False, 0)
-        target_row.pack_start(Gtk.Label(label=_("Destination Track:")), False, False, 0)
-        target_row.pack_start(guiutils.get_pad_label(5, 3), False, False, 0)
-        target_row.pack_start(target_combo, False, False, 0)
-        target_row.pack_start(Gtk.Label(), True, True, 0)
-        vbox.pack_start(target_row, False, False, 0)
-        vbox.pack_start(guicomponents.EditorSeparator().widget, False, False, 0)
+    target_row = Gtk.HBox()
+    target_row.pack_start(guiutils.get_pad_label(5, 3), False, False, 0)
+    target_row.pack_start(Gtk.Label(label=_("Destination Track:")), False, False, 0)
+    target_row.pack_start(guiutils.get_pad_label(5, 3), False, False, 0)
+    target_row.pack_start(target_combo, False, False, 0)
 
+    vbox.pack_start(target_row, False, False, 0)
+    vbox.pack_start(guicomponents.EditorSeparator().widget, False, False, 0)
+
+    blend_added = False # for GUI prettyness.
+    
     # Transition editors
     t_editable_properties = propertyedit.get_transition_editable_properties(compositor)
     for ep in t_editable_properties:
         editor_row = propertyeditorbuilder.get_editor_row(ep)
-            
+  
+        # Add blend mode editor in top row if exists, we decided on this later to save vertical space.
+        # Using display name is bit hacky, but should work.
+        try:
+            if ep.args["displayname"] == "Blend!Mode":
+                target_row.pack_start(guiutils.get_pad_label(8, 3), False, False, 0)
+                editor_row.remove(editor_row.get_children()[0])
+                target_row.pack_start(editor_row, True, True, 0)
+                blend_added = True
+                continue
+        except:
+            pass # Not all EditablePropty objects have "displayname" arg, move on.
+    
+        # Add editor row in panel
         if editor_row != None: # Some properties don't have editors
             vbox.pack_start(editor_row, False, False, 0)
             vbox.pack_start(guicomponents.EditorSeparator().widget, False, False, 0)
@@ -257,9 +251,14 @@ def _display_compositor_edit_box():
             or (editor_type == propertyeditorbuilder.KEYFRAME_EDITOR_CLIP)
             or (editor_type == propertyeditorbuilder.KEYFRAME_EDITOR_CLIP_FADE)
             or (editor_type == propertyeditorbuilder.FADE_LENGTH)
-            or (editor_type == propertyeditorbuilder.GEOMETRY_EDITOR)):
+            or (editor_type == propertyeditorbuilder.GEOMETRY_EDITOR)
+            or (editor_type == propertyeditorbuilder.ROTATION_GEOMETRY_EDITOR_BUILDER)):
                 keyframe_editor_widgets.append(editor_row)
-    
+                keygtkactions.connect_compositor_widget(editor_row)
+    # Add pad label after possibly adding blend mode editor.
+    if blend_added == False:
+        target_row.pack_start(Gtk.Label(), True, True, 0)
+            
     # Extra editors. Editable properties have already been created with "editor=no_editor"
     # and will be looked up by editors from clip
     editor_rows = propertyeditorbuilder.get_transition_extra_editor_rows(compositor, t_editable_properties)
@@ -268,6 +267,7 @@ def _display_compositor_edit_box():
         # because one editor sets values for multiple EditableProperty objects
         if editor_row.__class__ == keyframeeditor.RotatingGeometryEditor:
             keyframe_editor_widgets.append(editor_row)
+            keygtkactions.connect_compositor_widget(editor_row)
         vbox.pack_start(editor_row, False, False, 0)
         vbox.pack_start(guicomponents.EditorSeparator().widget, False, False, 0)
 
@@ -275,7 +275,7 @@ def _display_compositor_edit_box():
     vbox.show_all()
 
     scroll_window = Gtk.ScrolledWindow()
-    scroll_window.add_with_viewport(vbox)
+    scroll_window.add(vbox)
     scroll_window.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
     scroll_window.show_all()
 
@@ -305,7 +305,7 @@ def update_kfeditors_positions():
 
 
 def _compositor_uses_fade_buttons(compositor):
-    # we hard coded compositors using fade buttons here because adding data in compostors.xml may have had some backwards compatiblity issues.
+    # we hard coded compositors using fade buttons here because adding data in compostors.xml may have had some backwards compatibility issues.
     if compositor.transition.info.name  == "##opacity":
         return True
     elif compositor.transition.info.name  == "##pict_in_pict":
@@ -324,10 +324,10 @@ def _compositor_uses_fade_buttons(compositor):
         
     return False
 # ----------------------------------------------------------- hamburger menu
-def _hamburger_launch_pressed(widget, event):
-    guicomponents.get_compositor_editor_hamburger_menu(event, _compositor_hamburger_item_activated)
+def _hamburger_launch_pressed(launcher, widget, event, data):
+    guipopover.compositor_editor_hamburger_menu_show(launcher, widget, _compositor_hamburger_item_activated)
 
-def _compositor_hamburger_item_activated(widget, msg):
+def _compositor_hamburger_item_activated(action, variant, msg):
     if msg == "save":
         comp_name = mlttransitions.name_for_type[compositor.transition.info.name]
         default_name = comp_name.replace(" ", "_") + _("_compositor_values") + ".data"
@@ -362,7 +362,7 @@ def _load_compositor_values_dialog_callback(dialog, response_id):
         else:
             saved_name_comp_name = mlttransitions.name_for_type[compositor_data.info.name]
             current_comp_name = mlttransitions.name_for_type[compositor.transition.info.name]
-            primary_txt = _("Saved Compositor data not applicaple for this compositor!")
+            primary_txt = _("Saved Compositor data not applicable for this compositor!")
             secondary_txt = _("Saved data is for ") + saved_name_comp_name + " compositor,\n" + _(", current compositor is ") + current_comp_name + "."
             dialogutils.warning_message(primary_txt, secondary_txt, gui.editor_window.window)
 
@@ -375,51 +375,6 @@ def _set_fade_length_dialog_callback(dialog, response_id, spin):
         
     dialog.destroy()
 
-class PropertyChangePollingThread(threading.Thread):
-    
-    def __init__(self):
-        threading.Thread.__init__(self)
-        self.last_properties = None
-        
-    def run(self):
-        self.running = True
-        while self.running:
-            global compositor
-            if compositor == None:
-                self.shutdown()
-            else:
-                if self.last_properties == None:
-                    self.last_properties = self.get_compositor_properties()
-                
-                new_properties = self.get_compositor_properties()
-                
-                changed = False
-                for new_prop, old_prop in zip(new_properties, self.last_properties):
-                    if new_prop != old_prop:
-                        changed = True
-
-                if changed:
-                    global compositor_changed_since_last_save
-                    compositor_changed_since_last_save = True
-                    tlinerender.get_renderer().timeline_changed()
-
-                self.last_properties = new_properties
-                
-                time.sleep(1.0)
-                
-    def get_compositor_properties(self):
-        compositor_properties = []
-
-        for prop in compositor.transition.properties:
-            compositor_properties.append(copy.deepcopy(prop))
-    
-        compositor_properties.append((copy.deepcopy(compositor.clip_in ), copy.deepcopy(compositor.clip_out)))
-        
-        return compositor_properties
-        
-    def shutdown(self):
-        self.running = False
-        
 
 class CompositorValuesSaveData:
     
