@@ -598,7 +598,7 @@ def about_dialog(parent_window):
     # Application tab
     img = Gtk.Image.new_from_file(respaths.IMAGE_PATH + "flowbladeappicon.png")
     flow_label = Gtk.Label(label="Flowblade Movie Editor")
-    ver_label = Gtk.Label(label="2.22.1")
+    ver_label = Gtk.Label(label="2.24")
     janne_label = Gtk.Label(label="Copyright 2025 Janne Liljeblad and contributors.")
     page_label = Gtk.Label(label=_("Project page:") + " " + "<a href=\"https://github.com/jliljebl/flowblade\">https://github.com/jliljebl/flowblade</a>")
     page_label.set_use_markup(True)
@@ -624,11 +624,8 @@ def about_dialog(parent_window):
     up_label = Gtk.Label(label=_("Upstream:"))
     up_projs = Gtk.Label(label="MLT")
     up_projs2 = Gtk.Label(label="FFMpeg, Frei0r, LADSPA, Cairo, Gnome, Linux")
-    tools_label = Gtk.Label(label=_("Tools:"))
-    tools_list = Gtk.Label(label="Geany, Inkscape, Gimp, ack-grep")
 
     up_label.modify_font(Pango.FontDescription("sans bold 12"))
-    tools_label.modify_font(Pango.FontDescription("sans bold 12"))
 
     vbox2 = Gtk.VBox(False, 4)
     vbox2.pack_start(guiutils.get_pad_label(30, 12), False, False, 0)
@@ -636,9 +633,6 @@ def about_dialog(parent_window):
     vbox2.pack_start(up_projs, False, False, 0)
     vbox2.pack_start(up_projs2, False, False, 0)
     vbox2.pack_start(guiutils.get_pad_label(30, 22), False, False, 0)
-    vbox2.pack_start(tools_label, False, False, 0)
-    vbox2.pack_start(tools_list, False, False, 0)
-    vbox2.pack_start(guiutils.get_pad_label(30, 22), False, False, 0)
     vbox2.pack_start(Gtk.Label(), True, True, 0)
 
     alignment2 = dialogutils.get_default_alignment(vbox2)
@@ -1808,7 +1802,7 @@ def confirm_compositing_mode_change(callback, new_compositing_mode):
                         (_("Cancel"), Gtk.ResponseType.REJECT,
                         _("Change Compositing Mode"), Gtk.ResponseType.ACCEPT))
     
-    primary_txt = _("Changing Compositing Mode destroys current Compositors and undo stack")
+    primary_txt = _("Changing Compositing Mode destroys current Compositors and undo stack!")
     secondary_txt = _("This operation cannot be undone. Are you sure you wish to proceed?")
     warning_panel = dialogutils.get_warning_message_dialog_panel(primary_txt, secondary_txt, is_info=False, alternative_icon=None, panels=None)
 
@@ -1971,8 +1965,32 @@ def select_link_sequence_for_container(callback):
 
     dialogutils.panel_ok_cancel_dialog(title, panel, accept_text, callback, (sequences_combo, selection_data))
     
-
 def show_cyclic_error():
     primary_txt = _("Cyclic relation detected!")
     secondary_txt = _("Edit would create a cyclink linked sequence relation and was cancelled!")
     dialogutils.warning_message(primary_txt, secondary_txt, gui.editor_window.window)
+
+def get_duplicate_sequence_dialog():
+    dialog = Gtk.Window(Gtk.WindowType.TOPLEVEL)
+    dialog.set_title(_("Duplicating Sequence"))
+
+    progress_bar = Gtk.ProgressBar()
+    progress_bar.set_fraction(0.2)
+    progress_bar.set_pulse_step(0.1)
+    progress_bar.set_margin_bottom(24)
+    progress_bar.set_margin_top(24)
+    
+    progress_vbox = Gtk.VBox(False, 2)
+    progress_vbox.pack_start(progress_bar, False, False, 0)
+
+    alignment = guiutils.set_margins(progress_vbox, 12, 12, 12, 12)
+
+    dialog.add(alignment)
+    dialog.set_default_size(500, 70)
+    dialog.set_position(Gtk.WindowPosition.CENTER)
+    dialog.show_all()
+
+    pulse_runner = guiutils.PulseEvent(progress_bar)
+    dialog.pulse_runner = pulse_runner
+        
+    return dialog
