@@ -95,17 +95,13 @@ def do_clip_insert(track, new_clip, tline_pos, use_clip_in=False):
             "clip_in":clip_in,
             "clip_out":clip_out}
     action = edit.insert_action(data)
-    action.do_edit()
+    _do_action_and_maybe_autosplit_action(action, new_clip, track)
     
     updater.display_tline_cut_frame(track, index)
 
 def do_multiple_clip_insert(track, clips, tline_pos, use_as_action_build_func_for_paste=False):
     index = _get_insert_index(track, tline_pos)
     
-    if use_as_action_build_func_for_paste == True:
-        # For this use case there happens a cut before the insert is done.
-        index += 1
-    
     # Can't put audio media on video track
     for new_clip in clips:
         if isinstance(new_clip, int):
@@ -137,6 +133,7 @@ def  _attempt_dnd_overwrite(track, clip, frame):
     # Dropping on first available frame after last clip is append 
     # and is handled by insert code
     if track.get_length() == frame:
+        print("insert")
         return False
 
     # Clip dropped after last clip on track
@@ -152,7 +149,8 @@ def  _attempt_dnd_overwrite(track, clip, frame):
                 "clip_in":clip.mark_in,
                 "clip_out":clip.mark_out}
         action = edit.dnd_after_track_end_action(data)
-        action.do_edit()
+        _do_action_and_maybe_autosplit_action(action, clip, track)
+
 
         updater.display_tline_cut_frame(track, index + 1)
         return True
@@ -181,7 +179,7 @@ def  _attempt_dnd_overwrite(track, clip, frame):
                         "index":index,
                         "clip_in":clip.mark_in}
                 action = edit.dnd_on_blank_replace_action(data)
-                action.do_edit()
+                _do_action_and_maybe_autosplit_action(action, clip, track)
             else: # If dropped clip shorter then blank, replace start part of blank
                 data = {"track":track,
                         "clip":clip,
@@ -190,7 +188,7 @@ def  _attempt_dnd_overwrite(track, clip, frame):
                         "clip_in":clip.mark_in,
                         "clip_out":clip.mark_out}
                 action = edit.dnd_on_blank_start_action(data)
-                action.do_edit()
+                _do_action_and_maybe_autosplit_action(action, clip, track)
 
             updater.display_tline_cut_frame(track, index)
             return True
@@ -206,7 +204,7 @@ def  _attempt_dnd_overwrite(track, clip, frame):
                     "clip_in":clip.mark_in,
                     "clip_out":clip.mark_out}
             action = edit.dnd_on_blank_end_action(data)
-            action.do_edit()
+            _do_action_and_maybe_autosplit_action(action, clip, track)
         else: # Overwrite part of blank ei toimi
             data = {"track":track,
                     "clip":clip,
@@ -216,13 +214,32 @@ def  _attempt_dnd_overwrite(track, clip, frame):
                     "clip_in":clip.mark_in,
                     "clip_out":clip.mark_out}
             action = edit.dnd_on_blank_middle_action(data)
-            action.do_edit()
+            _do_action_and_maybe_autosplit_action(action, clip, track)
             
         updater.display_tline_cut_frame(track, index + 1)
         return True
 
     return False # this won't be hit
+
+def _do_action_and_maybe_autosplit_action(action, clip, track):
     
+    if editorpersistance.prefs.sync_autosplit == appconsts.AUDIO_AUTO_SPLIT_ALL_TACKS:
+        auto_split = True
+    elif editorpersistance.prefs.sync_autosplit == appconsts.AUDIO_AUTO_SPLIT_V1_V2 and (track.id == current_sequence().first_video_index or track.id == current_sequence().first_video_index + 1):
+        auto_split = True
+    elif editorpersistance.prefs.sync_autosplit == appconsts.AUDIO_AUTO_SPLIT_V1 and track.id == current_sequence().first_video_index:
+        auto_split = True
+    else:
+        auto_split = False
+    
+    if track.type == appconsts.AUDIO or auto_split == False:
+        action.do_edit()
+    else:
+        split_action = lambda : syncsplitevent.get_synched_split_action_for_clip_and_track(clip, track)
+        edit_actions = [action, split_action]
+        action = edit.ConsolidatedEditAction(edit_actions)
+        action.do_consolidated_edit()
+
 def _get_insert_index(track, tline_pos):
     cut_frame = current_sequence().get_closest_cut_frame(track.id, tline_pos)
     index = current_sequence().get_clip_index(track, cut_frame)
@@ -352,27 +369,6 @@ def tline_canvas_mouse_pressed(event, frame):
             trimmodes.set_no_edit_trim_mode()
             PLAYER().seek_frame(frame)
         return
-    # LEFT BUTTON: Select new trimmed clip in active one roll trim mode	with sensitive cursor.
-    elif (event.button == 1 and EDIT_MODE() == editorstate.ONE_ROLL_TRIM):	
-        track = tlinewidgets.get_track(event.y)	
-        if track == None:	
-            modesetting.set_default_edit_mode(True)	
-            return	
-        success = trimmodes.set_oneroll_mode(track, frame)	
-        if not success:
-            modesetting.set_default_edit_mode(True)	
-            return	
-
-        if trimmodes.edit_data["to_side_being_edited"] == True:	
-            pointer_context = appconsts.POINTER_CONTEXT_TRIM_LEFT	
-        else:	
-            pointer_context = appconsts.POINTER_CONTEXT_TRIM_RIGHT	
-        gui.editor_window.tline_cursor_manager.set_tline_cursor_to_context(pointer_context)	
-        gui.editor_window.tline_cursor_manager.set_tool_selector_to_mode()	
-        if not editorpersistance.prefs.quick_enter_trims:	
-            editorstate.timeline_mouse_disabled = True	
-        else:	
-            trimmodes.oneroll_trim_move(event.x, event.y, frame, None)
     elif event.button == 2:
         updater.zoom_project_length()
     # LEFT BUTTON: Handle left mouse button edits by passing event to current edit mode
@@ -485,7 +481,12 @@ def tline_effect_drop(x, y):
     selected_track_before = movemodes.selected_track
     selected_in_before = movemodes.selected_range_in
     selected_out_before = movemodes.selected_range_out
-    
+
+    if clipeffectseditor.get_stack() != None and clip == clipeffectseditor.get_stack().clip:
+        expanded_panels = clipeffectseditor.get_stack().get_expanded()
+    else:
+        expanded_panels = None
+        
     # Effect dropped on selected range, add to all in range.
     if selected_in_before != -1 and selected_track_before == track.id and ((selected_in_before <= index) and (selected_out_before >= index)):
         actions = []
@@ -512,7 +513,12 @@ def tline_effect_drop(x, y):
         action.do_edit()
 
     clipeffectseditor.set_clip(clip, track, index)
-    clipeffectseditor.set_filter_item_expanded(len(clip.filters) - 1)
+
+    if expanded_panels != None:
+        expanded_panels.append(True)
+        clipeffectseditor.get_stack().set_expanded(expanded_panels)
+    else:
+        clipeffectseditor.set_filter_item_expanded(len(clip.filters) - 1)
     
 def tline_media_drop(drag_data, x, y, use_marks=False):
     # drag_data not used unless we which later to enable dropping multiple media items.
@@ -559,6 +565,7 @@ def tline_media_drop(drag_data, x, y, use_marks=False):
             new_clip = current_sequence().create_file_producer_clip(media_file.path, media_file.name, False, media_file.ttl)
             new_clip.container_data = copy.deepcopy(media_file.container_data)
             new_clip.container_data.generate_clip_id()
+            new_clip.link_seq_data = media_file.link_seq_data
     else:
         new_clip = current_sequence().create_pattern_producer(media_file)
 
@@ -602,9 +609,9 @@ def tline_media_drop(drag_data, x, y, use_marks=False):
                 if media_file.type == appconsts.IMAGE_SEQUENCE:
                     new_clip.mark_out = media_file.length
 
-    # Images fom media panel get bin default length.
+    # Images from media panel get bin default length.
     use_clip_in = False
-    if dnd.drag_source != dnd.SOURCE_MONITOR_WIDGET and  new_clip.media_type == appconsts.IMAGE:
+    if dnd.drag_source != dnd.SOURCE_MONITOR_WIDGET and new_clip.media_type == appconsts.IMAGE:
         default_grfx_length = PROJECT().get_current_bin_graphics_default_length()
         in_fr = (new_clip.get_length() - 1) // 2 - (default_grfx_length // 2)
         out_fr = in_fr + default_grfx_length - 1
@@ -651,7 +658,6 @@ def maybe_autorender_plugin(clip):
     if clip.container_data == None:
         return
 
-    print("---------------renderdata:", clip.container_data.render_data)
     if editorpersistance.prefs.auto_render_media_plugins == True:
         if clip.container_data.container_type == appconsts.CONTAINER_CLIP_FLUXITY:
             action_object = containeractions.get_action_object(clip.container_data)
@@ -674,24 +680,15 @@ OVERWRITE_MOVE_FUNCS = [movemodes.overwrite_move_press,
 ONE_ROLL_TRIM_FUNCS = [trimmodes.oneroll_trim_press, 
                        trimmodes.oneroll_trim_move,
                        trimmodes.oneroll_trim_release]
-ONE_ROLL_TRIM_NO_EDIT_FUNCS = [modesetting.oneroll_trim_no_edit_press, 
-                               modesetting.oneroll_trim_no_edit_move,
-                               modesetting.oneroll_trim_no_edit_release]
 TWO_ROLL_TRIM_FUNCS = [trimmodes.tworoll_trim_press,
                        trimmodes.tworoll_trim_move,
                        trimmodes.tworoll_trim_release]
-TWO_ROLL_TRIM_NO_EDIT_FUNCS = [modesetting.tworoll_trim_no_edit_press,
-                               modesetting.tworoll_trim_no_edit_move,
-                               modesetting.tworoll_trim_no_edit_release]
 COMPOSITOR_EDIT_FUNCS = [compositormodes.mouse_press,
                          compositormodes.mouse_move,
                          compositormodes.mouse_release]
 SLIDE_TRIM_FUNCS = [trimmodes.slide_trim_press,
                     trimmodes.slide_trim_move,
                     trimmodes.slide_trim_release]
-SLIDE_TRIM_NO_EDIT_FUNCS = [modesetting.slide_trim_no_edit_press,
-                            modesetting.slide_trim_no_edit_move,
-                            modesetting.slide_trim_no_edit_release]
 MULTI_MOVE_FUNCS = [multimovemode.mouse_press,
                     multimovemode.mouse_move,
                     multimovemode.mouse_release]
@@ -715,10 +712,7 @@ EDIT_MODE_FUNCS = {editorstate.INSERT_MOVE:INSERT_MOVE_FUNCS,
                    editorstate.ONE_ROLL_TRIM:ONE_ROLL_TRIM_FUNCS,
                    editorstate.TWO_ROLL_TRIM:TWO_ROLL_TRIM_FUNCS,
                    editorstate.COMPOSITOR_EDIT:COMPOSITOR_EDIT_FUNCS,
-                   editorstate.ONE_ROLL_TRIM_NO_EDIT:ONE_ROLL_TRIM_NO_EDIT_FUNCS,
-                   editorstate.TWO_ROLL_TRIM_NO_EDIT:TWO_ROLL_TRIM_NO_EDIT_FUNCS,
                    editorstate.SLIDE_TRIM:SLIDE_TRIM_FUNCS,
-                   editorstate.SLIDE_TRIM_NO_EDIT:SLIDE_TRIM_NO_EDIT_FUNCS,
                    editorstate.MULTI_MOVE:MULTI_MOVE_FUNCS,
                    editorstate.CLIP_END_DRAG:CLIP_END_DRAG_FUNCS,
                    editorstate.CUT:CUT_FUNCS,
