@@ -190,11 +190,11 @@ def update_prefs_from_widgets(widgets_tuples_tuple):
     gfx_length_spin, cover_delete, mouse_scroll_action, hide_file_ext_button, \
     hor_scroll_dir, effects_editor_clip_load, auto_render_plugins, dnd_action = edit_prefs_widgets
 
-    auto_center_check, play_pause_button, timeline_start_end_button, auto_center_on_updown, \
+    auto_center_check, auto_center_on_updown, \
     ffwd_rev_shift_spin, ffwd_rev_caps_spin, follow_move_range, loop_clips = playback_prefs_widgets
     
-    force_language_combo, disp_splash, window_mode_combo, full_names, tracks_combo, project_panel_width_spin, \
-    edit_panel_width_spin, media_panel_width_spin, layout_monitor, filter_select_width_spin = view_prefs_widgets
+    force_language_combo, window_mode_combo, full_names, tracks_combo, project_panel_width_spin, \
+    edit_panel_width_spin, media_panel_width_spin, layout_monitor, filter_select_width_spin, show_bins_and_seqs_titles = view_prefs_widgets
 
     perf_render_threads, perf_drop_frames = performance_widgets
 
@@ -211,8 +211,6 @@ def update_prefs_from_widgets(widgets_tuples_tuple):
     prefs.default_grfx_length = int(gfx_length_spin.get_adjustment().get_value())
     prefs.trans_cover_delete = cover_delete.get_active()
 
-    prefs.play_pause = play_pause_button.get_active()
-    prefs.timeline_start_end = timeline_start_end_button.get_active()
     prefs.hide_file_ext = hide_file_ext_button.get_active()
     prefs.mouse_scroll_action_is_zoom = (mouse_scroll_action.get_active() == 0)
     prefs.scroll_horizontal_dir_up_forward = (hor_scroll_dir.get_active() == 0)
@@ -223,12 +221,12 @@ def update_prefs_from_widgets(widgets_tuples_tuple):
 
     prefs.use_english_always = False # DEPRECATED, "force_language" used instead
     prefs.force_language = force_language_combo.lang_codes[force_language_combo.get_active()]
-    prefs.display_splash_screen = disp_splash.get_active()
 
     prefs.global_layout = window_mode_combo.get_active() + 1 # +1 'cause values are 1 and 2
     prefs.perf_render_threads = int(perf_render_threads.get_adjustment().get_value())
     prefs.perf_drop_frames = perf_drop_frames.get_active()
     prefs.show_full_file_names = full_names.get_active()
+    prefs.show_bins_and_sequences_titles = show_bins_and_seqs_titles.get_active()
     prefs.center_on_arrow_move = auto_center_on_updown.get_active()
     prefs.tracks_scale = tracks_combo.get_active()
     prefs.playback_follow_move_tline_range = follow_move_range.get_active()
@@ -283,7 +281,7 @@ class EditorPreferences:
         self.auto_center_on_play_stop = True
         self.thumbnail_folder = None # DEPRECATED, this is set by XDG variables now.
         self.hidden_profile_names = []
-        self.display_splash_screen = True
+        self.display_splash_screen = True # DEPRECATED
         self.auto_move_after_edit = False # DEPRECATED
         self.default_grfx_length = 250 # value is in frames
         self.track_configuration = 0 # DEPRECATED
@@ -314,12 +312,9 @@ class EditorPreferences:
         self.display_all_audio_levels = True
         self.overwrite_clip_drop = True # DEPRECATED, "dnd_action" used instead.
         self.trans_cover_delete = True
-        # Jul-2016 - SvdB - For play/pause button
-        self.play_pause = False
-        # ------------------------------ timeline_start_end_button
-        self.timeline_start_end = False
-        # ------------------------------End of timeline_start_end_button.
-        self.midbar_layout = appconsts.MIDBAR_TC_LEFT
+        self.play_pause = False  # DEPRECATED
+        self.timeline_start_end = False  # DEPRECATED
+        self.midbar_layout = 0 # DEPRECATED, TC widget no longer in middlebar.
         self.global_layout = appconsts.SINGLE_WINDOW
         self.trim_view_default = appconsts.TRIM_VIEW_OFF
         self.trim_view_message_shown = False
@@ -383,7 +378,7 @@ class EditorPreferences:
         self.zoom_to_playhead = True
         self.filter_select_width = 220
         self.tracks_scale = appconsts.TRACKS_SCALE_DEFAULT
-        self.icons_scale = appconsts.ICONS_SCALE_DEFAULT  # DEPRECATED, we are not ever getting useful results with this.
+        self.icons_scale = appconsts.ICONS_SCALE_DEFAULT # DEPRECATED, we are not ever getting useful results with this.
         self.project_panel_width = PROJECT_PANEL_WIDTH_MIN
         self.editor_panel_width = EDIT_PANEL_WIDTH_MIN 
         self.media_panel_width = MEDIA_PANEL_WIDTH_MIN
@@ -393,3 +388,8 @@ class EditorPreferences:
         self.show_sync = True
         self.wide_multitrim_slip = False
         self.disable_drag_when_selected = True
+        self.show_waveform_in_monitor = True
+        self.auto_sync_single_childs_on_trim = True
+        self.audio_master_position_is_top_row = True
+        self.close_titler_on_save = False
+        self.show_bins_and_sequences_titles = True
\ No newline at end of file
