@@ -34,6 +34,7 @@ import clipeffectseditor
 import clipmenuaction
 import compositeeditor
 import containerclip
+import copypaste
 import dialogs
 import dialogutils
 import dnd
@@ -55,6 +56,7 @@ import medialog
 import mediaplugin
 import menuactions
 import middlebar
+import mltplayer
 import modesetting
 import monitorevent
 import monitorwidget
@@ -92,20 +94,6 @@ MONITOR_AREA_WIDTH = appconsts.MONITOR_AREA_WIDTH
 DARK_BG_COLOR = (0.223, 0.247, 0.247, 1.0)
 
 
-def _b(button, icon, remove_relief=False):
-    button.set_image(icon)
-    button.set_property("can-focus",  False)
-    if remove_relief:
-        button.set_relief(Gtk.ReliefStyle.NONE)
-
-def _toggle_image_switch(widget, icons):
-    not_pressed, pressed = icons
-    if widget.get_active() == True:
-        widget.set_image(pressed)
-    else:
-        widget.set_image(not_pressed)
-
-
 class EditorWindow:
 
     def __init__(self):
@@ -115,7 +103,7 @@ class EditorWindow:
         # Create window(s)
         self.window = Gtk.Window(type=Gtk.WindowType.TOPLEVEL)
         self.window.set_icon_from_file(respaths.IMAGE_PATH + "flowbladeappicon.png")
-        self.window.set_border_width(5)
+        self.window.set_border_width(0)
 
         self.window2 = None
         if editorpersistance.prefs.global_layout != appconsts.SINGLE_WINDOW:
@@ -128,7 +116,10 @@ class EditorWindow:
         self.window.connect("delete-event", lambda w, e:callbackbridge.app_shutdown())
 
         # Player consumer has to be stopped and started when window resized
-        self.window.connect("window-state-event", lambda w, e:updater.refresh_player(e))
+        if mltplayer.get_sdl_consumer_version() == mltplayer.SDL_1: # Delete when everyone is on mlt 7.30 or moving to Gtk4.
+            self.window.connect("window-state-event", lambda w, e:updater.refresh_player(e))
+
+        self.audio_master_meter = None
 
         # Init application main menu.
         self.ui = Gtk.UIManager()
@@ -136,7 +127,7 @@ class EditorWindow:
 
         # Create all panels and gui components.
         self._init_gui_components()
-        
+
         # Create timeline comnponents and panels.
         self._init_tline()
 
@@ -213,7 +204,8 @@ class EditorWindow:
         self.app_h_box = Gtk.HBox(False, 0)
         self.app_h_box.pack_start(self.left_column_frame, False, False, 0)
         self.app_h_box.pack_start(self.app_v_paned, True, True, 0)
-
+        self.app_h_box.pack_start(self.right_column_frame, False, False, 0)
+        
         # Menu box
         self.menubar.set_margin_bottom(4)
         self.menubar.set_name("lighter-bg-widget")
@@ -225,54 +217,17 @@ class EditorWindow:
         else:
             menubar_box.pack_start(self.menubar, False, False, 0)
 
-        monitor_source_box = Gtk.HBox(False, 0)
-        monitor_source_box.pack_start(Gtk.Label(), True, True, 0)
-        monitor_source_box.pack_start(self.monitor_tc_info.monitor_source, False, False, 0)
-        monitor_source_box.pack_start(self.monitor_tc_info.monitor_tc, False, False, 0)
+        project_info_box = Gtk.HBox(False, 0)
+        project_info_box.pack_start(Gtk.Label(), True, True, 0)
         monitor_desc_panel = projectinfogui.get_top_level_project_info_panel()
         self.monitor_desc_label = projectinfogui.widgets.monitor_desc_label
-        monitor_source_box.pack_start(monitor_desc_panel, False, False, 0)
-        monitor_source_box.pack_start(Gtk.Label(), True, True, 0)
+        project_info_box.pack_start(monitor_desc_panel, False, False, 0)
+        project_info_box.pack_start(Gtk.Label(), True, True, 0)
 
-        fullscreen_icon = guiutils.get_cairo_image("fullscreen")
-        fullscreen_exit_icon = guiutils.get_cairo_image("fullscreen_exit")
-        if guiutils.double_icon_size() == False:
-            self.fullscreen_press = guicomponents.PressLaunch(menuactions.toggle_fullscreen, fullscreen_icon, 20, 12)
-        else:
-            self.fullscreen_press = guicomponents.PressLaunch(menuactions.toggle_fullscreen, fullscreen_icon, 40, 24)
-            self.fullscreen_press.surface_x = 12
-            self.fullscreen_press.surface_y = 13
+        layout_widgets = [self.tools_buttons.widget, guiutils.pad_label(24,2), self.fullscreen_press.widget, guiutils.pad_label(6,2), self.layout_press.widget]
+        layout_controls_box = guiutils.get_right_justified_box(layout_widgets)
+        layout_controls_box.set_margin_right(6)
 
-        self.fullscreen_press.widget.set_margin_top(1)
-        self.fullscreen_press.widget.set_tooltip_text(_("Fullscreen - F11"))
-        # Used in menuactions.toggle_fullscreen to switch image
-        self.fullscreen_press.fullscreen_icon = fullscreen_icon
-        self.fullscreen_press.fullscreen_exit_icon = fullscreen_exit_icon
-
-        icon_2 = guiutils.get_cairo_image("layout")
-        if guiutils.double_icon_size() == False:
-            layout_press = guicomponents.PressLaunchPopover(editorlayout.show_layout_press_menu, icon_2, 24, 12)
-        else:
-            layout_press = guicomponents.PressLaunchPopover(editorlayout.show_layout_press_menu, icon_2, 48, 24)
-            layout_press.surface_y = 13
-            
-        layout_press.widget.set_margin_top(1)
-        layout_press.widget.set_tooltip_text(_("Layouts"))
-        
-        tline_info_box = Gtk.HBox(False, 0)
-        if editorpersistance.prefs.global_layout == appconsts.SINGLE_WINDOW:
-            tline_info_box.pack_start(self.tools_buttons.widget, False, False, 0)
-            tline_info_box.pack_start(guiutils.pad_label(24,2), False, False, 0)
-            tline_info_box.pack_start(self.fullscreen_press.widget, False, False, 0)
-            if editorstate.SCREEN_WIDTH > 1678:
-                tline_info_box.pack_start(guiutils.pad_label(6,2), False, False, 0)
-                tline_info_box.pack_start(layout_press.widget, False, False, 0)
-                tline_info_box.pack_start(guiutils.pad_label(6,2), False, False, 0)
-            
-        tline_info_box.pack_start(Gtk.Label(), True, True, 0)
-        tline_info_box.pack_start(self.monitor_tc_info.widget, False, False, 0)
-        guiutils.set_margins(tline_info_box, 0, 0, 0, 10)
-        
         if editorstate.SCREEN_WIDTH > 1550:
             menu_vbox = Gtk.HBox(True, 0)
         else:
@@ -282,24 +237,17 @@ class EditorWindow:
 
         if editorpersistance.prefs.global_layout == appconsts.SINGLE_WINDOW:
             if editorstate.screen_size_small_width() == False:
-                menu_vbox.pack_start(monitor_source_box, True, True, 0)
+                menu_vbox.pack_start(project_info_box, True, True, 0)
             else:
                 menu_vbox.pack_start(guiutils.pad_label(24, 2), False, False, 0)
-                menu_vbox.pack_start(monitor_source_box, False, False, 0)
+                menu_vbox.pack_start(project_info_box, False, False, 0)
                 menu_vbox.pack_start(guiutils.pad_label(40, 2), False, False, 0)
-            menu_vbox.pack_start(tline_info_box, True, True, 0)
-            menu_vbox.override_background_color(Gtk.StateFlags.NORMAL, gui.get_mid_neutral_color())
+            menu_vbox.pack_start(layout_controls_box, True, True, 0)
         else:
-            menubar_box.pack_start(self.tools_buttons.widget, False, False, 0)
-            menubar_box.pack_start(guiutils.pad_label(8, 2), False, False, 0)
-            menubar_box.pack_start(self.fullscreen_press.widget, False, False, 0)
-            
-            self.top_row_window_2 = Gtk.HBox(False, 0)
-            self.top_row_window_2.pack_start(monitor_source_box, False, False, 0)
-            self.top_row_window_2.pack_start(Gtk.Label(), True, True, 0)
-            self.top_row_window_2.pack_start(tline_info_box, False, False, 0)
-            monitor_source_box.set_margin_bottom(4)
-            tline_info_box.set_margin_bottom(9)
+            menu_vbox.pack_start(project_info_box, True, True, 0)
+            menu_vbox.pack_start(layout_controls_box, True, True, 0)
+            tline_info_box = self._get_monitor_info_box()
+            self.top_row_window_2 = tline_info_box #Gtk.HBox(False, 0)
             
         # Pane
         pane = Gtk.VBox(False, 1)
@@ -316,7 +264,8 @@ class EditorWindow:
         self.bin_list_view = guicomponents.BinTreeView(
                                         projectaction.bin_selection_changed,
                                         projectaction.bin_name_edited,
-                                        projectaction.bins_panel_popup_requested)
+                                        projectaction.bins_panel_popup_requested,
+                                        projectaction.media_panel_to_front)
         dnd.connect_bin_tree_view(self.bin_list_view.treeview, projectaction.move_files_to_bin)
         self.bin_list_view.set_property("can-focus",  True)
 
@@ -362,22 +311,20 @@ class EditorWindow:
         # Effects edit panel
         info_row = clipeffectseditor.get_clip_effects_editor_info_row()    
         effects_editor_panel = guiutils.set_margins(clipeffectseditor.widgets.value_edit_frame, 4, 0, 4, 0)
-
         effects_vbox = Gtk.VBox()
         effects_vbox.pack_start(effects_editor_panel, True, True, 0)
         effects_vbox.pack_start(info_row, False, False, 0)
 
+
         if not(editorstate.SCREEN_HEIGHT < 1023):
             self.effects_panel = guiutils.set_margins(effects_vbox, 8, 0, 7, 2)
         else:
             self.effects_panel = effects_vbox
 
+        gui.apply_widget_css_class(self.effects_panel, "dark-bg", "dark-bg-class.css")
+
         # Effects select panel
-        effect_select_panel, effect_select_list_view, effect_select_combo_box  = panels.get_effect_selection_panel(clipeffectseditor.effect_select_row_double_clicked)
-        # example code for using widget css from deleted test dev branch
-        #gui.apply_widget_css_class(effect_select_list_view.treeview, "bold-text", "bold-text-class.css")
-        #effect_select_list_view.treeview.set_name("light-text")
-        #gui.apply_widget_css(effect_select_list_view.treeview, "light-text", "light-text-id.css")
+        effect_select_panel, effect_select_list_view, effect_select_combo_box = panels.get_effect_selection_panel(clipeffectseditor.effect_select_row_double_clicked)
         self.effect_select_panel = effect_select_panel
         self.effect_select_list_view = effect_select_list_view
         self.effect_select_combo_box = effect_select_combo_box
@@ -414,11 +361,12 @@ class EditorWindow:
         # Multi empty panel
         multi_empty_vbox = Gtk.VBox(False, 0)
         multi_empty_vbox.pack_start(Gtk.Label(), True, True, 0)
-        no_target = Gtk.Label(label=_("No Edit Target."))
+        no_target = Gtk.Label(label=_("No Edit Target."))         
         no_target.set_sensitive(False)
         multi_empty_vbox.pack_start(no_target, False, False, 0)
         multi_empty_vbox.pack_start(Gtk.Label(), True, True, 0)
-    
+        gui.apply_widget_css_class(multi_empty_vbox, "dark-bg", "dark-bg-class.css")
+        
         # Multi edit panel
         self.edit_multi = guicomponents.EditMultiStack()
         self.edit_multi.add_named(multi_empty_vbox, appconsts.EDIT_MULTI_EMPTY)
@@ -426,7 +374,7 @@ class EditorWindow:
         self.edit_multi.add_named(compositors_panel, appconsts.EDIT_MULTI_COMPOSITORS)
         self.edit_multi.add_named(mediaplugins_panel, appconsts.EDIT_MULTI_PLUGINS)
         self.edit_multi.set_visible_child_name(appconsts.EDIT_MULTI_EMPTY)
-        
+        gui.apply_widget_css_class(self.edit_multi.widget, "dark-bg", "dark-bg-class.css")
         # Render panel
         try:
             render.create_widgets()
@@ -486,13 +434,11 @@ class EditorWindow:
         # Project panel
         if editorlayout.top_level_project_panel() == True:
             # Project info
-            #project_info_panel = projectinfogui.get_top_level_project_info_panel()
             top_project_vbox = Gtk.VBox()
-            #top_project_vbox.pack_start(project_info_panel, False, False, 0)
             top_project_vbox.pack_start(self.bins_panel, True, True, 0)
             top_project_vbox.pack_start(seq_panel, True, True, 0)
 
-            self.top_project_panel = guiutils.set_margins(top_project_vbox, 4, 4, 0, 4)
+            self.top_project_panel = guiutils.set_margins(top_project_vbox, 0, 0, 0, 0)
             self.project_panel = None
         else:
             # Notebook project panel for smallest screens
@@ -505,8 +451,30 @@ class EditorWindow:
             project_vbox.pack_start(seq_panel, True, True, 0)
             self.project_panel = guiutils.set_margins(project_vbox, 0, 2, 6, 2)
             self.top_project_panel = None 
+
+        # Middlebar
+        # Fullscreen and layout buttons are created here but adda to middlebar in middlebar.py
+        fullscreen_icon = guiutils.get_cairo_image("fullscreen")
+        fullscreen_exit_icon = guiutils.get_cairo_image("fullscreen_exit")
+        self.fullscreen_press = guicomponents.PressLaunch(menuactions.toggle_fullscreen, fullscreen_icon, 20, 12)
+        self.fullscreen_press.widget.set_margin_top(1)
+        self.fullscreen_press.widget.set_tooltip_text(_("Fullscreen - F11"))
+        # Used in menuactions.toggle_fullscreen to switch image
+        self.fullscreen_press.fullscreen_icon = fullscreen_icon
+        self.fullscreen_press.fullscreen_exit_icon = fullscreen_exit_icon
+
+        icon_2 = guiutils.get_cairo_image("layout")
+        self.layout_press = guicomponents.PressLaunchPopover(editorlayout.show_layout_press_menu, icon_2, 24, 12)
+        self.layout_press.widget.set_margin_top(1)
+        self.layout_press.widget.set_tooltip_text(_("Layouts"))
         
-        # Position bar and decorative frame  for it
+        self.edit_buttons_row = self._get_edit_buttons_row()
+
+        self.edit_buttons_frame = Gtk.Frame()
+        self.edit_buttons_frame.add(self.edit_buttons_row)
+        guiutils.set_margins(self.edit_buttons_frame, 1, 0, 0, 0)
+
+        # Position bar and decorative frame for it
         self.pos_bar = PositionBar()
         pos_bar_frame = Gtk.HBox()
         pos_bar_frame.add(self.pos_bar.widget)
@@ -531,34 +499,37 @@ class EditorWindow:
 
         callbacks = [monitorevent.mark_in_pressed,
                      monitorevent.mark_out_pressed,
-                     monitorevent.marks_clear_pressed]
+                     monitorevent.marks_clear_pressed,
+                     monitorevent.to_mark_in_pressed,
+                     monitorevent.to_mark_out_pressed]
         markbuttons = glassbuttons.MarkButtons(callbacks)
         markbuttons.widget.set_margin_right(12)
-        mbtooltips = [_("Mark In - I"),  _("Mark Out - O"), _("Clear Marks - Alt + K")]
+        mbtooltips = [_("Mark In - I"),  _("Mark Out - O"),  _("To Mark In - Alt + I"),  _("To Mark Out - Alt + K"), _("Clear Marks - Alt + K")]
         tooltip_runner = glassbuttons.TooltipRunner(markbuttons, mbtooltips)
-        
+
         player_buttons_row = Gtk.HBox(False, 0)
         player_buttons_row.pack_start(self.monitor_switch.widget, False, False, 0)
         player_buttons_row.pack_start(Gtk.Label(), True, True, 0)
-        #player_buttons_row.pack_start(self.monitor_clip_type.widget, False, False, 0)
-        #player_buttons_row.pack_start(Gtk.Label(), True, True, 0)
         player_buttons_row.pack_start(self.player_buttons.widget, False, False, 0)
         player_buttons_row.pack_start(Gtk.Label(), True, True, 0)
-        #player_buttons_row.pack_start(Gtk.Label(), True, True, 0)
         player_buttons_row.pack_start(markbuttons.widget, False, False, 0)
         player_buttons_row.pack_start(self.trim_view_select.widget, False, False, 0)
         player_buttons_row.pack_start(self.view_mode_select.widget, False, False, 0)
-        player_buttons_row.set_margin_top(8)
+        player_buttons_row.set_margin_top(7)
         player_buttons_row.set_margin_bottom(6)
         player_buttons_row.set_margin_left(12)
         player_buttons_row.set_margin_right(12)
 
+        # This is used in updater.py
         player_buttons_row.set_name("player-bar")
-        gui.apply_widget_css(player_buttons_row, "player-bar", "player-bar-id.css")
-        
-        self.player_buttons_row = player_buttons_row
 
-        # Switch / pos bar row
+        self.player_buttons_row = player_buttons_row
+        
+        tc_player_row = Gtk.HBox(False, 0)
+        tc_player_row.pack_start(self.big_TC, False, False, 0)
+        tc_player_row.pack_start(player_buttons_row, True, True, 0)
+
+        # pos bar row
         sw_pos_hbox = Gtk.HBox(False, 1)
         sw_pos_hbox.pack_start(pos_bar_frame, True, True, 0)
         
@@ -569,28 +540,23 @@ class EditorWindow:
 
         dnd.connect_video_monitor(self.tline_display)
 
+        # Top info row
+        if editorpersistance.prefs.global_layout == appconsts.SINGLE_WINDOW:
+            monitor_info_box = self._get_monitor_info_box()
+
         # Monitor
         monitor_vbox = Gtk.VBox(False, 0)
+        if editorpersistance.prefs.global_layout == appconsts.SINGLE_WINDOW:
+            monitor_vbox.pack_start(monitor_info_box, False, True, 0)
         monitor_vbox.pack_start(monitor_widget.widget, True, True, 0)
-        monitor_vbox.pack_start(player_buttons_row, False, True, 0)
+        monitor_vbox.pack_start(tc_player_row, False, True, 0)
         monitor_vbox.pack_start(sw_pos_hbox, False, True, 0)
         monitor_align = guiutils.set_margins(monitor_vbox, 0, 0, 0, 0)
 
         self.monitor_frame = Gtk.Frame()
         self.monitor_frame.add(monitor_align)
         self.monitor_frame.set_size_request(MONITOR_AREA_WIDTH, appconsts.TOP_ROW_HEIGHT)
-        
-        # Middlebar
-        self.edit_buttons_row = self._get_edit_buttons_row()
 
-        self.edit_buttons_frame = Gtk.Frame()
-        self.edit_buttons_frame.add(self.edit_buttons_row)
-        guiutils.set_margins(self.edit_buttons_frame, 1, 0, 0, 0)
-
-        self.edit_buttons_frame.override_background_color(Gtk.StateFlags.NORMAL, gui.get_mid_neutral_color())
-        #self.edit_buttons_frame.set_name("middlebar")
-        #gui.apply_widget_css(player_buttons_row, "middlebar", "middlebar-id.css")
-                    
     def _init_tline(self):
         self.tline_scale = tlinewidgets.TimeLineFrameScale(modesetting.set_default_edit_mode,
                                                            updater.mouse_scroll_zoom)
@@ -602,26 +568,28 @@ class EditorWindow:
         info_h = Gtk.HBox()
         info_h.pack_start(self.tline_info, False, False, 0)
         info_h.pack_start(Gtk.Label(), True, True, 0)
-        # Aug-2019 - SvdB - BB - Height doesn't need to be doubled. 1.4x is nicer
-        size_adj = 1
+
         size_x = tlinewidgets.COLUMN_WIDTH - 22 - 22 - 22 - 22
         size_y = tlinewidgets.SCALE_HEIGHT
 
         info_h.set_size_request(size_x, size_y)
 
-        # Aug-2019 - SvdB - BB - add size_adj and width/height as parameter to be able to adjust it for double height
         marker_surface =  guiutils.get_cairo_image("marker")
-        markers_launcher =  guicomponents.PressLaunchPopover(tlineaction.marker_menu_lauch_pressed, marker_surface, 22*size_adj, 22*size_adj)
-        
+        markers_launcher =  guicomponents.PressLaunchPopover(tlineaction.marker_menu_lauch_pressed, marker_surface, 22, 22)
+        markers_launcher.widget.set_tooltip_markup(_("Timeline Markers"))
+
         tracks_launcher_surface = guiutils.get_cairo_image("track_menu_launch")
-        tracks_launcher = guicomponents.PressLaunchPopover(trackaction.all_tracks_menu_launch_pressed, tracks_launcher_surface, 22*size_adj, 22*size_adj)
-
+        tracks_launcher = guicomponents.PressLaunchPopover(trackaction.all_tracks_menu_launch_pressed, tracks_launcher_surface, 22, 22)
+        tracks_launcher.widget.set_tooltip_markup(_("Tracks"))
+        
         levels_launcher_surface = guiutils.get_cairo_image("audio_levels_menu_launch")
-        levels_launcher = guicomponents.PressLaunchPopover(trackaction.tline_properties_menu_launch_pressed, levels_launcher_surface, 22*size_adj, 22*size_adj)
-
+        levels_launcher = guicomponents.PressLaunchPopover(trackaction.tline_properties_menu_launch_pressed, levels_launcher_surface, 22, 22)
+        levels_launcher.widget.set_tooltip_markup(_("Timeline Properties"))
+        
         sync_launcher_surface = guiutils.get_cairo_image("sync_menu_launch")
-        sync_launcher = guicomponents.PressLaunchPopover(syncsplitevent.sync_menu_launch_pressed, sync_launcher_surface, 22*size_adj, 22*size_adj)
-
+        sync_launcher = guicomponents.PressLaunchPopover(syncsplitevent.sync_menu_launch_pressed, sync_launcher_surface, 22, 22)
+        sync_launcher.widget.set_tooltip_markup(_("Syncing"))
+        
         # Timeline top row
         tline_hbox_1 = Gtk.HBox()
         tline_hbox_1.pack_start(info_h, False, False, 0)
@@ -670,13 +638,13 @@ class EditorWindow:
         self.tline_hbox_2 = tline_hbox_2
 
         # Comp mode selector
-        size_adj = 1
+
         tds = guiutils.get_cairo_image("top_down")
         tdds = guiutils.get_cairo_image("top_down_auto")
         sas = guiutils.get_cairo_image("standard_auto")
         fta = guiutils.get_cairo_image("full_track_auto")
         surfaces = [tds, tdds, sas, fta]
-        comp_mode_launcher = guicomponents.ImageMenuLaunchPopover(projectaction.compositing_mode_menu_launched, surfaces, 22*size_adj, 20)
+        comp_mode_launcher = guicomponents.ImageMenuLaunchPopover(projectaction.compositing_mode_menu_launched, surfaces, 22, 20)
         comp_mode_launcher.surface_x = 0
         comp_mode_launcher.surface_y = 4
         comp_mode_launcher.widget.set_tooltip_markup(_("Current Sequence Compositing Mode"))
@@ -697,7 +665,7 @@ class EditorWindow:
         tline_vbox = Gtk.VBox()
         tline_vbox.pack_start(self.tline_hbox_1, False, False, 0)
         tline_vbox.pack_start(self.tline_hbox_2, True, True, 0)
-        #tline_vbox.pack_start(self.tline_renderer_hbox, False, False, 0)
+
         tline_vbox.pack_start(tline_hbox_3, False, False, 0)
 
         tline_vbox_frame = guiutils.get_panel_etched_frame(tline_vbox)
@@ -746,7 +714,6 @@ class EditorWindow:
             # Position is empty.
             self.top_right_frame = guiutils.get_empty_panel_etched_frame() # to be filled later if panels are added into this position 
 
-
         # ---------------------------------------------------------------- BOTTOM ROW
         # Horizon box for bottom row GUI elements
         self.tline_pane = Gtk.HBox(False, 0)
@@ -762,7 +729,9 @@ class EditorWindow:
             
         # Put timeline between left and right bottom row panels.
         self.tline_pane.pack_start(self.tline_vpane, True, True, 0)
-        
+        if editorpersistance.prefs.audio_master_position_is_top_row == False:
+            self.tline_pane.pack_end(self._get_audio_master_meter(), False, False, 0)
+
         # -------------- appconsts.PANEL_PLACEMENT_BOTTOM_ROW_RIGHT, by default this has filter select panel.
         self.bottom_right_panel, widget_is_notebook  = editorlayout.create_position_widget(self, appconsts.PANEL_PLACEMENT_BOTTOM_ROW_RIGHT)
         if self.bottom_right_panel != None:
@@ -775,7 +744,7 @@ class EditorWindow:
 
 
         # ---------------------------------------------------------------- LEFT  COLUMN
-        self.left_column_panel, widget_is_notebook  = editorlayout.create_position_widget(self, appconsts.PANEL_PLACEMENT_LEFT_COLUMN)
+        self.left_column_panel, widget_is_notebook = editorlayout.create_position_widget(self, appconsts.PANEL_PLACEMENT_LEFT_COLUMN)
         if self.left_column_panel != None:
             self.left_column_frame = guiutils.get_panel_etched_frame(self.left_column_panel)
             guiutils.set_margins(self.left_column_frame, 0, 0, 0, 1)
@@ -783,6 +752,15 @@ class EditorWindow:
         else:
             self.left_column_frame = guiutils.get_empty_panel_etched_frame() # to be filled later if panels are added into this position.
 
+        # ---------------------------------------------------------------- RIGHT COLUMN
+        self.right_column_panel, widget_is_notebook = editorlayout.create_position_widget(self, appconsts.PANEL_PLACEMENT_RIGHT_COLUMN)
+        if self.right_column_panel != None:
+            self.right_column_frame = guiutils.get_panel_etched_frame(self.right_column_panel)
+            guiutils.set_margins(self.right_column_frame, 0, 0, 0, 1)
+
+        else:
+            self.right_column_frame = guiutils.get_empty_panel_etched_frame() # to be filled later if panels are added into this position.
+            
         # Top row paned
         self.top_paned = gtkbuilder.HPaned()
         if editorpersistance.prefs.global_layout == appconsts.SINGLE_WINDOW:
@@ -797,7 +775,8 @@ class EditorWindow:
         self.top_row_hbox.pack_start(self.top_project_panel_frame, False, False, 0)
         self.top_row_hbox.pack_start(self.top_paned, True, True, 0)
         self.top_row_hbox.pack_end(self.top_right_frame, False, False, 0)
-        self.top_row_hbox.pack_end(audiomonitoring.get_master_meter(), False, False, 0)
+        if editorpersistance.prefs.audio_master_position_is_top_row == True:
+            self.top_row_hbox.pack_end(self._get_audio_master_meter(), False, False, 0)
 
         editorlayout.apply_tabs_positions()
         
@@ -828,9 +807,9 @@ class EditorWindow:
             ('EditMenu', None, _('_Edit')),
             ('Undo', None, _('_Undo'), '<control>Z', None, undo.do_undo_and_repaint),
             ('Redo', None, _('_Redo'), '<control>Y', None, undo.do_redo_and_repaint),
-            ('Cut', None, _('Cut'), '<control>X', None, lambda a:keyevents.cut_action()),
-            ('Copy', None, _('Copy'), '<control>C', None, lambda a:keyevents.copy_action()),
-            ('Paste', None, _('Paste'), '<control>V', None, lambda a:keyevents.paste_action()),
+            ('Cut', None, _('Cut'), '<control>X', None, lambda a:copypaste.cut_action()),
+            ('Copy', None, _('Copy'), '<control>C', None, lambda a:copypaste.copy_action()),
+            ('Paste', None, _('Paste'), '<control>V', None, lambda a:copypaste.paste_action()),
             ('PasteFilters', None, _('Paste Filters / Properties'), '<control><alt>V', None, lambda a:tlineaction.do_timeline_filters_paste()),
             ('AddFromMonitor', None, _('Add Monitor Clip')),
             ('AppendClip', None, _('Append'), None, None, lambda a:tlineaction.append_button_pressed()),
@@ -864,8 +843,9 @@ class EditorWindow:
             ('AddMediaClip', None, _('Add Video, Audio or Image...'), None, None, lambda a: projectaction.add_media_files()),
             ('AddMediaFolder', None, _('Add Media From Folder...'), None, None, lambda a: projectaddmediafolder.show_add_media_folder_dialog()),
             ('AddImageSequence', None, _('Add Image Sequence...'), None, None, lambda a:projectaction.add_image_sequence()),
+            ('AddTitle', None, _('Add Title...'), None, None, lambda a: titler.show_titler()),
             ('CreateColorClip', None, _('Add Color Clip...'), None, None, lambda a:patternproducer.create_color_clip()),
-            ('BinMenu', None, _('Bin')),
+            ('BinMenu', None, _('Bins')),
             ('AddBin', None, _('Add Bin'), None, None, lambda a:projectaction.add_new_bin()),
             ('DeleteBin', None, _('Delete Selected Bin'), None, None, lambda a:projectaction.delete_selected_bin()),
             ('SequenceMenu', None, _('Sequence')),
@@ -877,6 +857,8 @@ class EditorWindow:
             ('AddMediaPlugin', None, _('Add Generator...'), None, None, lambda a:mediaplugin.show_add_media_plugin_window()),
             ('LoadMediaPluginScript', None, _('Load Generator Script...'), None, None,lambda w: containerclip.create_fluxity_media_item()),
             ('CreateSelectionCompound', None, _('From Selected Clips'), None, None, lambda a:projectaction.create_selection_compound_clip()),
+            ('CreateBoxCompound', None, _('From Box Selection'), None, None, lambda a:projectaction.create_box_compound_clip()),
+            ('CreateRangeCompound', None, _('From Timeline Range'), None, None, lambda a:projectaction.create_range_compound_clip()),
             ('CreateSequenceCompound', None, _('From Current Sequence'), None, None, lambda a:projectaction.create_sequence_compound_clip()),
             ('CreateSequenceLinkContainerItem', None, _("Add Sequence Link Container Clip..."), None, None, lambda a:projectaction.create_sequence_link_container()),
             ('CreateSequenceFreezeCompound', None, _('From Current Sequence With Freeze Frame at Playhead Position'), None, None, lambda a:projectaction.create_sequence_freeze_frame_compound_clip()),
@@ -908,7 +890,7 @@ class EditorWindow:
             ('QuickReference', None, _('Contents'), None, None, lambda a:menuactions.quick_reference()),
             ('QuickReferenceWeb', None, _('Contents Web'), None, None, lambda a:menuactions.quick_reference_web()),
             ('Environment', None, _('Runtime Environment'), None, None, lambda a:menuactions.environment()),
-            ('KeyboardShortcuts', None, _('Keyboard Shortcuts'), None, None, lambda a:shortcutsdialog.keyboard_shortcuts_dialog(self.window, workflow.get_tline_tool_working_set, menuactions.keyboard_shortcuts_callback, keyevents.change_single_shortcut, menuactions.keyboard_shortcuts_menu_item_selected_callback)),
+            ('KeyboardShortcuts', None, _('Keyboard Shortcuts'), None, None, lambda a:shortcutsdialog.keyboard_shortcuts_dialog(self.window, workflow.get_tline_tool_working_set, menuactions.keyboard_shortcuts_callback, shortcuts.change_single_shortcut, menuactions.keyboard_shortcuts_menu_item_selected_callback)),
             ('About', None, _('About'), None, None, lambda a:menuactions.about()),
             ('TOOL_ACTION_KEY_1', None, None, '1', None, lambda a:_this_is_not_used()),
             ('TOOL_ACTION_KEY_2', None, None, '2', None, lambda a:_this_is_not_used()),
@@ -982,11 +964,15 @@ class EditorWindow:
                 <menu action='ProjectMenu'>
                     <menuitem action='AddMediaClip'/>
                     <menuitem action='AddImageSequence'/>
+                    <separator/>
                     <menuitem action='AddMediaPlugin'/>
+                    <menuitem action='AddTitle'/>
                     <menuitem action='CreateColorClip'/>
                     <separator/>
                     <menu action='ContainerClipsMenu'>
                         <menuitem action='CreateSelectionCompound'/>
+                        <menuitem action='CreateBoxCompound'/>
+                        <menuitem action='CreateRangeCompound'/>
                         <menuitem action='CreateSequenceCompound'/>
                         <menuitem action='AudioSyncCompoundClip'/>
                         <separator/>
@@ -1073,7 +1059,7 @@ class EditorWindow:
 
         # Get menu bar
         self.menubar = self.ui.get_widget('/MenuBar')
-        self.menubar .override_background_color(Gtk.StateFlags.NORMAL, gui.get_mid_neutral_color())
+        #self.menubar .override_background_color(Gtk.StateFlags.NORMAL, gui.get_mid_neutral_color())
 
         # Set reference to UI manager and acclegroup
         self.uimanager = ui
@@ -1155,6 +1141,26 @@ class EditorWindow:
         tool_selector_menu_item.set_submenu(tool_selector_menu)
         menu.append(tool_selector_menu_item)
         
+        # Audio master meter
+        # Tool Selection Widget
+        audiomaster_menu_item = Gtk.MenuItem(_("Audoi Master Level Meter"))
+        audiomaster_menu = Gtk.Menu()
+        audiomaster_top = Gtk.RadioMenuItem()
+        audiomaster_top.set_label( _("Top Row"))
+        audiomaster_menu.append(audiomaster_top)
+        audiomaster_bottom = Gtk.RadioMenuItem.new_with_label([audiomaster_top], _("Bottom Row"))
+
+        if editorpersistance.prefs.audio_master_position_is_top_row == True:
+            audiomaster_top.set_active(True)
+        else:
+            audiomaster_bottom.set_active(True)
+        audiomaster_top.connect("activate", lambda w: self._set_audiomaster_position(True))
+        audiomaster_bottom.connect("activate", lambda w: self._set_audiomaster_position(False))
+
+        audiomaster_menu.append(audiomaster_bottom)
+        audiomaster_menu_item.set_submenu(audiomaster_menu)
+        menu.append(audiomaster_menu_item)
+        
         sep = Gtk.SeparatorMenuItem()
         menu.append(sep)
 
@@ -1278,7 +1284,28 @@ class EditorWindow:
         middlebar.re_create_tool_selector(self)
         middlebar.redo_layout(self)
         workflow.select_default_tool()
+
+    def _set_audiomaster_position(self, value):
+        # We get 2 events from radio menu items, only handle one.
+        if editorpersistance.prefs.audio_master_position_is_top_row == value:
+            return 
+            
+        editorpersistance.prefs.audio_master_position_is_top_row = value
+        editorpersistance.save()
+
+        if value == True:
+            self.tline_pane.remove(self._get_audio_master_meter())
+            self.top_row_hbox.pack_end(self._get_audio_master_meter(), False, False, 0)
+        else:
+            self.top_row_hbox.remove(self._get_audio_master_meter())
+            self.tline_pane.pack_end(self._get_audio_master_meter(), False, False, 0)
+
+    def _get_audio_master_meter(self):
+        if self.audio_master_meter == None:
+            self. audio_master_meter = audiomonitoring.get_master_meter()
         
+        return self.audio_master_meter
+
     def _show_tools_dock(self, widget):
         if widget.get_active() == False:
             return
@@ -1313,12 +1340,9 @@ class EditorWindow:
         self.monitor_switch.widget.set_margin_top(2)
         self.monitor_switch.widget.set_margin_right(57)
 
-        self.monitor_clip_type = guicomponents.MonitorClipType()
-        #self.monitor_clip_type.widget.set_margin_right(17)
-
     def _create_monitor_row_widgets(self):
         self.monitor_tc_info = guicomponents.MonitorMarksTCInfo()
-        guiutils.set_margins(self.monitor_tc_info.widget,5,0,0,0)
+        #guiutils.set_margins(self.monitor_tc_info.widget,5,0,0,0)
 
     def _monitor_switch_handler(self, action):
         if action == appconsts.MONITOR_TLINE_BUTTON_PRESSED:
@@ -1333,37 +1357,37 @@ class EditorWindow:
                                   monitorevent.play_stop_pressed,
                                   monitorevent.next_pressed]
 
-
         self.player_buttons.set_callbacks(pressed_callback_funcs)
 
         # Monitor position bar
         self.pos_bar.set_listener(mltplayer.seek_position_normalized)
-
+        gui.monitor_waveform_display.set_listener(mltplayer.seek_position_normalized)
+        
     def _get_edit_buttons_row(self):
         tools_pixbufs = tlinecursors.get_tools_pixbuffs()
 
         middlebar.create_edit_buttons_row_buttons(self, tools_pixbufs)
 
         buttons_row = Gtk.HBox(False, 1)
-        if editorpersistance.prefs.midbar_layout == appconsts.MIDBAR_COMPONENTS_CENTERED:
-            middlebar.fill_with_COMPONENTS_CENTERED_pattern(buttons_row, self)
-        elif editorpersistance.prefs.midbar_layout == appconsts.MIDBAR_TC_LEFT:
-            middlebar.fill_with_TC_LEFT_pattern(buttons_row, self)
-        else:
-            middlebar.fill_with_TC_MIDDLE_pattern(buttons_row, self)
+        middlebar.fill_with_TC_LEFT_pattern(buttons_row, self)
 
-        # Aug-2019 - SvdB - BB
         offset = 2
-        if guiutils.double_icon_size():
-           offset = 4
-           buttons_row.set_margin_bottom(offset)
-
         buttons_row.set_margin_top(offset)
         buttons_row.set_margin_start(offset)
         buttons_row.set_margin_end(offset)
 
         return buttons_row
 
+    def _get_monitor_info_box(self):
+        tline_info_box = Gtk.HBox(False, 0)
+        tline_info_box.pack_start(self.monitor_tc_info.monitor_source, False, False, 0)
+        tline_info_box.pack_start(self.monitor_tc_info.monitor_tc, False, False, 0)
+        tline_info_box.pack_start(Gtk.Label(), True, True, 0)
+        tline_info_box.pack_start(self.monitor_tc_info.widget, False, False, 0)
+        guiutils.set_margins(tline_info_box, 0, 0, 4, 2)
+    
+        return tline_info_box
+        
     def _add_tool_tips(self):
         self.big_TC.set_tooltip_text(_("Timeline current frame timecode"))
 
@@ -1375,6 +1399,9 @@ class EditorWindow:
     def top_paned_resized(self, w, req):
         pass
 
+    def get_middlebar_required_width(self):
+        return middlebar.get_required_width()
+
 # testing
 def _apply_test_dimensions(window, test_index, scale):
     dims = [(1920, 1200), (2048, 1152), (2048, 1536), (2560, 1440), (2560, 1600), (3440, 1440), (3840, 2160)]
