@@ -24,6 +24,7 @@ Module holds references to GUI widgets and offers some helper functions used in
 
 from gi.repository import Gtk, Gdk, GdkPixbuf
 
+import databridge
 import respaths
 
 
@@ -65,6 +66,8 @@ big_tc = None
 comp_mode_launcher = None
 monitor_widget = None
 monitor_switch = None
+monitor_waveform_display = None
+
 # indexes match editmode values in editorstate.py
 notebook_buttons = None
 
@@ -93,7 +96,7 @@ def capture_references(new_editor_window):
     tline_column, play_b, effect_select_list_view, effect_select_combo_box, \
     project_info_vbox, big_tc, editmenu, notebook_buttons, tline_left_corner, \
     monitor_widget, bin_panel, monitor_switch, comp_mode_launcher, tline_render_strip, \
-    tline_cursor_manager
+    tline_cursor_manager, monitor_waveform_display
 
     editor_window = new_editor_window
 
@@ -109,7 +112,8 @@ def capture_references(new_editor_window):
 
     monitor_widget = editor_window.monitor_widget
     monitor_switch = editor_window.monitor_switch
-    
+    monitor_waveform_display = monitor_widget.waveform_display
+     
     tline_display = editor_window.tline_display
     tline_scale = editor_window.tline_scale
     tline_canvas = editor_window.tline_canvas
@@ -182,6 +186,31 @@ def apply_gtk_css():
 
     return True
 
+def apply_widget_css(widget, widget_css_name, css_file):
+    css_path = respaths.ROOT_PATH + "/res/css3/" + css_file
+
+    provider = Gtk.CssProvider()
+    provider.load_from_path(css_path)
+    
+    widget.set_name(widget_css_name)
+    widget.get_style_context().add_provider(provider, Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION)
+
+def apply_widget_css_class(widget, widget_css_class_name, css_file):
+    css_path = respaths.ROOT_PATH + "/res/css3/" + css_file
+    provider = Gtk.CssProvider()
+    provider.load_from_path(css_path)
+    
+    widget.get_style_context().add_class(widget_css_class_name)
+    widget.get_style_context().add_provider(provider, Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION)
+
+def apply_widget_css_class_style_from_string(widget, css_str):#, widget_css_class_name, css_file):
+    css_data = css_str.encode("utf-8")
+    provider = Gtk.CssProvider()
+    provider.load_from_data(css_data)
+    
+    #widget.get_style_context().add_class(widget_css_class_name)
+    widget.get_style_context().add_provider(provider, Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION)
+    
 def get_default_filter_icon():
     return GdkPixbuf.Pixbuf.new_from_file(respaths.IMAGE_PATH + "filter.png")
     
@@ -204,3 +233,14 @@ def get_filter_group_icons(default_icon):
     group_icons["Blend"] = GdkPixbuf.Pixbuf.new_from_file(respaths.IMAGE_PATH + "blend_filter.png")
 
     return group_icons
+
+def timeline_has_focus(): # copied from keyevents.by. maybe put in utils?
+    if(tline_canvas.widget.is_focus()
+       or tline_column.widget.is_focus()
+       or editor_window.tool_selector.widget.is_focus()
+       or (pos_bar.widget.is_focus() and timeline_visible())
+       or tline_scale.widget.is_focus()
+       or databridge.glass_buttons_default_focus_group_has_focus()):
+        return True
+
+    return False
\ No newline at end of file
