@@ -286,8 +286,8 @@ def sync_menu_show(launcher, widget, properties_set_callback, split_mirror_callb
             
         properties_section = Gio.Menu.new()
 
-        
-        add_menu_action_check(properties_section, _("Show Synch Relations"), "midbar.sync.showsync", editorpersistance.prefs.show_sync, "showsync", properties_set_callback)
+        add_menu_action_check(properties_section, _("Auto Sync Trim Single Childs"), "midbar.sync.autotrimsingle", editorpersistance.prefs.auto_sync_single_childs_on_trim, "autotrimsingle", properties_set_callback)
+        add_menu_action_check(properties_section, _("Show Sync Relations"), "midbar.sync.showsync", editorpersistance.prefs.show_sync, "showsync", properties_set_callback)
         _sync_menu.append_section(None, properties_section)
 
         mirror_section = Gio.Menu.new()
@@ -394,6 +394,7 @@ def media_panel_popover_show(widget, x, y, callback):
 
     section2 = Gio.Menu.new()
     add_menu_action(section2, _("Add Generator..."), "mediapanel.addgenerator", "add generator", callback)
+    add_menu_action(section2, _("Add Title..."), "mediapanel.addtitle", "add title", callback)
     add_menu_action(section2, _("Add Color Clip..."), "mediapanel.addcolorclip", "add color clip", callback)
     _media_panel_menu.append_section(None, section2)
     
@@ -462,7 +463,7 @@ def trim_view_popover_show(launcher, widget, callback):
 
     _trimview_popover = new_popover(widget, _trimview_menu, launcher)
 
-def monitor_view_popupmenu_show(launcher, widget, callback, callback_opacity):
+def monitor_view_popupmenu_show(launcher, widget, callback, callback_opacity, waveform_callback):
     global _monitorview_popover, _monitorview_menu, _opacity_section, _opacity_submenu
 
     if _monitorview_menu == None:
@@ -476,6 +477,11 @@ def monitor_view_popupmenu_show(launcher, widget, callback, callback_opacity):
         add_menu_action_all_items_radio(view_section, items_data, "monitor.viewimage", active_index, callback)
         _monitorview_menu.append_section(None, view_section)
 
+        #checked_state = editorpersistance.prefs.show_waveform_in_monitor
+        #waveform_section =  Gio.Menu.new()
+        #add_menu_action_check(waveform_section, _("Show Clip Audio Waveform In Monitor"), "monitor.audiowaveform", checked_state, "monitor_waveform", waveform_callback)
+        #_monitorview_menu.append_section(None, waveform_section)
+        
         _opacity_section = menu_clear_or_create(_opacity_section)
         _opacity_submenu = menu_clear_or_create(_opacity_submenu)
         items_data = [( _("100%"), "3"), ( _("80%"), "4"), ( _("50%"), "5"), ( _("20%"), "6")]
@@ -963,6 +969,10 @@ def tracks_popover_menu_show(track, widget, x, y, callback, callback_height):
         add_menu_action(lock_section, _("Unlock Track"), "trackcolumn.unlock", (track,"unlock", None), callback, False)
     _tracks_column_menu.append_section(None, lock_section)
 
+    info_label_section = Gio.Menu.new()
+    add_menu_action(info_label_section, _("Edit Track Info Label"), "trackcolumn.sync.infolabel", (track,"infolabel", None), callback)
+    _tracks_column_menu.append_section(None, info_label_section)
+
     height_section = Gio.Menu.new()
     items_data =[(_("High Height"), "highheight"), (_("Large Height"), "normalheight"), (_("Normal Height"), "smallheight")]
     if track_obj.height == appconsts.TRACK_HEIGHT_HIGH:
@@ -1004,9 +1014,9 @@ def tracks_popover_menu_show(track, widget, x, y, callback, callback_height):
     active = True
 
     sync_set_section = Gio.Menu.new()
-    add_menu_action(sync_set_section, _("Sync All Clips to Track..."), "trackcolumn.sync.setsync",  (track,"setsync", None), callback, active)
+    add_menu_action(sync_set_section, _("Sync All Clips to Track..."), "trackcolumn.sync.setsync",  (track,"setsyncfrompopover", None), callback, active)
     reset_active = track_obj.parent_track != None
-    add_menu_action(sync_set_section, _("Update Sync to Clips' Current Positions"), "trackcolumn.sync.resetsync",  (track,"ressetsync", None), callback, reset_active)
+    add_menu_action(sync_set_section, _("Update Sync to Clips' Current Positions"), "trackcolumn.sync.resetsync",  (track,"resetsync", None), callback, reset_active)
     add_menu_action(sync_set_section, _("Clear Sync"), "trackcolumn.sync.clearsync", (track,"clearsync", None), callback, active)
     _tracks_column_menu.append_section(None, sync_set_section)
 
