@@ -137,7 +137,8 @@ def create_edit_buttons_row_buttons(editor_window, modes_pixbufs):
 def _create_buttons(editor_window):
 
     editor_window.big_TC = Gtk.Stack()
-    editor_window.big_TC.set_margin_top(5)
+    editor_window.big_TC.set_margin_top(4)
+    editor_window.big_TC.set_margin_bottom(1)
     tc_disp = guicomponents.BigTCDisplay()
     tc_entry = guicomponents.BigTCEntry()
     tc_disp.widget.show()
@@ -204,7 +205,7 @@ def _create_buttons(editor_window):
     editor_window.monitor_insert_buttons.add_button(guiutils.get_cairo_image("overwrite_clip"), tlineaction.three_point_overwrite_pressed)
     editor_window.monitor_insert_buttons.add_button(guiutils.get_cairo_image("insert_clip"), tlineaction.insert_button_pressed)
     editor_window.monitor_insert_buttons.add_button(guiutils.get_cairo_image("append_clip"), tlineaction.append_button_pressed)
-    tooltips = [_("Overwrite Range"), _("Overwrite Clip - T"), _("Insert Clip - Y"), _("Append Clip - U")]
+    tooltips = [_("Overwrite Range"), _("Overwrite Selected Clip/s - T"), _("Insert Clip - Y"), _("Append Clip - U")]
     tooltip_runner = glassbuttons.TooltipRunner(editor_window.monitor_insert_buttons, tooltips)
     editor_window.monitor_insert_buttons.no_decorations = no_decorations
     editor_window.monitor_insert_buttons.show_prelight_icons()
@@ -244,8 +245,7 @@ def fill_with_TC_LEFT_pattern(buttons_row, window):
     global w
     w = window
 
-    buttons_row.pack_start(guiutils.get_pad_label(7, MIDDLE_ROW_HEIGHT), False, True, 0) 
-    buttons_row.pack_start(guiutils.get_pad_label(7, MIDDLE_ROW_HEIGHT), False, True, 0) #### NOTE!!!!!! THIS DETERMINES THE HEIGHT OF MIDDLE ROW
+    buttons_row.pack_start(guiutils.get_pad_label(0, MIDDLE_ROW_HEIGHT), False, True, 0) #### NOTE!!!!!! THIS DETERMINES THE HEIGHT OF MIDDLE ROW
     if editorpersistance.prefs.tools_selection == appconsts.TOOL_SELECTOR_IS_MENU:
         buttons_row.pack_start(w.tool_selector.widget, False, True, 0)
             
@@ -274,12 +274,53 @@ def fill_with_TC_LEFT_pattern(buttons_row, window):
     buttons_row.pack_start(get_buttons_group(5), False, True, 0)
     buttons_row.pack_start(Gtk.Label(), True, True, 0)
 
-    buttons_row.pack_start(window.tools_buttons.widget, False, False, 0)
-    buttons_row.pack_start(guiutils.pad_label(12,2), False, False, 0)
-    buttons_row.pack_start(window.fullscreen_press.widget, False, False, 0)
     buttons_row.pack_start(guiutils.pad_label(6,2), False, False, 0)
-    buttons_row.pack_start(window.layout_press.widget, False, False, 0)
 
+def get_required_width():
+
+    w_tot = 0
+    wid, h = w.tool_selector.widget.get_preferred_width()
+    w_tot += int(wid)
+
+    if editorstate.screen_size_small_width() == False:
+        pad_w = 24
+    else:
+        pad_w = 5
+
+    wid, h = get_buttons_group(0).get_preferred_width()
+    w_tot += int(wid)
+    w_tot += pad_w
+
+    wid, h = get_buttons_group(1).get_preferred_width()
+    w_tot += int(wid)
+    w_tot += pad_w
+
+    wid, h = get_buttons_group(2).get_preferred_width()
+    w_tot += int(wid)
+    w_tot += pad_w
+
+    wid, h = get_buttons_group(3).get_preferred_width()
+    w_tot += int(wid)
+    w_tot += pad_w
+
+    wid, h = get_buttons_group(4).get_preferred_width()
+    w_tot += int(wid)
+    w_tot += pad_w
+
+    wid, h = get_buttons_group(5).get_preferred_width()
+    w_tot += int(wid)
+
+    wid, h = w.tools_buttons.widget.get_preferred_width()
+    w_tot += int(wid)
+    wid, h = w.fullscreen_press.widget.get_preferred_width()
+    w_tot += int(wid)
+    wid, h = w.layout_press.widget.get_preferred_width()
+    w_tot += int(wid)
+    w_tot += 24   
+    w_tot += 6
+
+    return w_tot
+    
 def _get_zoom_buttons_panel():    
     return w.zoom_buttons.widget
 
@@ -298,17 +339,6 @@ def _get_edit_buttons_3_panel():
 def _get_monitor_insert_buttons():
     return w.monitor_insert_buttons.widget
 
-"""
-def _get_tools_buttons():
-    return w.tools_buttons.widget
-"""
-
-def _b(button, icon, remove_relief=False):
-    button.set_image(icon)
-    button.set_property("can-focus",  False)
-    if remove_relief:
-        button.set_relief(Gtk.ReliefStyle.NONE)
-
 def _clear_container(cont):
     children = cont.get_children()
     for child in children:
