@@ -45,7 +45,7 @@ import utils
 # Mouse delta in pix needed before selection is interpreted as move.
 MOVE_START_LIMIT = 5
 
-# Width of area in pixels that is iterpreted as an attempt to place overwrite
+# Width of area in pixels that is interpreted as an attempt to place overwrite
 # clips, starting from edit
 MAGNETIC_AREA_IN_PIX = 5
 
@@ -69,23 +69,6 @@ blank_press_data = None
 # Data/state for ongoing edit.
 edit_data = None
 
-#------------------------------ playback control
-# These four buttons act differently in trimmodes and move modes
-def play_pressed():
-    # This handles only move modes, see trimmodes.py module for others.
-    # Jul-2016 - SvdB - Added code to handle play/pause button
-    if editorpersistance.prefs.play_pause == True:
-        if PLAYER().is_playing():
-            PLAYER().stop_playback()
-        else:
-            PLAYER().start_playback()
-    else:
-        # Original code
-        PLAYER().start_playback()
-
-def stop_pressed():
-    # This handles only move modes, see trimmodes.py module for others.
-    PLAYER().stop_playback()
 
 #------------------------------------------ go to start end
 def start_pressed():
@@ -95,6 +78,7 @@ def start_pressed():
 def end_pressed():
     # This handles only move modes, see trimmodes.py module for others.
     PLAYER().seek_frame(PLAYER().get_active_length() - 1)
+    
 #------------------------------------------ End of  go to start end
 def prev_pressed():
     # This handles only move modes, see trimmodes.py module for others.
@@ -196,7 +180,7 @@ def insert_move_press(event, frame):
     if edit_data == None:
         # We now enter box mode.
         # NOTE: this was originally made to work only with OVERWRITE mode (MOVE tool), but we piggyback existing functionality
-        # to create different box selection functionality for INSERT tool.
+        # to create box selection for INSERT tool.
         editorstate.overwrite_mode_box = True
         boxmove.entered_from_overwrite = True
         boxmove.clear_data()
@@ -500,6 +484,8 @@ def nudge_selection(delta):
     if selected_track == -1:
         return
 
+    # TODO: check and exit all on going edits. 
+
     # Collect edit data
     track = current_sequence().tracks[selected_track]
     selection_in_frame = track.clip_start(selected_range_in)
@@ -788,7 +774,7 @@ def clips_drag_out_started(event):
     clips = []
     for i in range(selected_range_in, selected_range_out + 1):
         clips.append(track.clips[i])
-    dnd.start_tline_clips_out_drag(event, clips, gui.tline_canvas.widget)
+    dnd.start_tline_clips_out_drag(event.get_gdk_event(), clips, gui.tline_canvas.widget)
 
     # Update tlione gui
     updater.repaint_tline()
