@@ -136,6 +136,8 @@ def _general_options_panel():
     disk_cache_warning_combo.append_text(_("500 MB"))
     disk_cache_warning_combo.append_text(_("1 GB"))
     disk_cache_warning_combo.append_text(_("2 GB"))
+    disk_cache_warning_combo.append_text(_("4 GB"))
+    disk_cache_warning_combo.append_text(_("8 GB"))
     disk_cache_warning_combo.set_active(prefs.disk_space_warning)
     
     # Layout
@@ -250,23 +252,12 @@ def _playback_prefs_panel():
     auto_center_on_stop = Gtk.CheckButton()
     auto_center_on_stop.set_active(prefs.auto_center_on_play_stop)
 
-    # Jul-2016 - SvdB - For play_pause button
-    play_pause_button = Gtk.CheckButton()
-    # The following test is to make sure play_pause can be used for the initial value. If not found, then leave uninitialized
-    if hasattr(prefs, 'play_pause'):
-        play_pause_button.set_active(prefs.play_pause)
-
-    timeline_start_end_button = Gtk.CheckButton()
-    if hasattr(prefs, 'timeline_start_end'):
-        timeline_start_end_button.set_active(prefs.timeline_start_end)
-
     auto_center_on_updown = Gtk.CheckButton()
     auto_center_on_updown.set_active(prefs.center_on_arrow_move)
 
     follow_move_range = Gtk.CheckButton()
     follow_move_range.set_active(prefs.playback_follow_move_tline_range)
 
-    # Apr-2017 - SvdB - For FF/Rev speed options
     if hasattr(prefs, 'ffwd_rev_shift'):
         spin_adj = Gtk.Adjustment(value=prefs.ffwd_rev_shift, lower=1, upper=10, step_increment=1)
     else:
@@ -288,8 +279,6 @@ def _playback_prefs_panel():
 
     row2 = _row(guiutils.get_checkbox_row_box(auto_center_on_stop, Gtk.Label(label=_("Center Current Frame on Playback Stop"))))
     row13 = _row(guiutils.get_checkbox_row_box(auto_center_on_updown, Gtk.Label(label=_("Center Current Frame after Up/Down Arrow"))))
-    row10 = _row(guiutils.get_checkbox_row_box(play_pause_button, Gtk.Label(label=_("Enable single Play/Pause button"))))
-    row11 = _row(guiutils.get_checkbox_row_box(timeline_start_end_button, Gtk.Label(label=_("Enable To Start and To End buttons"))))
     row14 = _row(guiutils.get_two_column_box(Gtk.Label(label=_("Fast Forward / Reverse Speed for Shift Key:")), ffwd_rev_shift_spin, PREFERENCES_LEFT))
     row14.set_tooltip_text(_("Speed of Forward / Reverse will be multiplied by this value if Shift Key is held (Only using KEYS).\n" \
         "Enabling multiple modifier keys will multiply the set values.\n" \
@@ -306,8 +295,6 @@ def _playback_prefs_panel():
     vbox.pack_start(row18, False, False, 0)
     vbox.pack_start(row2, False, False, 0)
     vbox.pack_start(row13, False, False, 0)
-    vbox.pack_start(row10, False, False, 0)
-    vbox.pack_start(row11, False, False, 0)
     vbox.pack_start(row14, False, False, 0)
     vbox.pack_start(row16, False, False, 0)
 
@@ -315,9 +302,8 @@ def _playback_prefs_panel():
 
     guiutils.set_margins(vbox, 12, 0, 12, 12)
 
-    return vbox, (auto_center_on_stop,
-                  play_pause_button, timeline_start_end_button, auto_center_on_updown,
-                  ffwd_rev_shift_spin, ffwd_rev_caps_spin, follow_move_range, loop_clips)
+    return vbox, (auto_center_on_stop, auto_center_on_updown, ffwd_rev_shift_spin,
+                  ffwd_rev_caps_spin, follow_move_range, loop_clips)
 
 def _view_prefs_panel():
     prefs = editorpersistance.prefs
@@ -346,10 +332,6 @@ def _view_prefs_panel():
     force_language_combo.set_active(active_index)
     force_language_combo.lang_codes = lang_list
 
-    display_splash_check = Gtk.CheckButton()
-    display_splash_check.set_active(prefs.display_splash_screen)
-
-    # Feb-2017 - SvdB - For full file names
     show_full_file_names = Gtk.CheckButton()
     show_full_file_names.set_active(prefs.show_full_file_names)
 
@@ -398,10 +380,12 @@ def _view_prefs_panel():
     media_panel_width_spin = Gtk.SpinButton.new_with_range(editorpersistance.MEDIA_PANEL_WIDTH_MIN, editorpersistance.MEDIA_PANEL_WIDTH_MAX, 1)
     media_panel_width_spin.set_adjustment(spin_adj)
     media_panel_width_spin.set_numeric(True)
-    
+
+    show_bin_and_seq_titles = Gtk.CheckButton()
+    show_bin_and_seq_titles.set_active(prefs.show_bins_and_sequences_titles)
+
     row00 = _row(guiutils.get_two_column_box(Gtk.Label(label=_("Application window mode:")), window_mode_combo, PREFERENCES_LEFT))
     row9 = _row(guiutils.get_two_column_box(Gtk.Label(label=_("Force Language:")), force_language_combo, PREFERENCES_LEFT))
-    row1 = _row(guiutils.get_checkbox_row_box(display_splash_check, Gtk.Label(label=_("Display splash screen"))))
     row6 = _row(guiutils.get_checkbox_row_box(show_full_file_names, Gtk.Label(label=_("Show Full File names"))))
     row7 = _row(guiutils.get_two_column_box(Gtk.Label(label=_("Tracks Heights:")), tracks_combo, PREFERENCES_LEFT))
 
@@ -410,13 +394,14 @@ def _view_prefs_panel():
     row12 = _row(guiutils.get_two_column_box(Gtk.Label(label=_("Project panel width:")), project_panel_width_spin, PREFERENCES_LEFT))
     row11 = _row(guiutils.get_two_column_box(Gtk.Label(label=_("Filter Select panel width:")), filter_select_width_spin, PREFERENCES_LEFT))
     row14 = _row(guiutils.get_two_column_box(Gtk.Label(label=_("Media panel width:")), media_panel_width_spin, PREFERENCES_LEFT))
-    
+    row15 = _row(guiutils.get_checkbox_row_box(show_bin_and_seq_titles, Gtk.Label(label=_("Show Bins And Sequences Area Titles"))))
+
     vbox = Gtk.VBox(False, 2)
     vbox.pack_start(row00, False, False, 0)
     vbox.pack_start(row10, False, False, 0)
     vbox.pack_start(row9, False, False, 0)
-    vbox.pack_start(row1, False, False, 0)
     vbox.pack_start(row6, False, False, 0)
+    vbox.pack_start(row15, False, False, 0)
     vbox.pack_start(row7, False, False, 0)
     vbox.pack_start(row14, False, False, 0)
     vbox.pack_start(row13, False, False, 0)
@@ -425,10 +410,10 @@ def _view_prefs_panel():
     vbox.pack_start(Gtk.Label(), True, True, 0)
     
     guiutils.set_margins(vbox, 12, 0, 12, 12)
-
-    return vbox, (force_language_combo, display_splash_check, window_mode_combo, show_full_file_names,
+    
+    return vbox, (force_language_combo, window_mode_combo, show_full_file_names,
                   tracks_combo, project_panel_width_spin, edit_panel_width_spin, media_panel_width_spin,
-                  layout_monitor, filter_select_width_spin)
+                  layout_monitor, filter_select_width_spin, show_bin_and_seq_titles)
 
 
 
