@@ -76,6 +76,9 @@ FADE_LENGTH = "fade_length"                                 # Autofade composito
 TEXT_ENTRY = "text_entry"                                   # Text editor
 ROTOMASK = "rotomask"                                       # Displays info and launches rotomask window
 NO_KF_RECT = "no_keyframes_rect"                            # keyframeeditor.GeometryNoKeyframes, no keyframes here, machinery for creating this type GUI editors just assumes keyframes
+GRADIENT_TINT = "gradient_tint_editor"                      # editor for Gradient Tint, "frei0r.cairogradient" MLT filter 
+CROP_EDITOR = "crop_editor"                                 # editor for Crop filter
+ALPHA_SHAPE_EDITOR = "alpha_shape_editor"                   # editor for Alpha Shape filter
 NO_EDITOR = "no_editor"                                     # No editor displayed for property
 
 COMPOSITE_EDITOR_BUILDER = "composite_properties"           # Creates a single row editor for multiple properties of composite transition
@@ -519,8 +522,8 @@ def _get_color_selector(editable_property):
     color_button.connect("color-set", editable_property.color_selected)
 
     picker_button = Gtk.ToggleButton()
-    picker_button.set_image(Gtk.Image.new_from_icon_name(Gtk.STOCK_COLOR_PICKER, Gtk.IconSize.BUTTON))
-
+    gtkbuilder.button_set_image_icon_name(picker_button, Gtk.STOCK_COLOR_PICKER)
+    
     info_label = Gtk.Label()
     
     editable_property.picker_toggled_id = picker_button.connect("toggled", _color_selector_picker_toggled, editable_property, color_button, info_label)
@@ -904,6 +907,60 @@ def _create_filter_roto_geom_editor(filt, editable_properties, editor_name, trac
     vbox.kf_edit_geom_editor = kf_edit_geom_editor
     return vbox
 
+def _create_gradient_tint_editor(filt, editable_properties, editor_name, track, clip_index):
+    clip, filter_index, prop, property_index, args_str = editable_properties[0].used_create_params
+
+    kf_editable_property = propertyedit.GradientTintExtraEditorProperty(
+                                editable_properties[0].used_create_params, 
+                                editable_properties,
+                                track, 
+                                clip_index)
+
+    kf_edit_geom_editor = keyframeeditor.GradientTintGeometryEditor(kf_editable_property)
+    kf_edit_geom_editor.set_margin_bottom(4)
+
+    vbox = Gtk.VBox(False, 4)
+    vbox.pack_start(kf_edit_geom_editor, False, False, 0)
+    vbox.no_separator = True
+    vbox.kf_edit_geom_editor = kf_edit_geom_editor
+    return vbox
+
+def _create_crop_editor(filt, editable_properties, editor_name, track, clip_index):
+    clip, filter_index, prop, property_index, args_str = editable_properties[0].used_create_params
+
+    kf_editable_property = propertyedit.CropEditorProperty(
+                                editable_properties[0].used_create_params, 
+                                editable_properties,
+                                track, 
+                                clip_index)
+
+    kf_edit_geom_editor = keyframeeditor.CropGeometryEditor(kf_editable_property)
+    kf_edit_geom_editor.set_margin_bottom(4)
+
+    vbox = Gtk.VBox(False, 4)
+    vbox.pack_start(kf_edit_geom_editor, False, False, 0)
+    vbox.no_separator = True
+    vbox.kf_edit_geom_editor = kf_edit_geom_editor
+    return vbox
+
+def _create_alpha_shape_editor(filt, editable_properties, editor_name, track, clip_index):
+    clip, filter_index, prop, property_index, args_str = editable_properties[0].used_create_params
+
+    kf_editable_property = propertyedit.AlphaShapeRotatingGeometryProperty(
+                                editable_properties[0].used_create_params, 
+                                editable_properties,
+                                track, 
+                                clip_index)
+
+    kf_edit_geom_editor = keyframeeditor.AlphaShapeGeometryEditor(kf_editable_property)
+    kf_edit_geom_editor.set_margin_bottom(4)
+
+    vbox = Gtk.VBox(False, 4)
+    vbox.pack_start(kf_edit_geom_editor, False, False, 0)
+    vbox.no_separator = True
+    vbox.kf_edit_geom_editor = kf_edit_geom_editor
+    return vbox
+
 def _create_colorbox_editor(filt, editable_properties, editor_name, track, clip_index):
     colorbox_editor = extraeditors.ColorBoxFilterEditor(editable_properties)
     
@@ -1218,6 +1275,12 @@ EDITOR_ROW_CREATORS = { \
                                 _create_apply_filter_mask_motion_editor(filt, editable_properties, editor_name, track, clip_index),
     TEXT_ENTRY: lambda ep: _get_text_entry(ep),
     NO_KF_RECT: lambda ep : _get_no_kf_rect_geom_editor(ep),
-    FILTER_RECT_GEOM_EDITOR: lambda ep : _get_filter_rect_geom_editor(ep)
+    FILTER_RECT_GEOM_EDITOR: lambda ep : _get_filter_rect_geom_editor(ep),
+    GRADIENT_TINT:  lambda filt, editable_properties, editor_name, track, clip_index: \
+                                _create_gradient_tint_editor(filt, editable_properties, editor_name, track, clip_index),
+    CROP_EDITOR:  lambda filt, editable_properties, editor_name, track, clip_index: \
+                                _create_crop_editor(filt, editable_properties, editor_name, track, clip_index),
+    ALPHA_SHAPE_EDITOR:  lambda filt, editable_properties, editor_name, track, clip_index: \
+                                _create_alpha_shape_editor(filt, editable_properties, editor_name, track, clip_index) 
     }
 
