@@ -26,6 +26,7 @@ Modules provides functions that:
 import json
 
 import appconsts
+import animatedvalue
 from editorstate import current_sequence
 from editorstate import PROJECT
 import respaths
@@ -247,17 +248,8 @@ def single_value_keyframes_string_to_kf_array(keyframes_str, out_to_in_func):
     keyframes_str = keyframes_str.strip('"') # expressions have sometimes quotes that need to go away
     kf_tokens = keyframes_str.split(";")
     for token in kf_tokens:
-        sides = token.split(appconsts.KEYFRAME_DISCRETE_EQUALS_STR)
-        if len(sides) == 2:
-            kf_type = appconsts.KEYFRAME_DISCRETE
-        else:
-            sides = token.split(appconsts.KEYFRAME_SMOOTH_EQUALS_STR)
-            if len(sides) == 2:
-                kf_type = appconsts.KEYFRAME_SMOOTH
-            else:
-                sides = token.split(appconsts.KEYFRAME_LINEAR_EQUALS_STR)
-                kf_type = appconsts.KEYFRAME_LINEAR
-        
+        kf_type, sides = animatedvalue.parse_kf_token(token)
+
         # Find out saved keyframe type here.
         add_kf = (int(sides[0]), out_to_in_func(float(sides[1])), kf_type) # kf = (frame, value, type)
         new_keyframes.append(add_kf)
@@ -272,17 +264,7 @@ def geom_keyframes_value_string_to_opacity_kf_array(keyframes_str, out_to_in_fun
     keyframes_str = keyframes_str.strip('"') # expression have sometimes quotes that need to go away
     kf_tokens =  keyframes_str.split(";")
     for token in kf_tokens:
-        sides = token.split(appconsts.KEYFRAME_DISCRETE_EQUALS_STR)
-        if len(sides) == 2:
-            kf_type = appconsts.KEYFRAME_DISCRETE
-        else:
-            sides = token.split(appconsts.KEYFRAME_SMOOTH_EQUALS_STR)
-            if len(sides) == 2:
-                kf_type = appconsts.KEYFRAME_SMOOTH
-            else:
-                sides = token.split(appconsts.KEYFRAME_LINEAR_EQUALS_STR)
-                kf_type = appconsts.KEYFRAME_LINEAR
-                
+        kf_type, sides = animatedvalue.parse_kf_token(token)
         values = sides[1].split(':')
 
         add_kf = (int(sides[0]), out_to_in_func(float(values[2])), kf_type) # kf = (frame, opacity, type)
@@ -295,17 +277,8 @@ def geom_keyframes_value_string_to_geom_kf_array(keyframes_str, out_to_in_func):
     keyframes_str = keyframes_str.strip('"') # expression have sometimes quotes that need to go away
     kf_tokens =  keyframes_str.split(';')
     for token in kf_tokens:
-        sides = token.split(appconsts.KEYFRAME_DISCRETE_EQUALS_STR)
-        if len(sides) == 2:
-            kf_type = appconsts.KEYFRAME_DISCRETE
-        else:
-            sides = token.split(appconsts.KEYFRAME_SMOOTH_EQUALS_STR)
-            if len(sides) == 2:
-                kf_type = appconsts.KEYFRAME_SMOOTH
-            else:
-                sides = token.split(appconsts.KEYFRAME_LINEAR_EQUALS_STR)
-                kf_type = appconsts.KEYFRAME_LINEAR
-                
+        kf_type, sides = animatedvalue.parse_kf_token(token)
+            
         values = sides[1].split(':')
         pos = values[0].split('/')
         size = values[1].split('x')
@@ -322,17 +295,8 @@ def rect_keyframes_value_string_to_geom_kf_array(keyframes_str, out_to_in_func):
     keyframes_str = keyframes_str.strip('"') # expression have sometimes quotes that need to go away
     kf_tokens =  keyframes_str.split(';')
     for token in kf_tokens:
-        sides = token.split(appconsts.KEYFRAME_DISCRETE_EQUALS_STR)
-        if len(sides) == 2:
-            kf_type = appconsts.KEYFRAME_DISCRETE
-        else:
-            sides = token.split(appconsts.KEYFRAME_SMOOTH_EQUALS_STR)
-            if len(sides) == 2:
-                kf_type = appconsts.KEYFRAME_SMOOTH
-            else:
-                sides = token.split(appconsts.KEYFRAME_LINEAR_EQUALS_STR)
-                kf_type = appconsts.KEYFRAME_LINEAR
-                
+        kf_type, sides = animatedvalue.parse_kf_token(token)
+
         values = sides[1].split(' ')
         x = values[0]
         y = values[1]
@@ -372,17 +336,8 @@ def rotating_geom_keyframes_value_string_to_geom_kf_array(keyframes_str, out_to_
     keyframes_str = keyframes_str.strip('"') # expression have sometimes quotes that need to go away
     kf_tokens =  keyframes_str.split(';')
     for token in kf_tokens:
-        sides = token.split(appconsts.KEYFRAME_DISCRETE_EQUALS_STR)
-        if len(sides) == 2:
-            kf_type = appconsts.KEYFRAME_DISCRETE
-        else:
-            sides = token.split(appconsts.KEYFRAME_SMOOTH_EQUALS_STR)
-            if len(sides) == 2:
-                kf_type = appconsts.KEYFRAME_SMOOTH
-            else:
-                sides = token.split(appconsts.KEYFRAME_LINEAR_EQUALS_STR)
-                kf_type = appconsts.KEYFRAME_LINEAR
-                
+        kf_type, sides = animatedvalue.parse_kf_token(token)
+            
         values = sides[1].split(':')
         frame = int(sides[0])
         # Get values and convert "frei0r.cairoaffineblend" values to editor values
@@ -405,7 +360,7 @@ def filter_rotating_geom_keyframes_value_string_to_geom_kf_array(keyframes_str,
     
     new_keyframes = []
 
-    keyframes_str = keyframes_str.strip('"') # expression have sometimes quotes that need to go away
+    keyframes_str = keyframes_str.strip('"') # expressions have sometimes quotes that need to go away
     kf_tokens =  keyframes_str.split(';')
     for token in kf_tokens:
         frame, value, kf_type = get_token_frame_value_type(token)
@@ -417,10 +372,10 @@ def filter_rotating_geom_keyframes_value_string_to_geom_kf_array(keyframes_str,
         y_scale = float(values[3]) / float(screen_height)
 
         # keyframecanvas.RotatingEditCanvas editor considers x anf y values position of
-        # anchor point around whicth image is rotated.
+        # anchor point around which image is rotated.
         #
-        # MLT porprty "affine.transition.rect" considers x anf y values amount translation
-        # and rotate image automatically around its tramslated center point.
+        # MLT property "affine.transition.rect" considers x and y values amount translation
+        # and rotate image automatically around its translated center point.
         #
         # So the we need to add half of width and height to mlt values AND 
         # additional linear correction based on applied scaling when creating
@@ -430,7 +385,7 @@ def filter_rotating_geom_keyframes_value_string_to_geom_kf_array(keyframes_str,
         y = float(values[1]) + float(screen_height) / 2.0 + \
             ((y_scale * screen_height) - screen_height) / 2.0
 
-        rotation = float(values[4]) # degrees al arund
+        rotation = float(values[4]) # degrees all around
         opacity = 100 # not edited
 
         source_rect = [x,y,x_scale,y_scale,rotation]
@@ -439,6 +394,58 @@ def filter_rotating_geom_keyframes_value_string_to_geom_kf_array(keyframes_str,
         
     return new_keyframes
 
+def gradient_tint_geom_keyframes_value_string_to_geom_kf_array(keyframes_str, out_to_in_func):
+    screen_width = current_sequence().profile.width()
+    screen_height = current_sequence().profile.height()
+
+    new_keyframes = []
+
+    keyframes_str = keyframes_str.strip('"') # expressions have sometimes quotes that need to go away
+    kf_tokens =  keyframes_str.split(';')
+
+    for token in kf_tokens:
+        frame, value, kf_type = get_token_frame_value_type(token)
+        values = value.split(':')
+        values_floats = [float(x) for x in values]
+        start_x = values_floats[0] * screen_width
+        start_y = values_floats[1] * screen_height
+        end_x = values_floats[2] * screen_width
+        end_y =  values_floats[3] * screen_height
+        add_kf = (int(frame), (start_x, start_y, end_x, end_y), kf_type)
+
+        new_keyframes.append(add_kf)
+    
+    return new_keyframes
+
+def crop_geom_keyframes_value_string_to_geom_kf_array(keyframes_str, out_to_in_func):
+    screen_width = current_sequence().profile.width()
+    screen_height = current_sequence().profile.height()
+
+    new_keyframes = []
+
+    keyframes_str = keyframes_str.strip('"') # expressions have sometimes quotes that need to go away
+    kf_tokens =  keyframes_str.split(';')
+
+    for token in kf_tokens:
+        frame, value, kf_type = get_token_frame_value_type(token)
+        values = value.split(':')
+        values_floats = [float(x) for x in values]
+        left = values_floats[0] * screen_width
+        right = (1.0 - values_floats[1]) * screen_width
+        top = values_floats[2] * screen_height
+        bottom = (1.0 - values_floats[3]) * screen_height
+        x = left
+        y = top
+        w = right - left
+        h = bottom - top
+        dummy_opacity = 1.0 # historical artifat that has not been refactored out, used geom editor 
+                            # keyframeditcanvas.BoxEditCanvas assumes opacity to be there.
+        add_kf = (int(frame), [x, y, w, h], dummy_opacity,  kf_type)
+
+        new_keyframes.append(add_kf)
+
+    return new_keyframes
+
 def rotomask_json_value_string_to_kf_array(keyframes_str, out_to_in_func):
     new_keyframes = []
     json_obj = json.loads(keyframes_str)
@@ -450,44 +457,19 @@ def rotomask_json_value_string_to_kf_array(keyframes_str, out_to_in_func):
     return sorted(new_keyframes, key=lambda kf_tuple: kf_tuple[0]) 
 
 def get_token_frame_value_type(token):
-    sides = token.split(appconsts.KEYFRAME_DISCRETE_EQUALS_STR)
-    if len(sides) == 2:
-        kf_type = appconsts.KEYFRAME_DISCRETE
-    else:
-        sides = token.split(appconsts.KEYFRAME_SMOOTH_EQUALS_STR)
-        if len(sides) == 2:
-            kf_type = appconsts.KEYFRAME_SMOOTH
-        else:
-            sides = token.split(appconsts.KEYFRAME_LINEAR_EQUALS_STR)
-            kf_type = appconsts.KEYFRAME_LINEAR
-                
+    kf_type, sides = animatedvalue.parse_kf_token(token)
+
     # returns (frame, value, kf_type)
     return(sides[0], sides[1], kf_type)
 
 # ----------------------------------------------------------------------------- AFFINE BLEND
 def _get_roto_geom_frame_value(token):
-    sides = token.split(appconsts.KEYFRAME_DISCRETE_EQUALS_STR)
-    if len(sides) == 2:
-        kf_type = appconsts.KEYFRAME_DISCRETE
-    else:
-        sides = token.split(appconsts.KEYFRAME_SMOOTH_EQUALS_STR)
-        if len(sides) == 2:
-            kf_type = appconsts.KEYFRAME_SMOOTH
-        else:
-            sides = token.split(appconsts.KEYFRAME_LINEAR_EQUALS_STR)
-            kf_type = appconsts.KEYFRAME_LINEAR
+    kf_type, sides = animatedvalue.parse_kf_token(token)
     
     return(sides[0], sides[1], kf_type)
 
 def _get_eq_str(kf_type):
-    if kf_type == appconsts.KEYFRAME_DISCRETE:
-        eq_str = appconsts.KEYFRAME_DISCRETE_EQUALS_STR
-    elif kf_type == appconsts.KEYFRAME_SMOOTH:
-        eq_str = appconsts.KEYFRAME_SMOOTH_EQUALS_STR
-    else:
-        eq_str = appconsts.KEYFRAME_LINEAR_EQUALS_STR
-    
-    return eq_str
+    return animatedvalue.TYPE_TO_EQ_STRING[kf_type]
     
 def rotating_ge_write_out_keyframes(ep, keyframes):
     x_val = ""
