@@ -65,11 +65,7 @@ def render_progress_dialog(callback, parent_window, frame_rates_match=True):
     passed_box.pack_start(Gtk.Label(), True, True, 0)
 
     if frame_rates_match == False:
-        # Aug-2019 - SvdB - BB
-        if guiutils.double_icon_size():
-            warning_icon = Gtk.Image.new_from_icon_name("dialog-warning", Gtk.IconSize.DND)
-        else:
-            warning_icon = Gtk.Image.new_from_icon_name("dialog-warning", Gtk.IconSize.MENU)
+        warning_icon = Gtk.Image.new_from_icon_name("dialog-warning", Gtk.IconSize.MENU)
         warning_text = Gtk.Label(label=_("Project and Render Profile FPS values are not same. Rendered file may have A/V sync issues."))
         warning_box = Gtk.HBox(False, 2)
         warning_box.pack_start(warning_icon,False, False, 0)
@@ -1299,14 +1295,12 @@ class RenderArgsPanelSmall():
         self.use_args_check.connect("toggled", self.use_args_toggled)
 
         self.opts_save_button = Gtk.Button()
-        icon = Gtk.Image.new_from_icon_name("document-save", Gtk.IconSize.MENU)
-        self.opts_save_button.set_image(icon)
+        gtkbuilder.button_set_image_icon_name(self.opts_save_button, "document-save")
         self.opts_save_button.connect("clicked", lambda w: save_args_callback())
         self.opts_save_button.set_sensitive(False)
     
         self.opts_load_button = Gtk.Button()
-        icon = Gtk.Image.new_from_icon_name("document-open", Gtk.IconSize.MENU)
-        self.opts_load_button.set_image(icon)
+        gtkbuilder.button_set_image_icon_name(self.opts_load_button, "document-open")
         self.opts_load_button.connect("clicked", lambda w: load_args_callback())
 
         self.open_in_bin = Gtk.CheckButton()
