@@ -682,6 +682,17 @@ class Sequence:
                 new_compositors.append(clone_compositor)
         self.compositors = new_compositors
 
+    def get_clone_compositors(self, track_delta, pos_delta=0):
+        # Used when cloning compositors to change track count by cloning sequence
+        clone_compositors = []
+        for compositor in self.compositors:
+            clone_compositor = self.create_compositor(compositor.type_id)
+            clone_compositor.clone_properties(compositor)
+            clone_compositor.set_in_and_out(compositor.clip_in + pos_delta, compositor.clip_out + pos_delta)
+            clone_compositor.transition.set_tracks(compositor.transition.a_track + track_delta, compositor.transition.b_track + track_delta)
+            clone_compositors.append(clone_compositor)
+        return clone_compositors
+
     def _create_and_plant_clone_compositor_for_sequnce_clone(self, old_compositor, track_delta):      
         # Create and plant new compositor
         compositor = self.create_compositor(old_compositor.type_id)
@@ -719,7 +730,6 @@ class Sequence:
         self.compositors = []
 
     def add_full_track_compositors(self):
-        #print("Adding full track compositors")
         
         for i in range(self.first_video_index, len(self.tracks) - 1):
             track = self.tracks[i]
@@ -736,7 +746,6 @@ class Sequence:
             self.add_compositor(compositor)
         
         self.restack_compositors()
-        #print("Adding full track compositors DONE")
     
     def get_compositor_for_destroy_id(self, destroy_id):
         for comp in self.compositors:
@@ -766,6 +775,11 @@ class Sequence:
             if comp.transition.b_track == track_index:
                 track_compositors.append(comp)
         return track_compositors
+
+    def print_compositors(self):
+        for comp in self.compositors:
+            print(comp.__dict__)
+            print(comp.transition.a_track, comp.transition.b_track)
             
     # -------------------------- monitor clip, trimming display, output mode and hidden track
     def display_monitor_clip(self, path, pattern_producer_data=None, ttl=None):
@@ -1030,6 +1044,46 @@ class Sequence:
                 
         return cut_frame
 
+    def find_next_mark_or_marker(self, tline_frame):
+        result_frame = -1
+        
+        if self.tractor.mark_in > tline_frame:
+            result_frame = self.tractor.mark_in
+        if self.tractor.mark_out > tline_frame:
+            if result_frame == -1:
+                result_frame = self.tractor.mark_out
+            elif self.tractor.mark_out < result_frame:
+                result_frame = self.tractor.mark_out 
+        
+        for name, frame in self.markers:
+            if frame > tline_frame:
+                if result_frame == -1:
+                    result_frame = frame
+                elif frame < result_frame:
+                    result_frame = frame
+        
+        return result_frame
+
+    def find_prev_mark_or_marker(self, tline_frame):
+        result_frame = -1
+        
+        if self.tractor.mark_in < tline_frame:
+            result_frame = self.tractor.mark_in
+        if self.tractor.mark_out < tline_frame:
+            if result_frame == -1:
+                result_frame = self.tractor.mark_out
+            elif self.tractor.mark_out > result_frame:
+                result_frame = self.tractor.mark_out 
+        
+        for name, frame in self.markers:
+            if frame < tline_frame:
+                if result_frame == -1:
+                    result_frame = frame
+                elif frame > result_frame:
+                    result_frame = frame
+        
+        return result_frame
+
     def find_parent_clip_for_clip_start(self, parent_track, clip_start_frame):
         parent_clip = None
         last_pos_diff = None
@@ -1305,7 +1359,7 @@ class Sequence:
 
         return None
 
-    # ----------------------------------- info pronts
+    # ----------------------------------- info prints
     def print_all(self):
         print("------------------------######")
         for i in range(0, len(self.tracks)):
@@ -1330,7 +1384,10 @@ class Sequence:
         for i in range(0, track.count()):
             clip = track.get_clip(i)
             print(i, " in:", clip.get_in()," out:", clip.get_out())
-
+        
+        print("print_track done")
+            
+            
     def print_compositors(self):
         for compositor in self.compositors:
             print("---")
