@@ -18,6 +18,9 @@
     along with Flowblade Movie Editor.  If not, see <http://www.gnu.org/licenses/>.
 """
 
+
+from gi.repository import Gdk, Gtk
+
 # Apr-2017 - SvdB - Functions to scan available shortcut files, validate and load them
 import collections
 import os
@@ -49,6 +52,52 @@ _mod_names = {}
 _gtk_mod_names = {}
 _editable = False
 
+
+
+# Copied from keyevents.py so that we are using same code to 
+def get_shortcut_action(event):
+    # Get the name of the key pressed.
+    key_name = Gdk.keyval_name(event.keyval).lower()
+
+    # Check if this key is in the dictionary.
+    state = event.get_state()
+    # Now we have a key and a key state we need to check if it is a shortcut.
+    # If it IS a shortcut we need to determine what action to take.
+    if key_name in _keyboard_actions:
+        # Now get the associated dictionary
+        _secondary_dict = _keyboard_actions[key_name]
+        # In order to check for all available combinations of Ctrl+Alt etc (CTRL+ALT should be the same as ALT_CTRL)
+        # we do a SORT on the string. So both CTRL+ALT and ALT+CTRL will become +ACLLRTT and can be easily compared.
+        modifier = ""
+        if state & Gdk.ModifierType.CONTROL_MASK:
+            modifier = "CTRL"
+        if state & Gdk.ModifierType.MOD1_MASK:
+            if modifier != "":
+                modifier = modifier + "+"
+            modifier = modifier + "ALT"
+        if state & Gdk.ModifierType.SHIFT_MASK:
+            if modifier != "":
+                modifier = modifier + "+"
+            modifier = modifier + "SHIFT"
+        # CapsLock is used as an equivalent to SHIFT, here
+        if state & Gdk.ModifierType.LOCK_MASK:
+            if modifier != "":
+                modifier = modifier + "+"
+            modifier = modifier + "SHIFT"
+        # Set to None if no modifier found
+        if modifier == "":
+            modifier = 'None'
+        try:
+            action = _secondary_dict[''.join(sorted(re.sub(r'[\s]','',modifier.lower())))]
+        except:
+            try:
+                action = _secondary_dict[''.join(sorted(re.sub(r'[\s]','','Any'.lower())))]
+            except:
+                action = 'None'
+        return action
+    # We didn't find an action, so return nothing.
+    return 'None'
+
 def load_shortcut_files():
     global shortcut_files, shortcut_files_display_names
     default_shortcuts_file_found = False
@@ -149,9 +198,6 @@ def set_keyboard_shortcuts():
     except:
         print("Error opening shortcuts file:" + prefs.shortcuts)
 
-    #_print_shortcuts()
-
-
 def update_custom_shortcuts():
     # If new shortcuts have been added and user is using custom shortcuts when updating, we need to update custom shortcuts.
     custom_files = os.listdir(userfolders.get_data_dir() + "/" + appconsts.USER_SHORTCUTS_DIR)
@@ -182,6 +228,32 @@ def _update_custom_xml_file_nodes_to_default(custom_xml_file_path):
         print("Writing ", custom_xml_file_path)
         pref_shortcuts.write(custom_xml_file_path)
 
+def change_single_shortcut(code, event, shortcut_label):
+    key_val_name = Gdk.keyval_name(event.keyval).lower()
+    
+    mods_list = []
+    state = event.get_state()
+    if state & Gdk.ModifierType.CONTROL_MASK:
+        mods_list.append("CTRL")
+    if state & Gdk.ModifierType.MOD1_MASK:
+        mods_list.append("ALT")
+        
+    if state & Gdk.ModifierType.SHIFT_MASK:
+        mods_list.append("SHIFT")
+    elif state & Gdk.ModifierType.LOCK_MASK:     # CapsLock is used as an equivalent to SHIFT.
+        mods_list.append("SHIFT")
+
+    shortcut_info_str = get_shortcut_info_for_keyname_and_modlist(key_val_name, mods_list)
+    if is_blocked_shortcut(key_val_name, mods_list):
+        return shortcut_info_str
+
+    shortcut_label.set_text(shortcut_info_str)
+
+    change_custom_shortcut(code, key_val_name, mods_list)
+    set_keyboard_shortcuts()
+
+    return None
+    
 # code -> xml.etree.ElementTree.Element
 def _get_events_dict(xml_root):
     events_dict = {}
@@ -317,7 +389,8 @@ def get_shortcut_info(root, code):
                 if mod_name != "":
                     mod_name = mod_name + " + "
                 return (mod_name + _key_names[event.text], _keyboard_action_names[code]) 
-    except:
+    except Exception as e:
+        print("Exception: ", e)
         print("error in get_shortcut_info, event.text:", event.text)
         pass
 
@@ -398,7 +471,7 @@ def _set_keyboard_action_names():
     _keyboard_action_names['switch_monitor'] = _("Switch Monitor Source")
     _keyboard_action_names['display_clip_in_monitor'] = _("Display Clip In Monitor")
     _keyboard_action_names['display_sequence_in_monitor'] = _("Display Sequence In Monitor")
-    _keyboard_action_names['add_marker'] = _("Add Mark")
+    _keyboard_action_names['add_marker'] = _("Add Marker")
     _keyboard_action_names['enter_edit'] =  _("Complete Keyboard Trim Edit")
     _keyboard_action_names['nudge_back'] =  _("Nudge Move Selection Back 1 Frame")
     _keyboard_action_names['nudge_forward'] =  _("Nudge Move Selection Forward 1 Frame")
@@ -421,6 +494,11 @@ def _set_keyboard_action_names():
     _keyboard_action_names['monitor_show_video'] = _('Show Video')
     _keyboard_action_names['monitor_show_scope'] = _('Show Vectorscope')
     _keyboard_action_names['monitor_show_rgb'] = _('Show RGB Parade')
+    _keyboard_action_names['set_length'] = _('Set Clip Length')
+    _keyboard_action_names['clear_sync_relation'] = _('Clear Clip Sync Relation')
+    _keyboard_action_names['toggle_audio_mute'] = _('Toggle Clip Audio Mute')
+    _keyboard_action_names['set_sync_relation'] = _('Set Clip Sync Relation')
+    _keyboard_action_names['mark_selection_range'] = _('Mark Selection Range')
 
 def _set_key_names():
     global _key_names, _mod_names, _gtk_mod_names
