@@ -24,6 +24,7 @@ from gi.repository import Gtk, Gdk
 import editorpersistance
 import editorstate
 import dialogutils
+import gtkevents
 import guicomponents
 import guiutils
 import shortcuts
@@ -184,7 +185,7 @@ def _get_dynamic_kb_shortcuts_panel(xml_file, tool_set):
     trimming_box.pack_start(_get_kb_row(_("Right Arrow"), _("Next Frame Trim Edit")), False, False, 0)
     trimming_box.pack_start(_get_kb_row(_("Shift + Left Arrow "), _("Back 10 Frames Trim Edit")), False, False, 0)
     trimming_box.pack_start(_get_kb_row(_("Shift + Right Arrow"), _("Forward 10 Frames Trim Edit")), False, False, 0)
-    trimming_box.pack_start(_get_kb_row(_("ENTER"),  _("Complete Keyboard Trim Edit")), False, False, 0) #  _get_dynamic_kb_row(root_node, "enter_edit"), False, False, 0)
+    trimming_box.pack_start(_get_kb_row(_("ENTER"),  _("Init / Complete Keyboard Trim Edit")), False, False, 0) #  _get_dynamic_kb_row(root_node, "enter_edit"), False, False, 0)
     trimming = guiutils.get_named_frame(_("Trimming"), trimming_box)
 
     sync_box = Gtk.VBox()
@@ -198,6 +199,7 @@ def _get_dynamic_kb_shortcuts_panel(xml_file, tool_set):
     marks_box = Gtk.VBox()
     marks_box.pack_start(_get_dynamic_kb_row(root_node, "mark_in"), False, False, 0)
     marks_box.pack_start(_get_dynamic_kb_row(root_node, "mark_out"), False, False, 0)
+    marks_box.pack_start(_get_dynamic_kb_row(root_node, "mark_selection_range"), False, False, 0)
     marks_box.pack_start(_get_dynamic_kb_row(root_node, "to_mark_in"), False, False, 0)
     marks_box.pack_start(_get_dynamic_kb_row(root_node, "to_mark_out"), False, False, 0)
     marks_box.pack_start(_get_dynamic_kb_row(root_node, "clear_io_marks"), False, False, 0)
@@ -237,7 +239,7 @@ def _get_dynamic_kb_shortcuts_panel(xml_file, tool_set):
     kfs_vbox = Gtk.VBox()
     kfs_vbox.pack_start(_get_kb_row(_("Control + C"), _("Copy Keyframe Value")), False, False, 0)
     kfs_vbox.pack_start(_get_kb_row(_("Control + V"), _("Paste Keyframe Value")), False, False, 0)
-    kfs_vbox.pack_start(_get_kb_row(_("Control + Mouse Drag"), _("Move all keyframes after selected")), False, False, 0)
+    kfs_vbox.pack_start(_get_kb_row(_("Shift + Mouse Drag"), _("Move all keyframes after selected")), False, False, 0)
     kfs = guiutils.get_named_frame(_("Keyframe and Geometry Editor"), kfs_vbox)
     
     geom_vbox = Gtk.VBox()
@@ -387,8 +389,9 @@ class KBShortcutEditor:
         item_vbox.pack_start(input_label, True, True, 0)
            
         self.kb_input = Gtk.EventBox()
-        self.kb_input.add_events(Gdk.EventMask.KEY_PRESS_MASK)
-        self.kb_input.connect("key-press-event", lambda w,e: self.kb_input_listener(e))
+        self.kb_input.add_events(Gdk.EventMask.KEY_PRESS_MASK)    
+        self.global_key_controller = gtkevents.KeyPressEventAdapter(self.kb_input, self.kb_input_listener)
+        
         self.kb_input.set_can_focus(True)
         self.kb_input.add(item_vbox)
 
@@ -415,7 +418,7 @@ class KBShortcutEditor:
         self.kb_input.grab_focus()
         KBShortcutEditor.input_listener = self
 
-    def kb_input_listener(self, event):
+    def kb_input_listener(self, widget, event):
 
         
         # Gdk.KEY_Return ? Are using this as clear and make "exit trim edit" not settable?
