@@ -70,35 +70,26 @@ def split_audio_synched_from_clips_list(clips, track):
     item_id = "not actually used"
     split_actions_data = []
     split_actions = []
+
     for clip in clips:
         # We're using the existing function to do this need x for clip frame to use it
         index = track.clips.index(clip)
         frame = track.clip_start(index)
         x = tlinewidgets._get_frame_x(frame)
 
-        popup_data = (clip, track, item_id, x)
-
         # We can only split audio from unmuted clips because splitting mutes audio
         # and we want to avoid splitting audio twice.
         if clip.mute_filter == None:
-            split_action, parent_clip, child_clip, child_clip_track = _get_split_audio_edit_action(popup_data)
+            split_action = _create_sync_split_action_lambda(clip, track) #:lambda : get_synched_split_action_for_clip_and_track(clip, track)
             split_actions.append(split_action)
-            split_actions_data.append((parent_clip, child_clip, child_clip_track))
-    
-    # We need to do split action before creating set sync actio0ns because we need a clip on timeline 
+
+    # We need to do split action before creating set sync actions because we need a clip on timeline 
     # to actually sync with.
     split_consolidated_action = edit.ConsolidatedEditAction(split_actions)
     split_consolidated_action.do_consolidated_edit()
 
-    set_sync_actions = []
-    for split_data in split_actions_data:
-        parent_clip, child_clip, child_clip_track = split_data
-        
-        sync_action = _get_set_sync_action(child_clip_track, child_clip, parent_clip, track)
-        set_sync_actions.append(sync_action)
-
-    sync_consolidated_action = edit.ConsolidatedEditAction(set_sync_actions)
-    sync_consolidated_action.do_consolidated_edit()
+def _create_sync_split_action_lambda(clip, track):
+    return lambda : get_synched_split_action_for_clip_and_track(clip, track)
 
 def sync_menu_launch_pressed(launcher, widget, event):
     guipopover.sync_menu_show(launcher, widget, _sync_property_item_activated, _sync_split_property_activated, _auto_sync_split_menu_item_item_activated)
@@ -112,7 +103,9 @@ def _sync_property_item_activated(action, event, msg):
         editorpersistance.prefs.sync_dualtrim = new_state
     elif msg == "showsync":
         editorpersistance.prefs.show_sync = new_state
-        
+    elif msg == "autotrimsingle":
+        editorpersistance.prefs.auto_sync_single_childs_on_trim = new_state
+
     action.set_state(GLib.Variant.new_boolean(new_state))
 
 def _sync_split_property_activated(action, variant):
@@ -141,7 +134,6 @@ def _get_set_sync_action(child_clip_track, child_clip, parent_clip, parent_track
             "parent_track":parent_track}
     action = edit.set_sync_action(data)
     return action
-    #action.do_edit()
     
 def split_audio(popup_data):
     clip, track, item_id, x = popup_data
@@ -171,7 +163,7 @@ def split_audio_from_clips_list(clips, track):
         if clip.mute_filter == None:
             action, clip, audio_clip, to_track = _get_split_audio_edit_action(popup_data)
             actions_list.append(action)
-    
+
     consolidated_action = edit.ConsolidatedEditAction(actions_list)
     consolidated_action.do_consolidated_edit()
 
@@ -188,7 +180,7 @@ def _get_split_audio_edit_action(popup_data):
         if to_track_id < 1:
             to_track_id = 1
         to_track = current_sequence().tracks[to_track_id]
-        
+
     press_frame = tlinewidgets.get_frame(x)
     index = current_sequence().get_clip_index(track, press_frame)
     frame = track.clip_start(index)
@@ -214,7 +206,7 @@ def get_synched_split_action_for_clip_and_track(clip, track):
         if to_track_id < 1:
             to_track_id = 1
         to_track = current_sequence().tracks[to_track_id]
-        
+    
     index = track.clips.index(clip)
     frame = track.clip_start(index)
 
@@ -278,10 +270,30 @@ def clear_track_clips_sync(child_track):
 
     data = {"child_track":child_track,
             "orig_sync_data":orig_sync_data}
-    
+
     action = edit.clear_track_sync_action(data)
     action.do_edit()
 
+def set_box_clips_sync(box_selection):
+    parent_track, parent_track_selection = box_selection.get_center_most_sync_track()
+    
+    # Get parent clip. No edit actions for missing parent clip on parent track on blank clips.
+    # TODO: Add info window.
+    try:
+        parent_clip = parent_track.clips[parent_track_selection.selected_range_in]
+    except:
+        return
+    if parent_clip.is_blanck_clip == True:
+        return
+
+    parent_clip = parent_track.clips[parent_track_selection.selected_range_in]
+    tracks_orig_sync_data, tracks_new_sync_data = resync.get_box_selection_resync_action_data(box_selection, parent_track, parent_clip)
+    
+    data = {"orig_sync_data":tracks_orig_sync_data,
+            "new_sync_data":tracks_new_sync_data}
+    
+    action = edit.set_box_selection_sync_action(data)
+    action.do_edit()
 
 # ---------------------------------------------- sync parent clips
 def init_select_master_clip(popup_data):
@@ -299,13 +311,26 @@ def init_select_master_clip(popup_data):
 
         parent_selection_data = (CHILD_SELECTION_SINGLE, clip, child_index, track)
     except TypeError:
-        # This is from multi selection that does not porvide same data as single selection.
+        # This is from multi selection that does not provide same data as single selection.
         parent_selection_data = (CHILD_SELECTION_MULTIPLE, movemodes.selected_range_in, movemodes.selected_range_out, track)
         
     gdk_window = gui.tline_display.get_parent_window()
     gdk_window.set_cursor(Gdk.Cursor.new_for_display(Gdk.Display.get_default(), Gdk.CursorType.TCROSS))
     editorstate.edit_mode = editorstate.SELECT_PARENT_CLIP
 
+def init_select_master_clip_from_keyevent():
+    global parent_selection_data
+    if movemodes.selected_track != -1:
+        child_index = movemodes.selected_range_in
+        track = current_sequence().tracks[movemodes.selected_track]
+        clip = track.clips[child_index]
+
+        parent_selection_data = (CHILD_SELECTION_MULTIPLE, movemodes.selected_range_in, movemodes.selected_range_out, track)
+        gdk_window = gui.tline_display.get_parent_window()
+        gdk_window.set_cursor(Gdk.Cursor.new_for_display(Gdk.Display.get_default(), Gdk.CursorType.TCROSS))
+        editorstate.edit_mode = editorstate.SELECT_PARENT_CLIP
+        gui.editor_window.tline_cursor_manager.tline_cursor_enter(None)
+
 def select_sync_parent_mouse_pressed(event, frame):
    
     global parent_selection_data
@@ -363,8 +388,8 @@ def _set_sync_parent_clip_multi(event, frame):
     sel_type,  selected_range_in, selected_range_out, child_clip_track = parent_selection_data
     parent_track = tlinewidgets.get_track(event.y)
     if parent_track == None:
-        return 
-    
+        return
+
     child_clips = []
     for i in range(selected_range_in, selected_range_out + 1):
         child_clips.append(child_clip_track.clips[i])
@@ -472,7 +497,15 @@ def resync_selected_track(selected_track):
 
 def clear_sync_relation(popup_data):
     clip, track, item_id, x = popup_data
+    do_clear_sync_relation(clip, track)
 
+def clear_sync_relation_from_keyevent():
+    if movemodes.selected_track != -1:
+        track = current_sequence().tracks[movemodes.selected_track]
+        clip = track.clips[movemodes.selected_range_in]
+        do_clear_sync_relation(clip, track)
+
+def do_clear_sync_relation(clip, track):
     data = {"child_clip":clip,
             "child_track":track}
     action = edit.clear_sync_action(data)
