@@ -68,7 +68,7 @@ COPY_PASTE_DATA_COMPOSITOR_PROPERTIES = appconsts.COPY_PASTE_DATA_COMPOSITOR_PRO
 
 
 # --------------------------- module funcs
-def _get_new_clip_from_clip_monitor():
+def _get_new_clip_from_clip_monitor(force_range=True):
     """
     Creates and returns new clip from current clip monitor clip
     with user set in and out points.
@@ -91,10 +91,11 @@ def _get_new_clip_from_clip_monitor():
     new_clip.mark_out = MONITOR_MEDIA_FILE().mark_out
     new_clip.name = MONITOR_MEDIA_FILE().name
 
-    if new_clip.mark_in == -1:
-         new_clip.mark_in = 0
-    if new_clip.mark_out == -1:
-        new_clip.mark_out = new_clip.get_length() - 1 #-1 == out inclusive
+    if force_range == True:
+        if new_clip.mark_in == -1:
+             new_clip.mark_in = 0
+        if new_clip.mark_out == -1:
+            new_clip.mark_out = new_clip.get_length() - 1 #-1 == out inclusive
 
     return new_clip
 
@@ -181,7 +182,7 @@ def _can_do_cut():
 def sequence_split_pressed():
     """
     Intention of this method is to split a sequence at the current position,
-    reduce it to the the clips on the left side of the cut and move the remains
+    reduce it to the clips on the left side of the cut and move the remains
     on the right side of the cut to a newly created sequence that is then
     opened.
     """
@@ -624,12 +625,29 @@ def three_point_overwrite_pressed():
     range_end_frame = out_start + out_clip.clip_out - out_clip.clip_in
     range_length = range_end_frame - range_start_frame + 1 # calculated end is incl.
 
-    over_clip = _get_new_clip_from_clip_monitor()
+    over_clip = _get_new_clip_from_clip_monitor(False)
     if over_clip == None:
         no_monitor_clip_info(gui.editor_window.window)
         return
-    over_length = over_clip.mark_out - over_clip.mark_in + 1 # + 1 out incl ?????????? what if over_clip.mark_out == -1  ?????????? 
-    
+
+    if over_clip.mark_in == -1 and over_clip.mark_out == -1:
+        over_clip.mark_in = 0
+        over_clip.mark_out = over_clip.get_length() - 1 #-1 == out inclusive
+    elif over_clip.mark_out == -1:
+        if range_length > over_clip.get_length() - over_clip.mark_in:
+            monitor_clip_too_short(gui.editor_window.window)
+            return
+        else:
+            over_clip.mark_out = over_clip.mark_in + over_clip.get_length() - 1
+    elif over_clip.mark_in == -1:
+        if range_length <= over_clip.mark_out:
+            # Use mark out for monitor clip
+            over_clip.mark_in = over_clip.mark_out - range_length + 1
+        else:
+            monitor_clip_too_short(gui.editor_window.window)
+            return
+
+    over_length = over_clip.mark_out - over_clip.mark_in + 1 # + 1 out incl
     if over_length < range_length:
         monitor_clip_too_short(gui.editor_window.window)
         return
@@ -666,22 +684,37 @@ def range_overwrite_pressed():
         return
 
     # Get over clip and check it overwrite range area
-    over_clip = _get_new_clip_from_clip_monitor()
+    over_clip = _get_new_clip_from_clip_monitor(False)
     if over_clip == None:
         no_monitor_clip_info(gui.editor_window.window)
         return
 
-    # tractor is has mark in and mark
+    # Tractor has mark in and mark out.
     mark_in_frame = current_sequence().tractor.mark_in
     mark_out_frame = current_sequence().tractor.mark_out
-    
+
     # Case timeline marked
-    if mark_in_frame != -1 and mark_out_frame != -1:
+    if mark_in_frame != -1 and mark_out_frame != -1:    
         range_length = mark_out_frame - mark_in_frame + 1 # end is incl.
         if over_clip.mark_in == -1:
-            # This actually should never be hit because mark in and mark out seem to first and last frame if nothing set
-            show_three_point_edit_not_defined()
-            return
+            if over_clip.mark_out == -1:
+                # not enough data
+                show_three_point_edit_not_defined()
+                return
+            else:
+                if range_length <= over_clip.mark_out:
+                    # Use mark out for monitor clip
+                    over_clip.mark_in = over_clip.mark_out - range_length + 1
+                else:
+                    monitor_clip_too_short(gui.editor_window.window)
+                    return
+        elif over_clip.mark_out == -1:
+            if range_length >= over_clip.get_length() - over_clip.mark_in:
+                monitor_clip_too_short(gui.editor_window.window)
+                return
+            else:
+                # Use mark in for monitor clip
+                over_clip.mark_out = over_clip.mark_in + range_length - 1
 
         over_length = over_clip.mark_out - over_clip.mark_in + 1 # + 1 out incl
         if over_length < range_length:
@@ -719,9 +752,8 @@ def range_overwrite_pressed():
             "clip_in":over_clip.mark_in,
             "clip_out":over_clip_out,
             "mark_in_frame":mark_in_frame,
-            "mark_out_frame":mark_out_frame + 1} # +1 because mark is displayed and end of frame end this 
-                                                 # confirms to user expectation of
-                                                 # of how this should work
+            "mark_out_frame":mark_out_frame + 1} # +1 because mark is displayed at end of frame end because this 
+                                                 # is how user expects this to work.
     action = edit.range_overwrite_action(data)
     action.do_edit()
 
@@ -840,7 +872,11 @@ def resync_track_button_pressed():
     syncsplitevent.resync_track()
 
 def set_track_sync_button_pressed():
-    if movemodes.selected_track != -1:
+    if boxmove.box_selection_data != None:
+        print("haloo")
+        syncsplitevent.set_box_clips_sync(boxmove.box_selection_data)
+        boxmove._exit_to_overwrite()
+    elif movemodes.selected_track != -1:
         child_track = current_sequence().tracks[movemodes.selected_track]
         syncsplitevent.set_track_clips_sync(child_track)
 
@@ -909,19 +945,70 @@ def sync_all_compositors():
         action = edit.move_compositor_action(data)
         action.do_edit()
 
+def set_length_from_keyevent():
+    if movemodes.selected_track != -1:
+        track = current_sequence().tracks[movemodes.selected_track]
+        clip = track.clips[movemodes.selected_range_in]
+        set_length(clip, track)
+
+def set_length(clip, track):
+    dialogs.clip_length_change_dialog(_change_clip_length_dialog_callback, clip, track)
+
+def _change_clip_length_dialog_callback(dialog, response_id, clip, track, length_changer):
+    if response_id != Gtk.ResponseType.ACCEPT:
+        dialog.destroy()
+        return
+
+    length = length_changer.get_length()
+    index = track.clips.index(clip)
+    
+    dialog.destroy()
+    
+    data = {"track":track,
+            "clip":clip,
+            "index":index,
+            "length":length}
+            
+    action = edit.set_clip_length_action(data)
+    action.do_edit()
+
+def mute_clip_from_keyevent():
+    if movemodes.selected_track != -1:
+        track = current_sequence().tracks[movemodes.selected_track]
+        clip = track.clips[movemodes.selected_range_in]
+        audio_on = (clip.mute_filter==None)
+        do_mute_clip(clip, audio_on)
+
+def do_mute_clip(clip, audio_on):
+    if audio_on == True:
+        data = {"clip":clip}
+        action = edit.mute_clip(data)
+        action.do_edit()
+    else:# then we're sitting clip unmuted
+        data = {"clip":clip}
+        action = edit.unmute_clip(data)
+        action.do_edit()
+
 
 # --------------------------------------------------------- view move setting
 def view_mode_menu_lauched(launcher, widget, event):
-    guipopover.monitor_view_popupmenu_show(launcher, widget, _view_mode_menu_item_item_activated, _opacity_menu_item_item_activated)
+    guipopover.monitor_view_popupmenu_show(launcher, widget, _view_mode_menu_item_item_activated, _opacity_menu_item_item_activated, _waveform_callback)
     
 def _view_mode_menu_item_item_activated(action, new_value_variant):
     msg = int(new_value_variant.get_string())
-    
     editorstate.current_sequence().set_output_mode(msg)
     editorstate.tline_view_mode = msg
     action.set_state(new_value_variant)
     guipopover._monitorview_popover.hide()
 
+def _waveform_callback(action, variant, msg):
+    pass
+    #new_state = not(action.get_state().get_boolean())
+    #editorpersistance.prefs.show_waveform_in_monitor = new_state
+    #editorpersistance.save()
+    #action.set_state(GLib.Variant.new_boolean(new_state))
+    #gui.monitor_waveform_display.update_visibility()
+    
 def set_monitor_display_mode(display_mode):
     editorstate.current_sequence().set_output_mode(display_mode)
     editorstate.tline_view_mode = display_mode
@@ -940,6 +1027,7 @@ def _opacity_menu_item_item_activated(action, new_value_variant):
     action.set_state(new_value_variant)
     guipopover._monitorview_popover.hide()
 
+
 # ------------------------------------------------------- dialogs    
 def no_monitor_clip_info(parent_window):
     primary_txt = _("No Clip loaded into Monitor")
@@ -1207,11 +1295,11 @@ def _do_add_marker(name, current_frame):
 # ---------------------------------------- timeline edits
 def all_filters_off():
     current_sequence().set_all_filters_active_state(False)
-    clipeffectseditor.update_stack_view()
+    clipeffectseditor.reinit_stack_if_needed(True)
 
 def all_filters_on():
     current_sequence().set_all_filters_active_state(True)
-    clipeffectseditor.update_stack_view()
+    clipeffectseditor.reinit_stack_if_needed(True)
 
 def set_track_small_height(track_index):
     track = get_track(track_index)
