@@ -118,6 +118,7 @@ class QueueRunnerThread(threading.Thread):
                 continue
             
             current_render_time = 0
+            batch_window.render_path = render_item.render_path
 
             # Create render objects
             identifier = render_item.generate_identifier()
@@ -236,7 +237,7 @@ class BatchRenderIPC():
     
         # Should not happen.
         if timestamp == None:
-            print("Failed toi read timestamp in BatchRenderIPC.app_running()")
+            print("Failed to read timestamp in BatchRenderIPC.app_running()")
             return False
 
         # Running batch render app lockfile was timestamp longer then 3 ago or
@@ -307,7 +308,8 @@ def add_render_item(flowblade_project, render_path, args_vals_list, mark_in, mar
     render_item.save()
 
     # Launch app if not already running.
-    launch_batch_rendering()
+    render_file_name = os.path.basename(render_path)
+    launch_batch_rendering(render_file_name)
 
 
 # ------------------------------------------------------- file utils
@@ -364,10 +366,13 @@ def maybe_create_render_folder(render_path):
         os.mkdir(folder)
         
 # --------------------------------------------------------------- app thread and data objects
-def launch_batch_rendering():
+def launch_batch_rendering(render_file_name=None):
     ipc_handle = BatchRenderIPC()
     if ipc_handle.app_running() == True:
-        _show_single_instance_info()
+        if render_file_name == None:
+            _show_single_instance_info()
+        else:
+            _show_queue_add_info(render_file_name)
     else:
         _do_batch_render_launch()
 
@@ -452,6 +457,31 @@ def _display_single_instance_window():
     dialog.connect('response', _early_exit)
     dialog.show_all()
 
+def _show_queue_add_info(render_file_name):
+    global timeout_id
+    timeout_id = GLib.timeout_add(200, _display_queue_add_window, render_file_name)
+    
+def _display_queue_add_window(render_file_name):
+    GObject.source_remove(timeout_id)
+    primary_txt = _("Render Item added to Render Queue")
+
+    msg_template = _("Render Item <b>%s</b> was added to Render Queue.")
+    msg = msg_template % render_file_name
+
+    content = dialogutils.get_warning_message_dialog_panel(primary_txt, msg, True)
+    align = dialogutils.get_default_alignment(content)
+
+    dialog = Gtk.Dialog("",
+                        None,
+                        Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT,
+                        (_("OK"), Gtk.ResponseType.OK))
+
+    dialog.vbox.pack_start(align, True, True, 0)
+    dialogutils.set_outer_margins(dialog.vbox)
+    dialogutils.default_behaviour(dialog)
+    dialog.connect('response', _early_exit)
+    dialog.show_all()
+
 def _early_exit(dialog, response):
     dialog.destroy()
     
@@ -695,25 +725,38 @@ class BatchRenderWindow:
         app_icon = GdkPixbuf.Pixbuf.new_from_file(respaths.IMAGE_PATH + "flowbladebatchappicon.png")
         self.window.set_icon(app_icon)
 
+        self.render_path = None # Set from thread.
+        self.free_disk = None # Needs to have path available.
+        self.file_size = None # Needs to have path available.
+        
         self.est_time_left = Gtk.Label()
         self.current_render = Gtk.Label()
         self.current_render_time = Gtk.Label()
         self.current_file = Gtk.Label()
+        self.size_warning = Gtk.Label()
+        self.file_est = Gtk.Label()
+    
         est_r = guiutils.get_right_justified_box([guiutils.bold_label(_("Estimated Left:"))])
         current_r = guiutils.get_right_justified_box([guiutils.bold_label(_("Current Render:"))])
         current_r_t = guiutils.get_right_justified_box([guiutils.bold_label(_("Elapsed:"))])
         current_file = guiutils.get_right_justified_box([guiutils.bold_label(_("File:"))])
+        file_size_est = guiutils.get_right_justified_box([guiutils.bold_label(_("File Size Est. / Free Disk:"))]) 
+        
         est_r.set_size_request(250, 20)
         current_r.set_size_request(250, 20)
         current_r_t.set_size_request(250, 20)
         current_file.set_size_request(250, 20)
+        file_size_est.set_size_request(250, 20)
+        self.size_warning.set_size_request(250, 20)
         
         info_vbox = Gtk.VBox(False, 0)
         info_vbox.pack_start(guiutils.get_left_justified_box([current_r, self.current_render]), False, False, 0)
         info_vbox.pack_start(guiutils.get_left_justified_box([current_file, self.current_file]), False, False, 0)
         info_vbox.pack_start(guiutils.get_left_justified_box([current_r_t, self.current_render_time]), False, False, 0)
         info_vbox.pack_start(guiutils.get_left_justified_box([est_r, self.est_time_left]), False, False, 0)
-        
+        info_vbox.pack_start(guiutils.get_left_justified_box([file_size_est, self.file_est]), False, False, 0)
+        info_vbox.pack_start(guiutils.get_centered_box([self.size_warning]), False, False, 0)
+
         self.items_rendered = Gtk.Label()
         items_r = Gtk.Label(label=_("Items Rendered:"))
         self.render_started_label = Gtk.Label()
@@ -877,6 +920,17 @@ class BatchRenderWindow:
         queue_runner_thread.start()
 
     def update_render_progress(self, fraction, items, current_name, current_render_time_passed):
+
+        if self.render_path != None:
+            try:
+                self.file_size = os.path.getsize(self.render_path)
+                if self.free_disk == None:
+                    total, used, free = shutil.disk_usage(os.path.dirname(self.render_path))
+                    self.free_disk = free 
+                
+            except FileNotFoundError:
+                pass # this can get called once before file hits disk
+                
         self.render_progress_bar.set_fraction(fraction)
 
         progress_str = str(int(fraction * 100)) + " %"
@@ -898,6 +952,26 @@ class BatchRenderWindow:
         
         self.items_rendered.set_text("  " + str(items))
 
+        est_free_mb = round(self.free_disk / 1048576)
+        if fraction > 0.25:
+
+            # We did some testing and pulled this algorithm right out of our...stetson hat.
+            # At least with short simple renders we get too small values all the way through.
+            est_file_size = (1.0 / fraction * self.file_size) * ((1.0 - (fraction - 0.25) / 0.75) * 0.1 + 1.0)
+            est_size_mb = est_file_size / 1048576
+            
+            if est_size_mb > 0.99999:
+                est_size_mb = round(est_size_mb)
+            else:
+                est_size_mb = round(est_size_mb, 1)
+
+            self.file_est.set_text(" " + str(est_size_mb) + " MB / " + str(est_free_mb) + " MB")
+            
+            if est_file_size > 0.6 * self.free_disk:
+                self.size_warning.set_text(_("Warning! Estimated render size exeeds 60% of available disk space!"))
+        else:
+            self.file_est.set_text(" " + _("N/A") + " / " + str(est_free_mb) + " MB")
+            
     def abort_render(self):
         global queue_runner_thread
         queue_runner_thread.abort()
@@ -912,7 +986,8 @@ class BatchRenderWindow:
         self.current_file.set_text("")
         self.remove_selected.set_sensitive(True)
         self.remove_finished.set_sensitive(True)
-
+        self.file_est.set_text("")
+        
         global queue_runner_thread, render_thread
         render_thread = None
         queue_runner_thread = None        
@@ -1032,9 +1107,7 @@ class RenderQueueView(Gtk.VBox):
         elif msg == "delete":
             batch_window.remove_item(render_item)
         elif msg == "saveas":
-            file_name = run_save_project_as_dialog(render_item.project_name)
-            if file_name != None:
-                copy_project(render_item, file_name)
+            run_save_project_as_dialog(render_item)
         elif msg == "changepath":
             show_change_render_item_path_dialog(_change_render_item_path_callback, render_item)
 
@@ -1050,8 +1123,8 @@ class RenderQueueView(Gtk.VBox):
             self.storemodel.append(row_data)
             self.scroll.queue_draw()
 
-
-def run_save_project_as_dialog(project_name):
+def run_save_project_as_dialog(render_item):
+    project_name = render_item.project_name
     dialog = Gtk.FileChooserDialog(_("Save Render Item Project As"), None, 
                                    Gtk.FileChooserAction.SAVE, 
                                    (_("Cancel"), Gtk.ResponseType.REJECT,
@@ -1060,13 +1133,16 @@ def run_save_project_as_dialog(project_name):
     project_name = project_name.rstrip(".flb")
     dialog.set_current_name(project_name + "_FROM_BATCH.flb")
     dialog.set_do_overwrite_confirmation(True)
-    response_id = dialog.run()
-    if response_id == Gtk.ResponseType.NONE:
+    dialog.connect('response', _save_render_callback, render_item)
+    dialog.show()
+
+def _save_render_callback(dialog, response_id, render_item):
+    if response_id == Gtk.ResponseType.ACCEPT:
+        file_name = dialog.get_filename()
+        copy_project(render_item, file_name)
+        dialog.destroy()
+    else:
         dialog.destroy()
-        return None
-    file_name = dialog.get_filename()
-    dialog.destroy()
-    return file_name
 
 def show_render_properties_panel(render_item):
     if render_item.render_data.user_args == False:
@@ -1302,6 +1378,7 @@ class SingleRenderThread(threading.Thread):
             data_file_path = hidden_dir + CURRENT_RENDER_RENDER_ITEM
             render_item = utils.unpickle(data_file_path)
             self.error_status = None
+            single_render_window.render_path = render_item.render_path
         except Exception as e:
             if self.error_status == None:
                 self.error_status = []
@@ -1388,6 +1465,7 @@ class SingleRenderThread(threading.Thread):
         single_render_window.update_render_progress(fraction, display_name, current_render_time)
 
     def _update_progress_bar(self, fraction):
+
         single_render_window.render_progress_bar.set_fraction(fraction)
                 
     def is_frame_sequence_render(self, vcodec):
@@ -1426,21 +1504,33 @@ class SingleRenderWindow:
         app_icon = GdkPixbuf.Pixbuf.new_from_file(respaths.IMAGE_PATH + "flowbladesinglerendericon.png")
         self.window.set_icon(app_icon)
 
+        self.render_path = None # Set from thread.
+        self.free_disk = None # Needs to have path available.
+        self.file_size = None # Needs to have path available.
+        
         self.est_time_left = Gtk.Label()
         self.current_render = Gtk.Label()
         self.current_render_time = Gtk.Label()
+        self.file_est = Gtk.Label()
+        self.size_warning = Gtk.Label()
         est_r = guiutils.get_right_justified_box([guiutils.bold_label(_("Estimated Left:"))])
         current_r = guiutils.get_right_justified_box([guiutils.bold_label(_("File:"))])
         current_r_t = guiutils.get_right_justified_box([guiutils.bold_label(_("Elapsed:"))])
+        file_size_est = guiutils.get_right_justified_box([guiutils.bold_label(_("File Size Est. / Free Disk:"))]) 
+        
         est_r.set_size_request(250, 20)
         current_r.set_size_request(250, 20)
         current_r_t.set_size_request(250, 20)
+        file_size_est.set_size_request(250, 20)
+        self.size_warning.set_size_request(250, 20)
 
         info_vbox = Gtk.VBox(False, 0)
         info_vbox.pack_start(guiutils.get_left_justified_box([current_r, self.current_render]), False, False, 0)
         info_vbox.pack_start(guiutils.get_left_justified_box([current_r_t, self.current_render_time]), False, False, 0)
         info_vbox.pack_start(guiutils.get_left_justified_box([est_r, self.est_time_left]), False, False, 0)
-
+        info_vbox.pack_start(guiutils.get_left_justified_box([file_size_est, self.file_est]), False, False, 0)
+        info_vbox.pack_start(guiutils.get_centered_box([self.size_warning]), False, False, 0)
+        
         self.stop_render_button = Gtk.Button(label=_("Stop Render"))
         self.stop_render_button.connect("clicked", 
                                    lambda w, e: _start_single_render_shutdown(), 
@@ -1471,6 +1561,16 @@ class SingleRenderWindow:
         self.window.show_all()
 
     def update_render_progress(self, fraction, current_name, current_render_time_passed):
+        if self.render_path != None:
+            try:
+                self.file_size = os.path.getsize(self.render_path)
+                if self.free_disk == None:
+                    total, used, free = shutil.disk_usage(os.path.dirname(self.render_path))
+                    self.free_disk = free 
+                
+            except FileNotFoundError:
+                pass # this can get called once before file hits disk
+
         self.render_progress_bar.set_fraction(fraction)
 
         progress_str = str(int(fraction * 100)) + " %"
@@ -1484,6 +1584,26 @@ class SingleRenderWindow:
             est_str = ""
         self.est_time_left.set_text(est_str)
 
+        est_free_mb = round(self.free_disk / 1048576)
+        if fraction > 0.25:
+
+            # We did some testing and pulled this algorithm right out of our...stetson hat.
+            # At least with short simple renders we get too small values all the way through.
+            est_file_size = (1.0 / fraction * self.file_size) * ((1.0 - (fraction - 0.25) / 0.75) * 0.1 + 1.0)
+            est_size_mb = est_file_size / 1048576
+            
+            if est_size_mb > 0.99999:
+                est_size_mb = round(est_size_mb)
+            else:
+                est_size_mb = round(est_size_mb, 1)
+
+            self.file_est.set_text(" " + str(est_size_mb) + " MB / " + str(est_free_mb) + " MB")
+            
+            if est_file_size > 0.6 * self.free_disk:
+                self.size_warning.set_text(_("Warning! Estimated render size exeeds 60% of available disk space!"))
+        else:
+            self.file_est.set_text(" " + _("N/A") + " / " + str(est_free_mb) + " MB")
+
         if current_render_time_passed != 0:
             current_str= "  " + utils.get_time_str_for_sec_float(current_render_time_passed)
         else:
