@@ -49,6 +49,7 @@ import gui
 import guiutils
 import glassbuttons
 import gtkbuilder
+import gtkevents
 import mltinit
 import mltprofiles
 import positionbar
@@ -584,7 +585,6 @@ class GmicWindow(Gtk.Window):
         hamburger_launcher_surface = guiutils.get_cairo_image("hamburger")
         psize = 22
         self.hamburger_launcher = toolguicomponents.PressLaunchSurface(self.hamburger_launch_pressed, hamburger_launcher_surface, psize, psize)
-        #self.hamburger_launcher.connect_launched_menu(_hamburger_menu)
         
         # Load media row
         self.load_button = Gtk.Button(label=_("Load Clip"))
@@ -603,15 +603,14 @@ class GmicWindow(Gtk.Window):
         load_row.set_margin_bottom(8)
 
         # Clip monitor
-        black_box = Gtk.EventBox()
-        black_box.add(Gtk.Label())
-        self.monitor = black_box  # This could be any GTK+ widget (that is not "windowless"), only its XWindow draw rect 
-                                  # is used to position and scale SDL overlay that actually displays video.
+        self.monitor = Gtk.Label()
         self.monitor.set_size_request(MONITOR_WIDTH, MONITOR_HEIGHT)
-
+        self.monitors_holder = Gtk.Stack()    
+        self.monitors_holder.add_named(self.monitor, "monitor") # we need to put Gtk.Label inside something with a XWindow to work with SDL.
+                
         left_vbox = Gtk.VBox(False, 0)
         left_vbox.pack_start(load_row, False, False, 0)
-        left_vbox.pack_start(self.monitor, True, True, 0)
+        left_vbox.pack_start(self.monitors_holder, True, True, 0)
 
         self.preview_info = Gtk.Label()
         self.preview_info.set_markup("<small>" + _("no preview") + "</small>" )
@@ -681,9 +680,7 @@ class GmicWindow(Gtk.Window):
         # Script area 
         # Script selector menu launcher
         self.preset_label = Gtk.Label()
-        self.present_event_box = Gtk.EventBox()
-        self.present_event_box.add(self.preset_label)
-        self.present_event_box.connect("button-press-event",  self.script_menu_lauched)
+        self.present_event_box = gtkbuilder.EventBox(self.preset_label, "button-press-event", self.script_menu_lauched)
 
         self.script_menu = toolguicomponents.PressLaunch(self.script_menu_lauched)
         
@@ -860,8 +857,8 @@ class GmicWindow(Gtk.Window):
         self.update_encode_sensitive()
 
         # Connect global key listener
-        self.connect("key-press-event", _global_key_down_listener)
-
+        self.global_key_controller = gtkevents.KeyPressEventAdapter(self, _global_key_down_listener, user_data=None, capture=True)
+        
         # Set pane and show window
         self.add(align)
         self.set_title(_("G'MIC Effects"))
