@@ -2,7 +2,7 @@
     Flowblade Movie Editor is a nonlinear video editor.
     Copyright 2012 Janne Liljeblad.
 
-    This file is part of Flowblade Movie Editor <http://code.google.com/p/flowblade>.
+    This file is part of Flowblade Movie Editor <https://github.com/jliljebl/flowblade/>.
 
     Flowblade Movie Editor is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,15 +21,17 @@
 from gi.repository import Gtk, Gdk
 from gi.repository import GLib, GObject
 
-from editorstate import PLAYER
 import editorstate
+from editorstate import PLAYER
+from editorstate import PROJECT
+import gtkevents
+import gtkbuilder
 import gui
 import guicomponents
 import guiutils
 import keyframeeditor
 import propertyparse
 import respaths
-import utils
 import vieweditor
 import vieweditorlayer
 import vieweditorshape
@@ -117,7 +119,7 @@ class RotoMaskEditor(Gtk.Window):
         # mask type param was added later, we need handle it not existing.
         if self.get_mask_type() == -1:
             self.set_mask_type(vieweditorshape.LINE_MASK)
-            self.set_mask_type_on_init = False # but we don't want to destroy user's curve masks. THis is not complety back wards compatible stuff can get destroyed on second load.
+            self.set_mask_type_on_init = False # but we don't want to destroy user's curve masks. THis is not completely back wards compatible stuff can get destroyed on second load.
         else:
             self.set_mask_type_on_init = True
             
@@ -130,16 +132,24 @@ class RotoMaskEditor(Gtk.Window):
         self.tc_display.use_internal_frame = True
         self.tc_display.widget.set_valign(Gtk.Align.CENTER)
 
-        kf_mode_img = Gtk.Image.new_from_file(respaths.IMAGE_PATH + "roto_kf_edit_mode.png")
-        move_mode_img = Gtk.Image.new_from_file(respaths.IMAGE_PATH + "roto_move_mode.png")
         self.kf_mode_button = Gtk.ToggleButton()
-        self.kf_mode_button.set_image(kf_mode_img)
+        gtkbuilder.button_set_image(self.kf_mode_button, "roto_kf_edit_mode")
+        self.kf_mode_button.set_tooltip_markup(_("<b>Add or move</b> single edit points and curve handles."))
         self.kf_mode_button.set_active(True) # we start with vieweditorlayer.ROTO_POINT_MODE edit mode
         self.kf_mode_button.connect("clicked", self._kf_mode_clicked)
         self.move_mode_button = Gtk.ToggleButton()
-        self.move_mode_button.set_image(move_mode_img)
+        gtkbuilder.button_set_image(self.move_mode_button, "roto_move_mode")
         self.move_mode_button.connect("clicked", self._move_mode_clicked)
+        self.move_mode_button.set_tooltip_markup(_("<b>Move all</b> edit points and curve handles."))
+        self.box_mode_button = Gtk.ToggleButton()
+        gtkbuilder.button_set_image(self.box_mode_button, "roto_box_mode")
+        self.box_mode_button.connect("clicked", self._box_mode_clicked)
+        self.box_mode_button.set_tooltip_markup(_("<b>Drag to select</b> edit points and curve handles and then <b>move selected</b>."))
         
+        red, green, blue, alpha = vieweditorshape.ROTO_CURVE_COLOR
+        self.color_select = Gtk.ColorButton.new_with_rgba(Gdk.RGBA(red, green, blue, alpha))
+        self.color_select.connect("color-set", self.line_color_set)
+    
         self.scale_selector = vieweditor.ScaleSelector(self)
         self.view_editor.scale_select = self.scale_selector
 
@@ -148,12 +158,14 @@ class RotoMaskEditor(Gtk.Window):
         timeline_box.pack_start(Gtk.Label(), True, True, 0)
         timeline_box.pack_start(self.kf_mode_button, False, False, 0)
         timeline_box.pack_start(self.move_mode_button, False, False, 0)
+        timeline_box.pack_start(self.box_mode_button, False, False, 0)
         timeline_box.pack_start(Gtk.Label(), True, True, 0)
+        timeline_box.pack_start(self.color_select, False, False, 0)
         timeline_box.pack_start(self.scale_selector, False, False, 0)
         timeline_box.set_margin_top(6)
         timeline_box.set_margin_bottom(6)
 
-        mask_type_label = Gtk.Label(_("Mask Type:"))
+        mask_type_label = Gtk.Label(label=_("Mask Type:"))
         mask_type_combo_box = Gtk.ComboBoxText()
         mask_type_combo_box.append_text(_("Curve Mask"))
         mask_type_combo_box.append_text(_("Line Mask"))
@@ -164,7 +176,7 @@ class RotoMaskEditor(Gtk.Window):
         allow_adding_check = Gtk.CheckButton()
         allow_adding_check.set_active(False) # This shows value of self.roto_mask_layer.allow_adding_points, False is default
         allow_adding_check.connect("toggled", self.allow_adding_toggled)
-        allow_adding_label = Gtk.Label(_("Allow to add / delete points in closed masks"))
+        allow_adding_label = Gtk.Label(label=_("Allow to add / delete points in closed masks"))
         
         save_rotodata_b = guiutils.get_sized_button(_("Close Tool"), 150, 32)
         save_rotodata_b.connect("clicked", lambda w:self._save_rotodata_pressed())
@@ -225,8 +237,10 @@ class RotoMaskEditor(Gtk.Window):
         self.kf_editor.active_keyframe_changed()
 
         self.connect("size-allocate", lambda w, e:self.window_resized())
-        self.connect("window-state-event", lambda w, e:self.window_resized())
-        self.connect("key-press-event", self.key_down)
+
+        # Connect global key listener
+        self.global_key_controller = gtkevents.KeyPressEventAdapter(self, self.key_down, user_data=None, capture=True)
+        
         self.window_resized()
 
         self.kf_editor.clip_editor.maybe_set_first_kf_in_clip_area_active()
@@ -262,14 +276,18 @@ class RotoMaskEditor(Gtk.Window):
         if self.get_mask_type() != -1: # for older project types, this param was added later and we need to handle case that is does not exist.
             rotomask_filter.non_mlt_properties.pop(0)
         rotomask_filter.non_mlt_properties.append(("mask_type", mask_type, 0))
-        
+
+    def line_color_set(self, color_button):
+        color = color_button.get_rgba()
+        vieweditorshape.ROTO_CURVE_COLOR = (color.red, color.green, color.blue, color.alpha)
+        self.update_view()
+    
     def update_view(self):
         # Callback from kf_editor
         self.show_current_frame()
 
     def show_current_frame(self):
         tline_frame = PLAYER().current_frame()
-        length = PLAYER().producer.get_length()
         rgbdata = PLAYER().seek_and_get_rgb_frame(tline_frame)
         self.view_editor.set_screen_rgb_data(rgbdata)
         self.view_editor.update_layers_for_frame(tline_frame)
@@ -290,7 +308,7 @@ class RotoMaskEditor(Gtk.Window):
 
     def update_effects_editor_value_labels(self):
         self.value_labels[0].set_text(str(len(self.kf_editor.clip_editor.keyframes)))
-        kf, curve_points = self.kf_editor.clip_editor.keyframes[0] # We always have one
+        kf, curve_points, kf_type = self.kf_editor.clip_editor.keyframes[0] # We always have one
         self.value_labels[1].set_text(str(len(curve_points)))
     
     def _kf_mode_clicked(self, kf_button):
@@ -301,7 +319,8 @@ class RotoMaskEditor(Gtk.Window):
         elif self.roto_mask_layer.edit_mode != vieweditorlayer.ROTO_POINT_MODE:
             self.roto_mask_layer.edit_mode = vieweditorlayer.ROTO_POINT_MODE
             self.move_mode_button.set_active(False)
-    
+            self.box_mode_button.set_active(False)
+            
     def _move_mode_clicked(self, move_button):
         if self.roto_mask_layer.edit_mode == vieweditorlayer.ROTO_MOVE_MODE and move_button.get_active() == False:
             move_button.set_active(True)  # we untoggled by clicking which is not allowed, untoggle happens whenthe other mode is selected. We set the untoggled button back to being active. 
@@ -310,7 +329,18 @@ class RotoMaskEditor(Gtk.Window):
         elif self.roto_mask_layer.edit_mode != vieweditorlayer.ROTO_MOVE_MODE:
             self.roto_mask_layer.edit_mode = vieweditorlayer.ROTO_MOVE_MODE
             self.kf_mode_button.set_active(False)
-
+            self.box_mode_button.set_active(False)
+            
+    def _box_mode_clicked(self, box_button):
+        if self.roto_mask_layer.edit_mode == vieweditorlayer.ROTO_BOX_MODE and box_button.get_active() == False:
+            box_button.set_active(True)  # we untoggled by clicking which is not allowed, untoggle happens whenthe other mode is selected. We set the untoggled button back to being active. 
+        elif box_button.get_active() == False:
+            pass # this event is redundant, we always get two events when changing modes
+        elif self.roto_mask_layer.edit_mode != vieweditorlayer.ROTO_BOX_MODE:
+            self.roto_mask_layer.edit_mode = vieweditorlayer.ROTO_BOX_MODE
+            self.kf_mode_button.set_active(False)
+            self.move_mode_button.set_active(False)
+            
     def position_listener(self, normalized_pos, length):
         frame = normalized_pos * length
         self.tc_display.set_frame(int(frame))
@@ -359,4 +389,7 @@ class RotoMaskEditor(Gtk.Window):
             self.mask_create_freeze = True
 
         self.kf_editor.set_editor_sensitive(not self.mask_create_freeze)
-                
+
+    def enable_save(self):
+        if PROJECT().last_save_path != None:
+            gui.editor_window.uimanager.get_widget("/MenuBar/FileMenu/Save").set_sensitive(True)
