@@ -51,6 +51,7 @@ import gui
 import guiutils
 import glassbuttons
 import gtkbuilder
+import gtkevents
 import gmicplayer
 import mediaplugin
 import mltinit
@@ -688,11 +689,8 @@ class ScriptToolWindow(Gtk.Window):
         # ---------------------------------------------------------------------- TOP ROW
         app_icon = GdkPixbuf.Pixbuf.new_from_file(respaths.IMAGE_PATH + "flowbladetoolicon.png")
         self.set_icon(app_icon)
-        hamburger_launcher_surface = guiutils.get_double_scaled_cairo_image("hamburger.png")
-        if guiutils.double_icon_size():
-            psize = 22
-        else:
-            psize = 44
+        hamburger_launcher_surface = guiutils.get_cairo_image("hamburger")
+        psize = 22
         self.hamburger_launcher = toolguicomponents.PressLaunchSurface(self.hamburger_launch_pressed_popover, hamburger_launcher_surface, psize, psize)
         self.hamburger_launcher.widget.set_margin_bottom(7)
 
@@ -733,9 +731,7 @@ class ScriptToolWindow(Gtk.Window):
         # -------------------------------------------------------------------- RIGHT SIDE: MONITOR, CONTROLS, ENCODING
         # -------------------------------------------------------------------- RIGHT SIDE: MONITOR, CONTROLS, ENCODING 
         # -------------------------------------------------------------------- RIGHT SIDE: MONITOR, CONTROLS, ENCODING 
-        black_box = Gtk.EventBox()
-        black_box.add(Gtk.Label())
-        self.monitor = black_box  # This could be any GTK+ widget (that is not "windowless"), only its XWindow draw rect 
+        self.monitor = Gtk.Label() #black_box  # This could be any GTK+ widget (that is not "windowless"), only its XWindow draw rect 
                                   # is used to position and scale SDL overlay that actually displays video.
         self.monitor.set_size_request(MONITOR_WIDTH, MONITOR_HEIGHT)
 
@@ -1008,8 +1004,9 @@ class ScriptToolWindow(Gtk.Window):
 
         self.update_encode_sensitive()
 
-        self.connect("key-press-event", _global_key_down_listener)
-
+        # Connect global key listener
+        self.global_key_controller = gtkevents.KeyPressEventAdapter(self, _global_key_down_listener, user_data=None, capture=True)
+        
         # Set pane and show window
         self.add(align)
         self.tool_name = _("Generator Script Editor")
@@ -1199,6 +1196,7 @@ class ScriptToolWindow(Gtk.Window):
 
 #------------------------------------------------- global key listener
 def _global_key_down_listener(widget, event):
+
     # CTRL + S saving
     if event.keyval == Gdk.KEY_s:
         if (event.get_state() & Gdk.ModifierType.CONTROL_MASK):
@@ -1206,7 +1204,13 @@ def _global_key_down_listener(widget, event):
                 save_script_dialog(_save_script_dialog_callback)
             else:
                 _save_script(_last_save_path)
-            
+
+    if event.keyval == Gdk.KEY_R or event.keyval == Gdk.KEY_r:
+        if (event.get_state() & Gdk.ModifierType.CONTROL_MASK):
+            if _last_save_path != None:
+                _load_script(_last_save_path)
+                return
+
     # Script view and frame name entry need their own key presses
     # and we can't e.g. use up LEFT ARROW here.
     if _window.frame_name.has_focus() or _window.script_view.has_focus():
@@ -1234,10 +1238,7 @@ def _global_key_down_listener(widget, event):
     if event.keyval == Gdk.KEY_Up:
         end_pressed()
 
-    if event.keyval == Gdk.KEY_r:
-        if (event.get_state() & Gdk.ModifierType.CONTROL_MASK):
-            if _last_save_path != None:
-                _load_script(_last_save_path)
+
         
     # I
     if event.keyval == Gdk.KEY_i:
@@ -1545,8 +1546,8 @@ class FluxityPluginRenderer(threading.Thread):
         _window.render_percentage.set_markup("<small>" + _("Render stopped!") + "</small>")
         self.set_render_stopped_gui_state()
 
-    def show_progress(self, persentage, fraction, set_stopped):
-        _window.render_percentage.set_markup(persentage)
+    def show_progress(self, percentage, fraction, set_stopped):
+        _window.render_percentage.set_markup(percentage)
         _window.render_progress_bar.set_fraction(fraction)
         if set_stopped:
             self.set_render_stopped_gui_state()
