@@ -33,20 +33,23 @@ from gi.repository import Pango
 from gi.repository import PangoCairo
 
 import atomicfile
-import toolsdialogs
+import editorpersistance
 from editorstate import PLAYER
 import editorstate
 import gui
 import guicomponents
 import guiutils
+import gtkbuilder
+import gtkevents
 import dialogutils
+import positionbar
 import projectaction
 import respaths
-import positionbar
-import utils
+import toolsdialogs
 import vieweditor
 import vieweditorlayer
 import userfolders
+import utils
 
 _titler = None
 _titler_data = None
@@ -279,6 +282,8 @@ class Titler(Gtk.Window):
         self.view_editor.active_layer_changed_listener = self.active_layer_changed
         
         self.guides_toggle = vieweditor.GuidesViewToggle(self.view_editor)
+
+        self.title_name = "TITLE"
         
         add_b = Gtk.Button(label=_("Add"))
         del_b = Gtk.Button(label=_("Delete"))
@@ -289,13 +294,11 @@ class Titler(Gtk.Window):
         add_del_box.pack_start(add_b, True, True, 0)
         add_del_box.pack_start(del_b, True, True, 0)
 
-        center_h_icon = Gtk.Image.new_from_file(respaths.IMAGE_PATH + "center_horizontal.png")
-        center_v_icon = Gtk.Image.new_from_file(respaths.IMAGE_PATH + "center_vertical.png")
         center_h = Gtk.Button()
-        center_h.set_image(center_h_icon)
+        gtkbuilder.button_set_image(center_h, "center_horizontal")
         center_h.connect("clicked", lambda w:self._center_h_pressed())
         center_v = Gtk.Button()
-        center_v.set_image(center_v_icon)
+        gtkbuilder.button_set_image(center_v, "center_vertical")
         center_v.connect("clicked", lambda w:self._center_v_pressed())
 
         self.layer_list = TextLayerListView(self._layer_selection_changed, self._layer_visibility_toggled)
@@ -346,7 +349,7 @@ class Titler(Gtk.Window):
         self.size_spin = Gtk.SpinButton()
         self.size_spin.set_adjustment(adj)
         self.size_spin.connect("changed", self._edit_value_changed)
-        self.size_spin.connect("key-press-event", self._key_pressed_on_widget)
+        self.spin_adapter = gtkevents.KeyPressEventAdapter(self.size_spin, self._key_pressed_on_widget)
 
         font_main_row = Gtk.HBox()
         font_main_row.pack_start(self.font_select, True, True, 0)
@@ -356,27 +359,17 @@ class Titler(Gtk.Window):
         
         self.bold_font = Gtk.ToggleButton()
         self.italic_font = Gtk.ToggleButton()
-        bold_icon = Gtk.Image.new_from_icon_name("format-text-bold", 
-                                       Gtk.IconSize.BUTTON)
-        italic_icon = Gtk.Image.new_from_icon_name("format-text-italic", 
-                                       Gtk.IconSize.BUTTON)
-        self.bold_font.set_image(bold_icon)
-        self.italic_font.set_image(italic_icon)
+        gtkbuilder.button_set_image_icon_name(self.bold_font, "format-text-bold")
+        gtkbuilder.button_set_image_icon_name(self.italic_font, "format-text-italic")
         self.bold_font.connect("clicked", self._edit_value_changed)
         self.italic_font.connect("clicked", self._edit_value_changed)
         
         self.left_align = Gtk.RadioButton(None)
         self.center_align = Gtk.RadioButton.new_from_widget(self.left_align)
         self.right_align = Gtk.RadioButton.new_from_widget(self.left_align)
-        left_icon = Gtk.Image.new_from_icon_name("format-justify-left", 
-                                       Gtk.IconSize.BUTTON)
-        center_icon = Gtk.Image.new_from_icon_name("format-justify-center", 
-                                       Gtk.IconSize.BUTTON)
-        right_icon = Gtk.Image.new_from_icon_name("format-justify-right", 
-                                       Gtk.IconSize.BUTTON)
-        self.left_align.set_image(left_icon)
-        self.center_align.set_image(center_icon)
-        self.right_align.set_image(right_icon)
+        gtkbuilder.button_set_image_icon_name(self.left_align, "format-justify-left")
+        gtkbuilder.button_set_image_icon_name(self.center_align, "format-justify-center")
+        gtkbuilder.button_set_image_icon_name(self.right_align, "format-justify-right")
         self.left_align.set_mode(False)
         self.center_align.set_mode(False)
         self.right_align.set_mode(False)
@@ -414,8 +407,8 @@ class Titler(Gtk.Window):
         self.out_line_size_spin = Gtk.SpinButton()
         self.out_line_size_spin.set_adjustment(adj2)
         self.out_line_size_spin.connect("changed", self._edit_value_changed)
-        self.out_line_size_spin.connect("key-press-event", self._key_pressed_on_widget)
-
+        self.out_line_size_adapter = gtkevents.KeyPressEventAdapter(self.out_line_size_spin, self._key_pressed_on_widget)
+        
         self.outline_on = Gtk.CheckButton()
         self.outline_on.set_active(False)
         self.outline_on.connect("toggled", self._edit_value_changed)
@@ -441,22 +434,22 @@ class Titler(Gtk.Window):
         adj3 = Gtk.Adjustment(value=float(100), lower=float(1), upper=float(100), step_increment=float(1))
         self.shadow_opa_spin.set_adjustment(adj3)
         self.shadow_opa_spin.connect("changed", self._edit_value_changed)
-        self.shadow_opa_spin.connect("key-press-event", self._key_pressed_on_widget)
-
+        self.shadow_opa_spin_adapter = gtkevents.KeyPressEventAdapter(self.shadow_opa_spin, self._key_pressed_on_widget)
+        
         self.shadow_xoff_spin = Gtk.SpinButton()
 
         adj4 = Gtk.Adjustment(value=float(3), lower=float(1), upper=float(100), step_increment=float(1))
         self.shadow_xoff_spin.set_adjustment(adj4)
         self.shadow_xoff_spin.connect("changed", self._edit_value_changed)
-        self.shadow_xoff_spin.connect("key-press-event", self._key_pressed_on_widget)
-
+        self.shadow_xoff_spin_adapter = gtkevents.KeyPressEventAdapter(self.shadow_xoff_spin, self._key_pressed_on_widget)
+        
         self.shadow_yoff_spin = Gtk.SpinButton()
 
         adj5 = Gtk.Adjustment(value=float(3), lower=float(1), upper=float(100), step_increment=float(1))
         self.shadow_yoff_spin.set_adjustment(adj5)
         self.shadow_yoff_spin.connect("changed", self._edit_value_changed)
-        self.shadow_yoff_spin.connect("key-press-event", self._key_pressed_on_widget)
-
+        self.shadow_yoff_spin_adapter = gtkevents.KeyPressEventAdapter(self.shadow_yoff_spin, self._key_pressed_on_widget)
+        
         self.shadow_on = Gtk.CheckButton()
         self.shadow_on.set_active(False)
         self.shadow_on.connect("toggled", self._edit_value_changed)
@@ -541,33 +534,29 @@ class Titler(Gtk.Window):
         self.x_pos_spin = Gtk.SpinButton()
         self.x_pos_spin.set_adjustment(adj)
         self.x_pos_spin.connect("changed", self._position_value_changed)
-        self.x_pos_spin.connect("key-press-event", self._key_pressed_on_widget)
-
+        self.xpos_adapter = gtkevents.KeyPressEventAdapter(self.x_pos_spin, self._key_pressed_on_widget)
+        
         adj = Gtk.Adjustment(value=float(0), lower=float(0), upper=float(3000), step_increment=float(1))
         self.y_pos_spin = Gtk.SpinButton()
         self.y_pos_spin.set_adjustment(adj)
         self.y_pos_spin.connect("changed", self._position_value_changed)
-        self.y_pos_spin.connect("key-press-event", self._key_pressed_on_widget)
-
+        self.y_pos_spin_adapter = gtkevents.KeyPressEventAdapter(self.y_pos_spin, self._key_pressed_on_widget)
+        
         adj = Gtk.Adjustment(value=float(0), lower=float(0), upper=float(3000), step_increment=float(1))
         self.rotation_spin = Gtk.SpinButton()
         self.rotation_spin.set_adjustment(adj)
         self.rotation_spin.connect("changed", self._position_value_changed)
-        self.rotation_spin.connect("key-press-event", self._key_pressed_on_widget)
+        self.rotation_spin_adapter = gtkevents.KeyPressEventAdapter(self.rotation_spin, self._key_pressed_on_widget)
         
         undo_pos = Gtk.Button()
-        undo_icon = Gtk.Image.new_from_icon_name("edit-undo", 
-                                       Gtk.IconSize.BUTTON)
-        undo_pos.set_image(undo_icon)
-
+        gtkbuilder.button_set_image_icon_name(undo_pos, "edit-undo")
+        
         # ------------------------------------------------- Timeline controls
-        next_icon = Gtk.Image.new_from_file(respaths.IMAGE_PATH + "next_frame_s.png")
-        prev_icon = Gtk.Image.new_from_file(respaths.IMAGE_PATH + "prev_frame_s.png")
         prev_frame = Gtk.Button()
-        prev_frame.set_image(prev_icon)
+        gtkbuilder.button_set_image(prev_frame, "prev_frame_s")
         prev_frame.connect("clicked", lambda w:self._prev_frame_pressed())
         next_frame = Gtk.Button()
-        next_frame.set_image(next_icon)
+        gtkbuilder.button_set_image(next_frame, "next_frame_s")
         next_frame.connect("clicked", lambda w:self._next_frame_pressed())
 
         self.scale_selector = vieweditor.ScaleSelector(self)
@@ -605,7 +594,6 @@ class Titler(Gtk.Window):
         controls_panel_1 = Gtk.VBox()
         controls_panel_1.pack_start(add_del_box, False, False, 0)
         controls_panel_1.pack_start(self.layer_list, True, True, 0)
-        #controls_panel_1.pack_start(layers_save_buttons_row, False, False, 0)
 
         controls_panel_2 = Gtk.VBox()
         controls_panel_2.pack_start(font_main_row, False, False, 0)
@@ -641,10 +629,24 @@ class Titler(Gtk.Window):
 
         # ------------------------------------------------------- Editor buttons
         self.save_action_combo = Gtk.ComboBoxText()
-        self.save_action_combo.append_text(_("Save As Title"))
-        self.save_action_combo.append_text(_("Save As Graphic"))
+        self.save_action_combo.append_text(_("Save As Title Media Object"))
+        self.save_action_combo.append_text(_("Save As Graphic Media Object"))
         self.save_action_combo.set_active(0)
 
+        self.title_name_entry = Gtk.Entry()
+        self.title_name_entry.set_text(self.title_name)
+        self.title_name_entry.set_width_chars(20)
+        self.title_name_entry.set_margin_right(12)
+
+        self.title_name_label = Gtk.Label(_("Title Name:"))
+        self.title_name_label.set_margin_right(4)
+
+        title_name_row = Gtk.HBox()
+        title_name_row.pack_start(Gtk.Label(), True, True, 0)
+        title_name_row.pack_start(self.title_name_label, False, False, 0)
+        title_name_row.pack_start(self.title_name_entry, False, False, 0)
+        title_name_row.pack_start(self.save_action_combo, False, False, 0)
+
         exit_b = guiutils.get_sized_button(_("Close"), 150, 32)
         exit_b.connect("clicked", lambda w:close_titler())
         if _clip_data == None:
@@ -658,11 +660,20 @@ class Titler(Gtk.Window):
         self.info_text = Gtk.Label()
         
         editor_buttons_row = Gtk.HBox()
-        editor_buttons_row.pack_start(self.info_text, True, True, 0)
+        editor_buttons_row.pack_start(Gtk.Label(), True, True, 0)
+        editor_buttons_row.pack_start(self.info_text, False, False, 0)
         editor_buttons_row.pack_start(guiutils.pad_label(12, 2), False, False, 0)
         if _clip_data == None:
-            editor_buttons_row.pack_start(self.save_action_combo, False, False, 0)
-        editor_buttons_row.pack_start(guiutils.pad_label(32, 2), False, False, 0)
+            close_on_save_checkbox = Gtk.CheckButton()
+            close_on_save_checkbox.set_active(editorpersistance.prefs.close_titler_on_save)
+            close_on_save_checkbox.connect("toggled", self._close_on_save_toggled)
+            close_save_label = Gtk.Label(label=_("Close on Save"))
+            close_save_label.set_margin_right(12)
+            close_save_label.set_margin_left(4)
+            editor_buttons_row.pack_start(close_on_save_checkbox, False, False, 0)
+            editor_buttons_row.pack_start(close_save_label, False, False, 0)
+
+        editor_buttons_row.pack_start(guiutils.pad_label(12, 2), False, False, 0)
         editor_buttons_row.pack_start(exit_b, False, False, 0)
         editor_buttons_row.pack_start(save_titles_b, False, False, 0)
         
@@ -672,6 +683,9 @@ class Titler(Gtk.Window):
         editor_panel.pack_start(timeline_box, False, False, 0)
         editor_panel.pack_start(guiutils.get_in_centering_alignment(view_editor_editor_buttons_row), False, False, 0)
         editor_panel.pack_start(guiutils.pad_label(2, 24), False, False, 0)
+        if _clip_data == None:
+            editor_panel.pack_start(title_name_row, False, False, 0)
+            editor_panel.pack_start(guiutils.pad_label(2, 12), False, False, 0)
         editor_panel.pack_start(editor_buttons_row, False, False, 0)
 
         editor_row = Gtk.HBox()
@@ -688,11 +702,9 @@ class Titler(Gtk.Window):
 
         # -------------------------------------------------- window state listeners
         self.connect("size-allocate", lambda w, e:self.window_resized())
-        self.connect("window-state-event", lambda w, e:self.window_resized())
     
     def show_info(self, info_text):
         self.info_text.set_markup("<small>" + info_text + "</small>")
-        #GLib.timeout_add(2500, self.clear_info)
 
     def clear_info(self):
         self.info_text.set_markup("")
@@ -753,6 +765,10 @@ class Titler(Gtk.Window):
         PLAYER().seek_frame(frame)
         self.show_current_frame()
 
+    def _close_on_save_toggled(self, w):
+        editorpersistance.prefs.close_titler_on_save = w.get_active()
+        editorpersistance.save()
+
     def _save_title_pressed(self):
         global _titler_data, _clip_data
 
@@ -763,49 +779,39 @@ class Titler(Gtk.Window):
             self.view_editor.write_callback = self.title_write_done
             self.view_editor.write_layers_to_png(new_title_path)
         else:
-            if self.save_action_combo.get_active() == 1:
-                toolsdialogs.save_titler_graphic_as_dialog(self._save_title_dialog_callback, "title.png", _titler_lastdir)
-            else:
-                dialog, entry = dialogutils.get_single_line_text_input_dialog(30, 130,
-                                                            _("Select Title Name"),
-                                                            _("Set Name"),
-                                                            _("Title Name:"),
-                                                            _("Title"))
-                dialog.connect('response', self._titler_item_name_dialog_callback, entry)
-                dialog.show_all()
+            self._do_title_save()
 
     def title_write_done(self, new_title_path):
         GLib.idle_add(_edit_title_exit, new_title_path)
             
-    def  _titler_item_name_dialog_callback(self, dialog, response_id, entry):
-        if response_id == Gtk.ResponseType.ACCEPT:
-            name = entry.get_text()
-            dialog.destroy()
-            
-            if name == "":
-                name = _("Title")
-            
-            md_str = hashlib.md5(str(os.urandom(32)).encode('utf-8')).hexdigest() + ".png"
-            save_path = userfolders.get_render_dir() + md_str
+    def _do_title_save(self):
+        name = self.title_name_entry.get_text()
 
-            self.view_editor.write_layers_to_png(save_path)
-            
-            # Destroy pango layouts as they cannot be pickled and thus cannot be part of savefile where 
-            # this data ends up as a clip.titler_data and mediafile.titler_data properties.
-            # We need deep copy from picledable shallow copy so when pango layers get recreated
-            # for titler they don't end up in save data.
-            title_data_shallow = copy.copy(_titler_data)
-            title_data_shallow.destroy_pango_layouts()
-            title_data = copy.deepcopy(title_data_shallow)
-
-            print("show_info 1")
-            #self.show_info(_("Saved Title") + " '" + name + "'.")
- 
-            open_title_item_thread = OpenTitlerItemThread(name, save_path, title_data, self.view_editor)
-            open_title_item_thread.start()
+        if name == "":
+            name = _("Title")
         else:
-            dialog.destroy()
+            self.title_name = name
 
+        if self.save_action_combo.get_active() == 1:
+            toolsdialogs.save_titler_graphic_as_dialog(self._save_title_dialog_callback, name + ".png", _titler_lastdir)
+            return
+
+        md_str = hashlib.md5(str(os.urandom(32)).encode('utf-8')).hexdigest() + ".png"
+        save_path = userfolders.get_render_dir() + md_str
+
+        self.view_editor.write_layers_to_png(save_path)
+        
+        # Destroy pango layouts as they cannot be pickled and thus cannot be part of savefile where 
+        # this data ends up as a clip.titler_data and mediafile.titler_data properties.
+        # We need deep copy from picledable shallow copy so when pango layers get recreated
+        # for titler they don't end up in save data.
+        title_data_shallow = copy.copy(_titler_data)
+        title_data_shallow.destroy_pango_layouts()
+        title_data = copy.deepcopy(title_data_shallow)
+
+        open_title_item_thread = OpenTitlerItemThread(name, save_path, title_data, self.view_editor)
+        open_title_item_thread.start()
+        
     def _save_title_dialog_callback(self, dialog, response_id):
         if response_id == Gtk.ResponseType.ACCEPT:
             try:
@@ -817,14 +823,11 @@ class Titler(Gtk.Window):
                 global _titler_lastdir
                 _titler_lastdir = dirname
 
-                print("show_info 2")
-                #self.show_info(_("Saved Graphic."))
+                self.show_info(_("Saved Graphic Media Item."))
             
                 open_file_thread = OpenFileThread(save_path, self.view_editor)
                 open_file_thread.start()
-                # INFOWINDOW
             except:
-                # INFOWINDOW
                 dialog.destroy()
                 return
         else:
@@ -1491,7 +1494,9 @@ class OpenFileThread(threading.Thread):
         open_in_bin_thread = projectaction.AddMediaFilesThread([self.filename])
         open_in_bin_thread.start()
 
-
+        if editorpersistance.prefs.close_titler_on_save == True:
+            close_titler()
+            
 
 class OpenTitlerItemThread(threading.Thread):
     
@@ -1511,8 +1516,12 @@ class OpenTitlerItemThread(threading.Thread):
         open_in_bin_thread.start()
 
     def _completed_callback(self):
-        GLib.idle_add(self._recreate_pango_layers)
-    
+        if editorpersistance.prefs.close_titler_on_save == False:
+            _titler.show_info(_("Saved Title Media Item."))
+            GLib.idle_add(self._recreate_pango_layers)
+        else:
+            close_titler()
+        
     def _recreate_pango_layers(self):
         global _titler, _titler_data
         _titler_data.create_pango_layouts()
