@@ -24,6 +24,7 @@ from gi.repository import GObject
 import os
 
 import appconsts
+from editorstate import PROJECT
 import guiutils
 import gtkbuilder
 import mltprofiles
@@ -53,7 +54,7 @@ class ToolsRenderData():
     """
     def __init__(self):
         self.profile_index = None
-        # The DEPRECATED values are part of save data and cannot be removed without braking save files.
+        # The DEPRECATED values are part of save data and cannot be removed without breaking save files.
         self.use_default_profile = None # DEPRECATED, 'profile_index' is used.
         self.use_preset_encodings = None  # DEPRECATED 'encoding_option_index', 'quality_option_index' are used.
         self.presets_index = None  # DEPRECATED, 'encoding_option_index', 'quality_option_index' are used.
@@ -99,6 +100,15 @@ def create_container_clip_default_render_data_object(profile):
     render_data.file_name = appconsts.CONTAINER_CLIP_VIDEO_CLIP_NAME
     render_data.file_extension = ".mp4"
 
+    # Set default encoding if available. Only main app usage has not-None PROJECT().
+    # Gmic and scriptool TOOLS don't get this data, but when rendered as timeline caontainer clips, data is used. 
+    if PROJECT() != None:
+        default_encoding = PROJECT().container_default_encoding
+        if default_encoding != None:
+            enc_index, q_index = default_encoding
+            render_data.encoding_option_index = enc_index
+            render_data.quality_option_index = q_index
+
     return render_data
 
 def create_container_clip_default_alpha_render_data_object(profile):
@@ -135,6 +145,8 @@ def get_render_type_from_render_data(render_data):
 def create_widgets(def_profile_index, disable_audio=True, create_container_file_panel=False):
     """
     Widgets for editing render properties and viewing render progress.
+    
+    These are RE_INITIALIZED always when using this module from main app.
     """
     global widgets, disable_audio_encoding, default_profile_index
     default_profile_index = def_profile_index
@@ -183,7 +195,8 @@ def get_encoding_panel(render_data, create_container_file_panel=False):
         widgets.file_panel.movie_name.set_text(render_data.file_name)
         widgets.file_panel.extension_label.set_text(render_data.file_extension)
         widgets.file_panel.out_folder.set_current_folder(render_data.render_dir + "/")
-        widgets.encoding_panel.encoding_selector.categorised_combo.set_selected(mltprofiles.get_profile_for_index(render_data.encoding_option_index).description())
+        enc_opt = renderconsumer.encoding_options[render_data.encoding_option_index]
+        widgets.encoding_panel.encoding_selector.categorised_combo.set_selected(enc_opt.name)
         widgets.encoding_panel.quality_selector.widget.set_active(render_data.quality_option_index)
         profile_desc = mltprofiles.get_profile_for_index(render_data.profile_index).description()
         widgets.profile_panel.out_profile_combo.categories_combo.set_selected(profile_desc)
@@ -199,9 +212,26 @@ def get_encoding_panel(render_data, create_container_file_panel=False):
             widgets.video_clip_panel.video_clip_combo.set_active(video_clip_combo_index)
             widgets.file_panel.render_location_combo.set_active(render_location_combo_index)
             widgets.file_panel.frame_name.set_text(render_data.frame_name)
-            
+    else:
+        if PROJECT() != None:
+            if PROJECT().container_default_encoding != None:
+                encoding_option_index, quality_option_index =  PROJECT().container_default_encoding 
+                enc_opt = renderconsumer.encoding_options[encoding_option_index]
+                widgets.encoding_panel.encoding_selector.categorised_combo.set_selected(enc_opt.name)
+                widgets.encoding_panel.quality_selector.widget.set_active(quality_option_index)
+
     return render_panel
 
+def get_default_encoding_setting_panel(default_encoding):
+    encoding_panel = guiutils.get_named_frame(_("Encoding Format"), widgets.encoding_panel.vbox, 4)
+    if default_encoding != None:
+        encoding_option_index, quality_option_index = default_encoding
+        enc_opt = renderconsumer.encoding_options[encoding_option_index]
+        widgets.encoding_panel.encoding_selector.categorised_combo.set_selected(enc_opt.name)
+        widgets.encoding_panel.quality_selector.widget.set_active(quality_option_index)
+
+    return encoding_panel
+
 def get_profile_info_small_box(profile):
     text = get_profile_info_text(profile)
     label = Gtk.Label(label=text)
@@ -369,10 +399,8 @@ class RenderVideoClipPanel:
         encoding_vbox.pack_start(encoding_panel, False, False, 0)
 
         encoding_hbox = Gtk.HBox(False, 2)
-        encoding_hbox.pack_start(guiutils.pad_label(12, 12), False, False, 0)
         encoding_hbox.pack_start(encoding_vbox, True, True, 0)
 
-        
         self.vbox = Gtk.VBox(False, 2)
         self.vbox.pack_start(self.video_clip_combo, False, False, 0)
         self.vbox.pack_start(guiutils.pad_label(12, 24), False, False, 0)
@@ -449,7 +477,7 @@ class RenderEncodingPanel():
     
     def __init__(self, extension_label):
         self.quality_selector = RenderQualitySelector()
-        self.quality_selector.widget.set_size_request(110, 34)
+        self.quality_selector.widget.set_size_request(140, 34)
         self.quality_selector.update_quality_selection(0)
         self.audio_desc = Gtk.Label()
         self.encoding_selector = RenderEncodingSelector(self.quality_selector,
@@ -459,10 +487,14 @@ class RenderEncodingPanel():
 
         quality_row  = Gtk.HBox()
         quality_row.pack_start(self.quality_selector.widget, False, False, 0)
-        quality_row.pack_start(Gtk.Label(), True, False, 0)
+        quality_row.pack_start(Gtk.Label(), True, True, 0)
 
+        enconding_row  = Gtk.HBox()
+        enconding_row.pack_start(self.encoding_selector.widget, False, False, 0)
+        enconding_row.pack_start(Gtk.Label(), True, True, 0)
+        
         self.vbox = Gtk.VBox(False, 2)
-        self.vbox.pack_start(self.encoding_selector.widget, False, False, 0)
+        self.vbox.pack_start(enconding_row, False, False, 0)
         self.vbox.pack_start(quality_row, False, False, 0)
 
     def set_sensitive(self, value):
