@@ -390,7 +390,7 @@ def display_clip_in_monitor(clip_monitor_currently_active=False):
     global save_monitor_frame
     save_monitor_frame = True
 
-    # Opening clip exits trim modes
+    # Opening clip goes to default edit mode for non-move modes.
     if not editorstate.current_is_move_mode():
         set_clip_edit_mode_callback()
 
@@ -449,6 +449,7 @@ def display_clip_in_monitor(clip_monitor_currently_active=False):
 
     # Display frame, marks and pos
     gui.pos_bar.update_display_from_producer(clip_producer)
+    gui.monitor_waveform_display.update_display_from_producer(clip_producer)
     
     display_monitor_clip_name()
 
@@ -465,11 +466,12 @@ def display_clip_in_monitor(clip_monitor_currently_active=False):
 
     css_str = "#player-bar { background-color: #464646; border-radius: 10px;}"
     gui.apply_widget_css_class_style_from_string(gui.editor_window.player_buttons_row, css_str)
-    gui.editor_window.monitor_clip_type.widget.queue_draw()
 
     gui.pos_bar.widget.grab_focus()
+    gui.pos_bar.set_clip_bg(True)
     gui.media_list_view.widget.queue_draw()    
     gui.monitor_switch.widget.queue_draw()
+    gui.monitor_waveform_display.update_visibility()
     repaint_tline()
 
 def display_monitor_clip_name():#we're displaying length and range length also
@@ -522,10 +524,11 @@ def display_sequence_in_monitor():
     gui.pos_bar.update_display_from_producer(PLAYER().producer)
     display_marks_tc()
 
-    css_str = "#player-bar { background-color: #363636; border-radius: 10px;}"
+    css_str = "#player-bar { background-color: #333333; border-radius: 10px;}"
     gui.apply_widget_css_class_style_from_string(gui.editor_window.player_buttons_row, css_str)
-    gui.editor_window.monitor_clip_type.widget.queue_draw()
-
+    gui.pos_bar.set_clip_bg(False)
+    
+    gui.monitor_waveform_display.widget.hide()
     gui.monitor_switch.widget.queue_draw()
     repaint_tline()
 
@@ -598,6 +601,7 @@ def update_frame_displayers(frame):
 
     norm_pos = frame / float(producer_length) 
     gui.pos_bar.set_normalized_pos(norm_pos)
+    gui.monitor_waveform_display.set_normalized_pos(norm_pos)
 
     kftoolmode.update_clip_frame(frame)
     
